@@ -30,20 +30,20 @@
 #include "../vpapplication.h"
 #include "../ifc/exception/vexception.h"
 #include "../vlayout/vlayoutexporter.h"
+#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
+#include "../vmisc/backport/qoverload.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
 
 #include <QMessageBox>
 #include <QShowEvent>
 #include <QtDebug>
 
 #ifndef Q_OS_WIN
-    Q_GLOBAL_STATIC_WITH_ARGS(const QString, baseFilenameRegExp, (QLatin1String("^[^\\/]+$")))
+    Q_GLOBAL_STATIC_WITH_ARGS(const QString, baseFilenameRegExp, (QLatin1String("^[^\\/]+$"))) // NOLINT
 #else
-    Q_GLOBAL_STATIC_WITH_ARGS(const QString, baseFilenameRegExp, (QLatin1String("^[^\\:?\"*|\\/<>]+$")))
+    Q_GLOBAL_STATIC_WITH_ARGS(const QString, baseFilenameRegExp, (QLatin1String("^[^\\:?\"*|\\/<>]+$"))) // NOLINT
 #endif
 
-bool DialogSaveManualLayout::havePdf = false;
-bool DialogSaveManualLayout::tested  = false;
-
 //---------------------------------------------------------------------------------------------------------------------
 DialogSaveManualLayout::DialogSaveManualLayout(int count, bool consoleExport, const QString &fileName, QWidget *parent)
     : VAbstractLayoutDialog(parent),
@@ -334,7 +334,7 @@ void DialogSaveManualLayout::SetTilesScheme(bool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogSaveManualLayout::IsTilesScheme() const
+auto DialogSaveManualLayout::IsTilesScheme() const -> bool
 {
     switch(Format())
     {
@@ -500,6 +500,8 @@ void DialogSaveManualLayout::ShowExample()
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogSaveManualLayout::SupportPSTest() -> bool
 {
+    static bool havePdf = false;
+    static bool tested  = false;
     if (!tested)
     {
         havePdf = VLayoutExporter::SupportPDFConversion();
