@@ -31,19 +31,22 @@
 #include <QXmlStreamAttributes>
 #include <ciso646>
 #include "vplayoutfilereader.h"
-#include "vplayoutfilewriter.h"
 #include "vplayoutliterals.h"
 #include "../layout/vpsheet.h"
 #include "../vlayout/vlayoutpiecepath.h"
 #include "../vlayout/vtextmanager.h"
 #include "../ifc/exception/vexception.h"
 #include "../ifc/exception/vexceptionconversionerror.h"
+#include "../vpatterndb/floatItemData/floatitemdef.h"
+#include "../vgeometry/vgeometrydef.h"
+#include "../layout/vplayout.h"
+#include "../layout/vppiece.h"
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_CLANG("-Wmissing-prototypes")
 QT_WARNING_DISABLE_INTEL(1418)
 
-Q_LOGGING_CATEGORY(MLReader, "mlReader")
+Q_LOGGING_CATEGORY(MLReader, "mlReader") // NOLINT
 
 QT_WARNING_POP
 
@@ -88,6 +91,7 @@ auto StringToPath(const QString &path) -> QVector<QPointF>
 {
     QVector<QPointF> p;
     QStringList points = path.split(ML::pointsSep);
+    p.reserve(points.size());
     for (const auto& point : points)
     {
         p.append(StringToPoint(point));
@@ -140,6 +144,7 @@ auto StringToLines(const QString &string) -> QVector<QLineF>
 {
     QStringList lines = string.split(ML::itemsSep);
     QVector<QLineF> path;
+    path.reserve(lines.size());
 
     for (const auto& line : lines)
     {
@@ -170,6 +175,7 @@ auto StringToMarkerShape(const QString &string) -> PlaceLabelImg
 {
     PlaceLabelImg shape;
     QStringList paths = string.split(ML::itemsSep);
+    shape.reserve(paths.size());
     for (const auto& path : paths)
     {
         shape.append(StringToPath(path));
@@ -466,18 +472,16 @@ void VPLayoutFileReader::ReadPiece(const VPPiecePtr &piece)
     QString uuidStr = ReadAttributeString(attribs, ML::AttrID, QUuid::createUuid().toString());
     piece->SetUUID(QUuid(uuidStr));
 
-    piece->SetName(ReadAttributeEmptyString(attribs, ML::AttrGradationLabel));
+    piece->SetGradationId(ReadAttributeEmptyString(attribs, ML::AttrGradationLabel));
     piece->SetCopyNumber(static_cast<quint16>(ReadAttributeUInt(attribs, ML::AttrCopyNumber, QChar('1'))));
     piece->SetHideMainPath(not ReadAttributeBool(attribs, ML::AttrShowSeamline, trueStr));
     piece->SetXScale(ReadAttributeDouble(attribs, ML::AttrXScale, QChar('1')));
     piece->SetYScale(ReadAttributeDouble(attribs, ML::AttrYScale, QChar('1')));
     piece->SetZValue(ReadAttributeDouble(attribs, ML::AttrZValue, QChar('1')));
-
-    bool pieceMirrored = ReadAttributeBool(attribs, ML::AttrMirrored, falseStr);
-    piece->SetMirror(pieceMirrored);
-
-    QString matrix = ReadAttributeEmptyString(attribs, ML::AttrTransform);
-    piece->SetMatrix(StringToTransfrom(matrix));
+    piece->SetMirror(ReadAttributeBool(attribs, ML::AttrMirrored, falseStr));
+    piece->SetForbidFlipping(ReadAttributeBool(attribs, ML::AttrForbidFlipping, falseStr));
+    piece->SetForceFlipping(ReadAttributeBool(attribs, ML::AttrForceFlipping, falseStr));
+    piece->SetMatrix(StringToTransfrom(ReadAttributeEmptyString(attribs, ML::AttrTransform)));
 
     const QStringList tags
     {
@@ -715,6 +719,7 @@ auto VPLayoutFileReader::ReadMarker() -> VLayoutPlaceLabel
 
     marker.shape = shape;
 
+    // cppcheck-suppress unknownMacro
     QT_WARNING_POP
 
     return marker;
@@ -957,7 +962,7 @@ auto VPLayoutFileReader::ReadAttributeBool(const QXmlStreamAttributes &attribs,
     {
         VExceptionConversionError excep(message, name);
         excep.AddMoreInformation(e.ErrorMessage());
-        throw excep;
+        throw excep; // NOLINT(cert-err09-cpp)
     }
 
     return val;
@@ -984,7 +989,7 @@ auto VPLayoutFileReader::ReadAttributeDouble(const QXmlStreamAttributes &attribs
     {
         VExceptionConversionError excep(message, name);
         excep.AddMoreInformation(e.ErrorMessage());
-        throw excep;
+        throw excep; // NOLINT(cert-err09-cpp)
     }
     return param;
 }
@@ -1010,7 +1015,7 @@ auto VPLayoutFileReader::ReadAttributeUInt(const QXmlStreamAttributes &attribs,
     {
         VExceptionConversionError excep(message, name);
         excep.AddMoreInformation(e.ErrorMessage());
-        throw excep;
+        throw excep; // NOLINT(cert-err09-cpp)
     }
     return param;
 }
@@ -1036,7 +1041,7 @@ auto VPLayoutFileReader::ReadAttributeInt(const QXmlStreamAttributes &attribs, c
     {
         VExceptionConversionError excep(message, name);
         excep.AddMoreInformation(e.ErrorMessage());
-        throw excep;
+        throw excep; // NOLINT(cert-err09-cpp)
     }
     return param;
 }
