@@ -74,6 +74,7 @@ auto PointToString(const QPointF &p) -> QString
 auto PathToString(const QVector<QPointF> &pathPoints) -> QString
 {
     QStringList path;
+    path.reserve(pathPoints.size());
 
     for (auto point : pathPoints)
     {
@@ -96,6 +97,7 @@ auto RectToString(const QRectF &r) -> QString
 auto MarkerShapeToString(const PlaceLabelImg &shape) -> QString
 {
     QStringList s;
+    s.reserve(shape.size());
     for (const auto& path : shape)
     {
         s.append(PathToString(path));
@@ -113,6 +115,7 @@ auto LineToString(const QLineF &line) -> QString
 auto LinesToString(const QVector<QLineF> &lines) -> QString
 {
     QStringList l;
+    l.reserve(lines.size());
     for (auto line : lines)
     {
         l.append(LineToString(line));
@@ -263,6 +266,10 @@ void VPLayoutFileWriter::WritePiece(const VPPiecePtr &piece)
     SetAttribute(ML::AttrName, piece->GetName());
     SetAttributeOrRemoveIf<bool>(ML::AttrMirrored, piece->IsMirror(),
                                  [](bool mirrored) noexcept {return not mirrored;});
+    SetAttributeOrRemoveIf<bool>(ML::AttrForbidFlipping, piece->IsForbidFlipping(),
+                                 [](bool forbid) noexcept {return not forbid;});
+    SetAttributeOrRemoveIf<bool>(ML::AttrForceFlipping, piece->IsForceFlipping(),
+                                 [](bool force) noexcept {return not force;});
     SetAttribute(ML::AttrTransform, TransformToString(piece->GetMatrix()));
     SetAttributeOrRemoveIf<QString>(ML::AttrGradationLabel, piece->GetGradationId(),
                                     [](const QString &label) noexcept {return label.isEmpty();});
