@@ -30,8 +30,10 @@
 #include "ui_tapepreferencesconfigurationpage.h"
 #include "../../mapplication.h"
 #include "../../vtapesettings.h"
-#include "../vpatterndb/variables/vmeasurement.h"
 #include "../vpatterndb/pmsystems.h"
+#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
+#include "../vmisc/backport/qoverload.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
 
 //---------------------------------------------------------------------------------------------------------------------
 TapePreferencesConfigurationPage::TapePreferencesConfigurationPage(QWidget *parent)
@@ -100,7 +102,7 @@ TapePreferencesConfigurationPage::~TapePreferencesConfigurationPage()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QStringList TapePreferencesConfigurationPage::Apply()
+auto TapePreferencesConfigurationPage::Apply() -> QStringList
 {
     QStringList preferences;
     VTapeSettings *settings = MApplication::VApp()->TapeSettings();
@@ -121,16 +123,16 @@ QStringList TapePreferencesConfigurationPage::Apply()
 
     if (m_langChanged || m_systemChanged)
     {
-        const QString locale = qvariant_cast<QString>(ui->langCombo->currentData());
+        const auto locale = qvariant_cast<QString>(ui->langCombo->currentData());
         settings->SetLocale(locale);
         m_langChanged = false;
 
-        const QString code = qvariant_cast<QString>(ui->systemCombo->currentData());
+        const auto code = qvariant_cast<QString>(ui->systemCombo->currentData());
         settings->SetPMSystemCode(code);
         m_systemChanged = false;
 
         VAbstractApplication::VApp()->LoadTranslation(locale);
-        qApp->processEvents();// force to call changeEvent
+        QCoreApplication::processEvents();// force to call changeEvent
 
         // Part about measurments will not be updated automatically
         MApplication::VApp()->RetranslateTables();
@@ -164,7 +166,7 @@ void TapePreferencesConfigurationPage::RetranslateUi()
     ui->osOptionCheck->setText(tr("With OS options") + QStringLiteral(" (%1)").arg(QLocale().decimalPoint()));
 
     {
-    const QString code = qvariant_cast<QString>(ui->systemCombo->currentData());
+    const auto code = qvariant_cast<QString>(ui->systemCombo->currentData());
     ui->systemCombo->blockSignals(true);
     ui->systemCombo->clear();
     InitPMSystems(ui->systemCombo);
