@@ -27,6 +27,9 @@
  *************************************************************************/
 #include "dialogdimensionlabels.h"
 #include "ui_dialogdimensionlabels.h"
+#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
+#include "../vmisc/backport/qoverload.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
 
 //---------------------------------------------------------------------------------------------------------------------
 DialogDimensionLabels::DialogDimensionLabels(const QMap<MeasurementDimension, MeasurementDimension_p> &dimensions,
@@ -196,8 +199,6 @@ void DialogDimensionLabels::InitTable()
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogDimensionLabels::DimensionValue(const MeasurementDimension_p &dimension, qreal value) const -> QString
 {
-    QStringList labels;
-
     if (dimension->Type() == MeasurementDimension::X)
     {
         return QString::number(value);
@@ -205,7 +206,7 @@ auto DialogDimensionLabels::DimensionValue(const MeasurementDimension_p &dimensi
 
     if (dimension->Type() == MeasurementDimension::Y)
     {
-        if (dimension->IsCircumference())
+        if (dimension->IsBodyMeasurement())
         {
             return QString::number(m_fullCircumference ? value*2 : value);
         }
