@@ -38,6 +38,8 @@
 #endif // QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
 
 class QDoubleSpinBox;
+class QGroupBox;
+class QLineEdit;
 
 namespace Ui
 {
@@ -62,13 +64,14 @@ protected:
 private slots:
     void ShowFullCircumference();
 
-    void XDimensionCircumferenceChanged();
-    void YDimensionCircumferenceChanged();
-    void WDimensionCircumferenceChanged();
-    void ZDimensionCircumferenceChanged();
+    void XDimensionBodyMeasurementChanged();
+    void YDimensionBodyMeasurementChanged();
+    void WDimensionBodyMeasurementChanged();
+    void ZDimensionBodyMeasurementChanged();
 
 private:
-    Q_DISABLE_COPY_MOVE(DialogSetupMultisize)
+    // cppcheck-suppress unknownMacro
+    Q_DISABLE_COPY_MOVE(DialogSetupMultisize) // NOLINT
     Ui::DialogSetupMultisize *ui;
     bool m_isInitialized{false};
     QSharedPointer<VXMeasurementDimension> m_xDimension;
@@ -76,6 +79,8 @@ private:
     QSharedPointer<VWMeasurementDimension> m_wDimension;
     QSharedPointer<VZMeasurementDimension> m_zDimension;
 
+    void CheckDimension(QGroupBox *group, QGroupBox *nameGroup, QLineEdit *lineEdit, bool &dimensionValid,
+                        int &dimensions, const MeasurementDimension_p &dimension);
     void CheckState();
 
     void InitDimensionMinMax(QDoubleSpinBox *doubleSpinBoxMinValue, QDoubleSpinBox *doubleSpinBoxMaxValue,
