@@ -29,7 +29,7 @@
 #include "preferencespathpage.h"
 #include "ui_preferencespathpage.h"
 #include "../vmisc/vvalentinasettings.h"
-#include "../../core/vapplication.h"
+#include "../vmisc/vabstractvalapplication.h"
 
 #include <QDir>
 #include <QFileDialog>
@@ -63,7 +63,7 @@ PreferencesPathPage::~PreferencesPathPage()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QStringList PreferencesPathPage::Apply()
+auto PreferencesPathPage::Apply() -> QStringList
 {
     VValentinaSettings *settings = VAbstractValApplication::VApp()->ValentinaSettings();
     settings->SetPathIndividualMeasurements(ui->pathTable->item(0, 1)->text());
@@ -74,7 +74,7 @@ QStringList PreferencesPathPage::Apply()
     settings->SetPathLabelTemplate(ui->pathTable->item(5, 1)->text());
     settings->SetPathManualLayouts(ui->pathTable->item(6, 1)->text());
 
-    return QStringList(); // No changes those require restart.
+    return {}; // No changes those require restart.
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -206,49 +206,49 @@ void PreferencesPathPage::InitTable()
 
     {
         ui->pathTable->setItem(0, 0, new QTableWidgetItem(tr("My Individual Measurements")));
-        QTableWidgetItem *item = new QTableWidgetItem(settings->GetPathIndividualMeasurements());
+        auto *item = new QTableWidgetItem(settings->GetPathIndividualMeasurements());
         item->setToolTip(settings->GetPathIndividualMeasurements());
         ui->pathTable->setItem(0, 1, item);
     }
 
     {
         ui->pathTable->setItem(1, 0, new QTableWidgetItem(tr("My Multisize Measurements")));
-        QTableWidgetItem *item = new QTableWidgetItem(settings->GetPathMultisizeMeasurements());
+        auto *item = new QTableWidgetItem(settings->GetPathMultisizeMeasurements());
         item->setToolTip(settings->GetPathMultisizeMeasurements());
         ui->pathTable->setItem(1, 1, item);
     }
 
     {
         ui->pathTable->setItem(2, 0, new QTableWidgetItem(tr("My Patterns")));
-        QTableWidgetItem *item = new QTableWidgetItem(settings->GetPathPattern());
+        auto *item = new QTableWidgetItem(settings->GetPathPattern());
         item->setToolTip(settings->GetPathPattern());
         ui->pathTable->setItem(2, 1, item);
     }
 
     {
         ui->pathTable->setItem(3, 0, new QTableWidgetItem(tr("My Layouts")));
-        QTableWidgetItem *item = new QTableWidgetItem(settings->GetPathLayout());
+        auto *item = new QTableWidgetItem(settings->GetPathLayout());
         item->setToolTip(settings->GetPathLayout());
         ui->pathTable->setItem(3, 1, item);
     }
 
     {
         ui->pathTable->setItem(4, 0, new QTableWidgetItem(tr("My Templates")));
-        QTableWidgetItem *item = new QTableWidgetItem(settings->GetPathTemplate());
+        auto *item = new QTableWidgetItem(settings->GetPathTemplate());
         item->setToolTip(settings->GetPathTemplate());
         ui->pathTable->setItem(4, 1, item);
     }
 
     {
         ui->pathTable->setItem(5, 0, new QTableWidgetItem(tr("My label templates")));
-        QTableWidgetItem *item = new QTableWidgetItem(settings->GetPathLabelTemplate());
+        auto *item = new QTableWidgetItem(settings->GetPathLabelTemplate());
         item->setToolTip(settings->GetPathLabelTemplate());
         ui->pathTable->setItem(5, 1, item);
     }
 
     {
         ui->pathTable->setItem(6, 0, new QTableWidgetItem(tr("My manual layouts")));
-        QTableWidgetItem *item = new QTableWidgetItem(settings->GetPathManualLayouts());
+        auto *item = new QTableWidgetItem(settings->GetPathManualLayouts());
         item->setToolTip(settings->GetPathManualLayouts());
         ui->pathTable->setItem(6, 1, item);
     }
