@@ -28,11 +28,15 @@
 
 #include "preferencespatternpage.h"
 #include "ui_preferencespatternpage.h"
-#include "../../core/vapplication.h"
-#include "../ifc/xml/vabstractpattern.h"
 #include "../dialogdatetimeformats.h"
 #include "../dialogknownmaterials.h"
 #include "../vmisc/vvalentinasettings.h"
+#include "../vmisc/vabstractvalapplication.h"
+#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
+#include "../vmisc/backport/qoverload.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
+#include "../vwidgets/vmaingraphicsview.h"
+#include "../ifc/xml/vabstractpattern.h"
 
 #include <QMessageBox>
 #include <QDate>
@@ -40,11 +44,12 @@
 
 namespace
 {
-QStringList ComboBoxAllStrings(QComboBox *combo)
+auto ComboBoxAllStrings(QComboBox *combo) -> QStringList
 {
     SCASSERT(combo != nullptr)
 
     QStringList itemsInComboBox;
+    itemsInComboBox.reserve(combo->count());
     for (int index = 0; index < combo->count(); ++index)
     {
         itemsInComboBox << combo->itemText(index);
@@ -52,14 +57,12 @@ QStringList ComboBoxAllStrings(QComboBox *combo)
 
     return itemsInComboBox;
 }
-}
+}  // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 PreferencesPatternPage::PreferencesPatternPage(QWidget *parent)
     : QWidget(parent),
-      ui(new Ui::PreferencesPatternPage),
-      m_knownMaterials(),
-      m_oldLineUnit(Unit::Mm)
+      ui(new Ui::PreferencesPatternPage)
 {
     ui->setupUi(this);
     RetranslateUi();
@@ -124,7 +127,7 @@ PreferencesPatternPage::~PreferencesPatternPage()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QStringList PreferencesPatternPage::Apply()
+auto PreferencesPatternPage::Apply() -> QStringList
 {
     QStringList preferences;
 
@@ -208,7 +211,7 @@ void PreferencesPatternPage::EditDateTimeFormats()
 {
     VValentinaSettings *settings = VAbstractValApplication::VApp()->ValentinaSettings();
 
-    QPushButton *button = qobject_cast<QPushButton *>(sender());
+    auto *button = qobject_cast<QPushButton *>(sender());
     if (button == ui->pushButtonEditDateFormats)
     {
         CallDateTimeFormatEditor(QDate::currentDate(), VCommonSettings::PredefinedDateFormats(),
@@ -252,6 +255,7 @@ void PreferencesPatternPage::InitLabelDateTimeFormats()
 //---------------------------------------------------------------------------------------------------------------------
 void PreferencesPatternPage::InitComboBoxFormats(QComboBox *box, const QStringList &items, const QString &currentFormat)
 {
+    // cppcheck-suppress unknownMacro
     SCASSERT(box != nullptr)
 
     box->addItems(items);
