@@ -28,10 +28,11 @@
 
 #include "dialoglayoutsettings.h"
 #include "ui_dialoglayoutsettings.h"
-#include "../core/vapplication.h"
-#include "../ifc/xml/vdomdocument.h"
 #include "../vmisc/vvalentinasettings.h"
-#include "../vmisc/vmath.h"
+#include "../vmisc/vabstractvalapplication.h"
+#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
+#include "../vmisc/backport/qoverload.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
 #include "../vlayout/vlayoutgenerator.h"
 
 #include <QMessageBox>
@@ -41,12 +42,12 @@
 //---------------------------------------------------------------------------------------------------------------------
 DialogLayoutSettings::DialogLayoutSettings(VLayoutGenerator *generator, QWidget *parent, bool disableSettings)
     : VAbstractLayoutDialog(parent), 
-      disableSettings(disableSettings), 
+      m_disableSettings(disableSettings),
       ui(new Ui::DialogLayoutSettings), 
-      oldPaperUnit(Unit::Mm),
-      oldLayoutUnit(Unit::Mm),
-      generator(generator),
-      isInitialized(false)
+      m_oldPaperUnit(Unit::Mm),
+      m_oldLayoutUnit(Unit::Mm),
+      m_generator(generator),
+      m_isInitialized(false)
 {
     ui->setupUi(this);
 
@@ -63,7 +64,7 @@ DialogLayoutSettings::DialogLayoutSettings(VLayoutGenerator *generator, QWidget
     InitPrinter();
 
     //in export console mode going to use defaults
-    if (disableSettings == false)
+    if (not disableSettings)
     {
         ReadSettings();
     }
@@ -116,9 +117,9 @@ DialogLayoutSettings::~DialogLayoutSettings()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal DialogLayoutSettings::GetPaperHeight() const
+auto DialogLayoutSettings::GetPaperHeight() const -> qreal
 {
-    return UnitConvertor(ui->doubleSpinBoxPaperHeight->value(), oldPaperUnit, Unit::Px);
+    return UnitConvertor(ui->doubleSpinBoxPaperHeight->value(), m_oldPaperUnit, Unit::Px);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -129,9 +130,9 @@ void DialogLayoutSettings::SetPaperHeight(qreal value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal DialogLayoutSettings::GetPaperWidth() const
+auto DialogLayoutSettings::GetPaperWidth() const -> qreal
 {
-    return UnitConvertor(ui->doubleSpinBoxPaperWidth->value(), oldPaperUnit, Unit::Px);
+    return UnitConvertor(ui->doubleSpinBoxPaperWidth->value(), m_oldPaperUnit, Unit::Px);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -142,7 +143,7 @@ void DialogLayoutSettings::SetPaperWidth(qreal value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int DialogLayoutSettings::GetNestingTime() const
+auto DialogLayoutSettings::GetNestingTime() const -> int
 {
     return ui->spinBoxNestingTime->value();
 }
@@ -154,7 +155,7 @@ void DialogLayoutSettings::SetNestingTime(int value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal DialogLayoutSettings::GetEfficiencyCoefficient() const
+auto DialogLayoutSettings::GetEfficiencyCoefficient() const -> qreal
 {
     return ui->doubleSpinBoxEfficiency->value();
 }
@@ -166,9 +167,9 @@ void DialogLayoutSettings::SetEfficiencyCoefficient(qreal ration)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal DialogLayoutSettings::GetLayoutWidth() const
+auto DialogLayoutSettings::GetLayoutWidth() const -> qreal
 {
-    return UnitConvertor(ui->doubleSpinBoxLayoutWidth->value(), oldLayoutUnit, Unit::Px);
+    return UnitConvertor(ui->doubleSpinBoxLayoutWidth->value(), m_oldLayoutUnit, Unit::Px);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -178,13 +179,13 @@ void DialogLayoutSettings::SetLayoutWidth(qreal value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QMarginsF DialogLayoutSettings::GetFields() const
+auto DialogLayoutSettings::GetFields() const -> QMarginsF
 {
     QMarginsF fields;
-    fields.setLeft(UnitConvertor(ui->doubleSpinBoxLeftField->value(), oldLayoutUnit, Unit::Px));
-    fields.setRight(UnitConvertor(ui->doubleSpinBoxRightField->value(), oldLayoutUnit, Unit::Px));
-    fields.setTop(UnitConvertor(ui->doubleSpinBoxTopField->value(), oldLayoutUnit, Unit::Px));
-    fields.setBottom(UnitConvertor(ui->doubleSpinBoxBottomField->value(), oldLayoutUnit, Unit::Px));
+    fields.setLeft(UnitConvertor(ui->doubleSpinBoxLeftField->value(), m_oldLayoutUnit, Unit::Px));
+    fields.setRight(UnitConvertor(ui->doubleSpinBoxRightField->value(), m_oldLayoutUnit, Unit::Px));
+    fields.setTop(UnitConvertor(ui->doubleSpinBoxTopField->value(), m_oldLayoutUnit, Unit::Px));
+    fields.setBottom(UnitConvertor(ui->doubleSpinBoxBottomField->value(), m_oldLayoutUnit, Unit::Px));
     return fields;
 }
 
@@ -198,20 +199,19 @@ void DialogLayoutSettings::SetFields(const QMarginsF &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-Cases DialogLayoutSettings::GetGroup() const
+auto DialogLayoutSettings::GetGroup() const -> Cases
 {
     if (ui->radioButtonThreeGroups->isChecked())
     {
         return Cases::CaseThreeGroup;
     }
-    else if (ui->radioButtonTwoGroups->isChecked())
+
+    if (ui->radioButtonTwoGroups->isChecked())
     {
         return Cases::CaseTwoGroup;
     }
-    else
-    {
-        return Cases::CaseDesc;
-    }
+
+    return Cases::CaseDesc;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -234,7 +234,7 @@ void DialogLayoutSettings::SetGroup(const Cases &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogLayoutSettings::GetFollowGrainline() const
+auto DialogLayoutSettings::GetFollowGrainline() const -> bool
 {
     return ui->checkBoxFollowGrainline->isChecked();
 }
@@ -246,7 +246,7 @@ void DialogLayoutSettings::SetFollowGrainline(bool state)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogLayoutSettings::GetManualPriority() const
+auto DialogLayoutSettings::GetManualPriority() const -> bool
 {
     return ui->checkBoxManualPriority->isChecked();
 }
@@ -258,7 +258,7 @@ void DialogLayoutSettings::SetManualPriority(bool state)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogLayoutSettings::GetAutoCropLength() const
+auto DialogLayoutSettings::GetAutoCropLength() const -> bool
 {
     return ui->checkBoxAutoCropLength->isChecked();
 }
@@ -270,7 +270,7 @@ void DialogLayoutSettings::SetAutoCropLength(bool autoCropLength)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogLayoutSettings::GetAutoCropWidth() const
+auto DialogLayoutSettings::GetAutoCropWidth() const -> bool
 {
     return ui->checkBoxAutoCropWidth->isChecked();
 }
@@ -282,7 +282,7 @@ void DialogLayoutSettings::SetAutoCropWidth(bool autoCropWidth)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogLayoutSettings::IsSaveLength() const
+auto DialogLayoutSettings::IsSaveLength() const -> bool
 {
     return ui->checkBoxSaveLength->isChecked();
 }
@@ -294,7 +294,7 @@ void DialogLayoutSettings::SetSaveLength(bool save)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogLayoutSettings::IsPreferOneSheetSolution() const
+auto DialogLayoutSettings::IsPreferOneSheetSolution() const -> bool
 {
     return ui->checkBoxOneSheetSolution->isChecked();
 }
@@ -306,7 +306,7 @@ void DialogLayoutSettings::SetPreferOneSheetSolution(bool prefer)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogLayoutSettings::IsUnitePages() const
+auto DialogLayoutSettings::IsUnitePages() const -> bool
 {
     return ui->checkBoxUnitePages->isChecked();
 }
@@ -318,7 +318,7 @@ void DialogLayoutSettings::SetUnitePages(bool save)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogLayoutSettings::IsStripOptimization() const
+auto DialogLayoutSettings::IsStripOptimization() const -> bool
 {
     return ui->groupBoxStrips->isChecked();
 }
@@ -330,7 +330,7 @@ void DialogLayoutSettings::SetStripOptimization(bool save)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint8 DialogLayoutSettings::GetMultiplier() const
+auto DialogLayoutSettings::GetMultiplier() const -> quint8
 {
     return static_cast<quint8>(ui->spinBoxMultiplier->value());
 }
@@ -342,7 +342,7 @@ void DialogLayoutSettings::SetMultiplier(const quint8 &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogLayoutSettings::IsIgnoreAllFields() const
+auto DialogLayoutSettings::IsIgnoreAllFields() const -> bool
 {
     return ui->checkBoxIgnoreFileds->isChecked();
 }
@@ -354,7 +354,7 @@ void DialogLayoutSettings::SetIgnoreAllFields(bool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogLayoutSettings::IsTextAsPaths() const
+auto DialogLayoutSettings::IsTextAsPaths() const -> bool
 {
     return ui->checkBoxTextAsPaths->isChecked();
 }
@@ -366,7 +366,7 @@ void DialogLayoutSettings::SetTextAsPaths(bool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogLayoutSettings::IsNestQuantity() const
+auto DialogLayoutSettings::IsNestQuantity() const -> bool
 {
     return ui->checkBoxNestQuantity->isChecked();
 }
@@ -378,7 +378,7 @@ void DialogLayoutSettings::SetNestQuantity(bool state)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogLayoutSettings::SelectedPrinter() const
+auto DialogLayoutSettings::SelectedPrinter() const -> QString
 {
     return ui->comboBoxPrinter->currentText();
 }
@@ -451,15 +451,15 @@ void DialogLayoutSettings::ConvertPaperSize()
     ui->doubleSpinBoxPaperWidth->blockSignals(false);
     ui->doubleSpinBoxPaperHeight->blockSignals(false);
 
-    const qreal newWidth = UnitConvertor(width, oldPaperUnit, paperUnit);
-    const qreal newHeight = UnitConvertor(height, oldPaperUnit, paperUnit);
+    const qreal newWidth = UnitConvertor(width, m_oldPaperUnit, paperUnit);
+    const qreal newHeight = UnitConvertor(height, m_oldPaperUnit, paperUnit);
 
-    const qreal newLeft = UnitConvertor(left, oldPaperUnit, paperUnit);
-    const qreal newRight = UnitConvertor(right, oldPaperUnit, paperUnit);
-    const qreal newTop = UnitConvertor(top, oldPaperUnit, paperUnit);
-    const qreal newBottom = UnitConvertor(bottom, oldPaperUnit, paperUnit);
+    const qreal newLeft = UnitConvertor(left, m_oldPaperUnit, paperUnit);
+    const qreal newRight = UnitConvertor(right, m_oldPaperUnit, paperUnit);
+    const qreal newTop = UnitConvertor(top, m_oldPaperUnit, paperUnit);
+    const qreal newBottom = UnitConvertor(bottom, m_oldPaperUnit, paperUnit);
 
-    oldPaperUnit = paperUnit;
+    m_oldPaperUnit = paperUnit;
     CorrectPaperDecimals();
     MinimumPaperSize();
 
@@ -473,7 +473,7 @@ void DialogLayoutSettings::ConvertPaperSize()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogLayoutSettings::SelectPaperUnit(const QString& units)
+auto DialogLayoutSettings::SelectPaperUnit(const QString& units) -> bool
 {
     qint32 indexUnit = ui->comboBoxPaperSizeUnit->findData(units);
     if (indexUnit != -1)
@@ -484,7 +484,7 @@ bool DialogLayoutSettings::SelectPaperUnit(const QString& units)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogLayoutSettings::SelectLayoutUnit(const QString &units)
+auto DialogLayoutSettings::SelectLayoutUnit(const QString &units) -> bool
 {
     qint32 indexUnit = ui->comboBoxLayoutUnit->findData(units);
     if (indexUnit != -1)
@@ -495,19 +495,19 @@ bool DialogLayoutSettings::SelectLayoutUnit(const QString &units)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal DialogLayoutSettings::LayoutToPixels(qreal value) const
+auto DialogLayoutSettings::LayoutToPixels(qreal value) const -> qreal
 {
     return UnitConvertor(value, LayoutUnit(), Unit::Px);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal DialogLayoutSettings::PageToPixels(qreal value) const
+auto DialogLayoutSettings::PageToPixels(qreal value) const -> qreal
 {
     return UnitConvertor(value, PaperUnit(), Unit::Px);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogLayoutSettings::MakeGroupsHelp()
+auto DialogLayoutSettings::MakeGroupsHelp() -> QString
 {
     //that is REALLY dummy ... can't figure fast how to automate generation... :/
     return tr("\n\tThree groups: big, middle, small = 0;\n\tTwo groups: big, small = 1;\n\tDescending area = 2");
@@ -522,7 +522,7 @@ void DialogLayoutSettings::showEvent(QShowEvent *event)
         return;
     }
 
-    if (isInitialized)
+    if (m_isInitialized)
     {
         return;
     }
@@ -534,7 +534,7 @@ void DialogLayoutSettings::showEvent(QShowEvent *event)
         resize(sz);
     }
 
-    isInitialized = true;//first show windows are held
+    m_isInitialized = true;//first show windows are held
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -543,7 +543,7 @@ void DialogLayoutSettings::resizeEvent(QResizeEvent *event)
     // remember the size for the next time this dialog is opened, but only
     // if widget was already initialized, which rules out the resize at
     // dialog creating, which would
-    if (isInitialized)
+    if (m_isInitialized)
     {
         VAbstractApplication::VApp()->Settings()->SetLayoutSettingsDialogSize(size());
     }
@@ -558,9 +558,9 @@ void DialogLayoutSettings::ConvertLayoutSize()
 
     ui->doubleSpinBoxLayoutWidth->setMaximum(FromPixel(QIMAGE_MAX, unit));
 
-    const qreal newLayoutWidth = UnitConvertor(layoutWidth, oldLayoutUnit, unit);
+    const qreal newLayoutWidth = UnitConvertor(layoutWidth, m_oldLayoutUnit, unit);
 
-    oldLayoutUnit = unit;
+    m_oldLayoutUnit = unit;
     CorrectLayoutDecimals();
     MinimumLayoutSize();
 
@@ -585,7 +585,7 @@ void DialogLayoutSettings::PaperSizeChanged()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogLayoutSettings::SelectTemplate(const PaperSizeTemplate& id)
+auto DialogLayoutSettings::SelectTemplate(const PaperSizeTemplate& id) -> bool
 {
     int index = ui->comboBoxTemplates->findData(static_cast<VIndexType>(id));
     if (index > -1)
@@ -617,35 +617,35 @@ void DialogLayoutSettings::Swap(bool checked)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogLayoutSettings::DialogAccepted()
 {
-    SCASSERT(generator != nullptr)
-    generator->SetLayoutWidth(GetLayoutWidth());
-    generator->SetCaseType(GetGroup());
-    generator->SetPaperHeight(GetPaperHeight());
-    generator->SetPaperWidth(GetPaperWidth());
-    generator->SetNestingTime(GetNestingTime());
-    generator->SetEfficiencyCoefficient(GetEfficiencyCoefficient());
-    generator->SetFollowGrainline(GetFollowGrainline());
-    generator->SetManualPriority(GetManualPriority());
-    generator->SetAutoCropLength(GetAutoCropLength());
-    generator->SetAutoCropWidth(GetAutoCropWidth());
-    generator->SetSaveLength(IsSaveLength());
-    generator->SetPreferOneSheetSolution(IsPreferOneSheetSolution());
-    generator->SetUnitePages(IsUnitePages());
-    generator->SetStripOptimization(IsStripOptimization());
-    generator->SetMultiplier(GetMultiplier());
-    generator->SetTextAsPaths(IsTextAsPaths());
-    generator->SetNestQuantity(IsNestQuantity());
+    SCASSERT(m_generator != nullptr)
+    m_generator->SetLayoutWidth(GetLayoutWidth());
+    m_generator->SetCaseType(GetGroup());
+    m_generator->SetPaperHeight(GetPaperHeight());
+    m_generator->SetPaperWidth(GetPaperWidth());
+    m_generator->SetNestingTime(GetNestingTime());
+    m_generator->SetEfficiencyCoefficient(GetEfficiencyCoefficient());
+    m_generator->SetFollowGrainline(GetFollowGrainline());
+    m_generator->SetManualPriority(GetManualPriority());
+    m_generator->SetAutoCropLength(GetAutoCropLength());
+    m_generator->SetAutoCropWidth(GetAutoCropWidth());
+    m_generator->SetSaveLength(IsSaveLength());
+    m_generator->SetPreferOneSheetSolution(IsPreferOneSheetSolution());
+    m_generator->SetUnitePages(IsUnitePages());
+    m_generator->SetStripOptimization(IsStripOptimization());
+    m_generator->SetMultiplier(GetMultiplier());
+    m_generator->SetTextAsPaths(IsTextAsPaths());
+    m_generator->SetNestQuantity(IsNestQuantity());
 
     if (IsIgnoreAllFields())
     {
-        generator->SetPrinterFields(false, QMarginsF());
+        m_generator->SetPrinterFields(false, QMarginsF());
     }
     else
     {
         QPrinterInfo printer = QPrinterInfo::printerInfo(ui->comboBoxPrinter->currentText());
         if (printer.isNull())
         {
-            generator->SetPrinterFields(true, GetFields());
+            m_generator->SetPrinterFields(true, GetFields());
         }
         else
         {
@@ -660,43 +660,23 @@ void DialogLayoutSettings::DialogAccepted()
                                                QMessageBox::Yes|QMessageBox::No, QMessageBox::No);
                 if (answer == QMessageBox::No)
                 {
-                    if (fields.left() < minFields.left())
-                    {
-                        ui->doubleSpinBoxLeftField->setValue(UnitConvertor(minFields.left(), Unit::Px, LayoutUnit()));
-                    }
-
-                    if (fields.right() < minFields.right())
-                    {
-                        ui->doubleSpinBoxRightField->setValue(UnitConvertor(minFields.right(), Unit::Px, LayoutUnit()));
-                    }
-
-                    if (fields.top() < minFields.top())
-                    {
-                        ui->doubleSpinBoxTopField->setValue(UnitConvertor(minFields.top(), Unit::Px, LayoutUnit()));
-                    }
-
-                    if (fields.bottom() < minFields.bottom())
-                    {
-                        ui->doubleSpinBoxBottomField->setValue(UnitConvertor(minFields.bottom(), Unit::Px,
-                                                                             LayoutUnit()));
-                    }
-
-                    generator->SetPrinterFields(true, GetFields());
+                    SetMinMargins(fields, minFields);
+                    m_generator->SetPrinterFields(true, GetFields());
                 }
                 else
                 {
-                    generator->SetPrinterFields(false, GetFields());
+                    m_generator->SetPrinterFields(false, GetFields());
                 }
             }
             else
             {
-                generator->SetPrinterFields(true, GetFields());
+                m_generator->SetPrinterFields(true, GetFields());
             }
         }
     }
 
     //don't want to break visual settings when cmd used
-    if (disableSettings == false)
+    if (not m_disableSettings)
     {
         WriteSettings();
     }
@@ -781,7 +761,7 @@ void DialogLayoutSettings::InitPaperUnits()
     ui->comboBoxPaperSizeUnit->addItem(tr("Pixels"), QVariant(UnitsToStr(Unit::Px)));
 
     // set default unit
-    oldPaperUnit = StrToUnits(VAbstractValApplication::VApp()->ValentinaSettings()->GetUnit());
+    m_oldPaperUnit = StrToUnits(VAbstractValApplication::VApp()->ValentinaSettings()->GetUnit());
     const qint32 indexUnit = ui->comboBoxPaperSizeUnit->findData(
                 VAbstractValApplication::VApp()->ValentinaSettings()->GetUnit());
     if (indexUnit != -1)
@@ -798,7 +778,7 @@ void DialogLayoutSettings::InitLayoutUnits()
     ui->comboBoxLayoutUnit->addItem(tr("Inches"), QVariant(UnitsToStr(Unit::Inch)));
 
     // set default unit
-    oldLayoutUnit = StrToUnits(VAbstractValApplication::VApp()->ValentinaSettings()->GetUnit());
+    m_oldLayoutUnit = StrToUnits(VAbstractValApplication::VApp()->ValentinaSettings()->GetUnit());
     const qint32 indexUnit = ui->comboBoxLayoutUnit->findData(
                 VAbstractValApplication::VApp()->ValentinaSettings()->GetUnit());
     if (indexUnit != -1)
@@ -829,9 +809,9 @@ void DialogLayoutSettings::InitPrinter()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogLayoutSettings::MakeHelpTemplateList()
+auto DialogLayoutSettings::MakeHelpTemplateList() -> QString
 {
-    QString out = "\n";
+    QString out = QChar('\n');
 
     auto cntr = static_cast<VIndexType>(PaperSizeTemplate::A0);
     for (int i = 0; i < VAbstractLayoutDialog::pageFormatNames.size(); ++i)
@@ -842,11 +822,11 @@ QString DialogLayoutSettings::MakeHelpTemplateList()
 
             if (i < VAbstractLayoutDialog::pageFormatNames.size() - 2)
             {
-               out += ",\n";
+               out += QLatin1String(",\n");
             }
             else
             {
-               out += ".\n";
+               out += QLatin1String(".\n");
             }
         }
     }
@@ -854,9 +834,9 @@ QString DialogLayoutSettings::MakeHelpTemplateList()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogLayoutSettings::MakeHelpTiledPdfTemplateList()
+auto DialogLayoutSettings::MakeHelpTiledPdfTemplateList() -> QString
 {
-    QString out = "\n";
+    QString out = QChar('\n');
 
     for (int i = 0; i <= static_cast<int>(PaperSizeTemplate::Tabloid); ++i)
     {
@@ -864,18 +844,18 @@ QString DialogLayoutSettings::MakeHelpTiledPdfTemplateList()
 
         if (i < static_cast<int>(PaperSizeTemplate::Tabloid))
         {
-           out += ",\n";
+           out += QLatin1String(",\n");
         }
         else
         {
-           out += ".\n";
+           out += QLatin1String(".\n");
         }
     }
     return out;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QSizeF DialogLayoutSettings::Template()
+auto DialogLayoutSettings::Template() -> QSizeF
 {
     const PaperSizeTemplate temp = static_cast<PaperSizeTemplate>(ui->comboBoxTemplates->currentData().toInt());
 
@@ -908,11 +888,11 @@ QSizeF DialogLayoutSettings::Template()
         default:
             break;
     }
-    return QSizeF();
+    return {};
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QSizeF DialogLayoutSettings::GetTemplateSize(const PaperSizeTemplate &tmpl, const Unit &unit) const
+auto DialogLayoutSettings::GetTemplateSize(const PaperSizeTemplate &tmpl, const Unit &unit) const -> QSizeF
 {
     qreal width = 0;
     qreal height = 0;
@@ -929,42 +909,37 @@ QSizeF DialogLayoutSettings::GetTemplateSize(const PaperSizeTemplate &tmpl, cons
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QMarginsF DialogLayoutSettings::MinPrinterFields() const
+auto DialogLayoutSettings::MinPrinterFields() const -> QMarginsF
 {
     QPrinterInfo printer = QPrinterInfo::printerInfo(ui->comboBoxPrinter->currentText());
     if (not printer.isNull())
     {
-        QSharedPointer<QPrinter> pr = QSharedPointer<QPrinter>(new QPrinter(printer));
-        return GetMinPrinterFields(pr);
-    }
-    else
-    {
-        return QMarginsF();
+        return GetMinPrinterFields(QSharedPointer<QPrinter>(new QPrinter(printer)));
     }
+
+    return {};
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QMarginsF DialogLayoutSettings::GetDefPrinterFields() const
+auto DialogLayoutSettings::GetDefPrinterFields() const -> QMarginsF
 {
     QPrinterInfo printer = QPrinterInfo::printerInfo(ui->comboBoxPrinter->currentText());
     if (not printer.isNull())
     {
         return GetPrinterFields(QSharedPointer<QPrinter>(new QPrinter(printer)));
     }
-    else
-    {
-        return QMarginsF();
-    }
+
+    return {};
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-Unit DialogLayoutSettings::PaperUnit() const
+auto DialogLayoutSettings::PaperUnit() const -> Unit
 {
     return StrToUnits(ui->comboBoxPaperSizeUnit->currentData().toString());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-Unit DialogLayoutSettings::LayoutUnit() const
+auto DialogLayoutSettings::LayoutUnit() const -> Unit
 {
     return StrToUnits(ui->comboBoxLayoutUnit->currentData().toString());
 }
@@ -972,7 +947,7 @@ Unit DialogLayoutSettings::LayoutUnit() const
 //---------------------------------------------------------------------------------------------------------------------
 void DialogLayoutSettings::CorrectPaperDecimals()
 {
-    switch (oldPaperUnit)
+    switch (m_oldPaperUnit)
     {
         case Unit::Cm:
         case Unit::Mm:
@@ -1002,7 +977,7 @@ void DialogLayoutSettings::CorrectPaperDecimals()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogLayoutSettings::CorrectLayoutDecimals()
 {
-    switch (oldLayoutUnit)
+    switch (m_oldLayoutUnit)
     {
         case Unit::Cm:
         case Unit::Mm:
@@ -1020,7 +995,7 @@ void DialogLayoutSettings::CorrectLayoutDecimals()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogLayoutSettings::MinimumPaperSize()
 {
-    const qreal value = UnitConvertor(1, Unit::Px, oldPaperUnit);
+    const qreal value = UnitConvertor(1, Unit::Px, m_oldPaperUnit);
     ui->doubleSpinBoxPaperWidth->setMinimum(value);
     ui->doubleSpinBoxPaperHeight->setMinimum(value);
 }
@@ -1028,7 +1003,7 @@ void DialogLayoutSettings::MinimumPaperSize()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogLayoutSettings::MinimumLayoutSize()
 {
-    const qreal value = UnitConvertor(1, Unit::Px, oldLayoutUnit);
+    const qreal value = UnitConvertor(1, Unit::Px, m_oldLayoutUnit);
     ui->doubleSpinBoxLayoutWidth->setMinimum(value);
 }
 
@@ -1092,9 +1067,9 @@ void DialogLayoutSettings::WriteSettings() const
 //---------------------------------------------------------------------------------------------------------------------
 void DialogLayoutSettings::SheetSize(const QSizeF &size)
 {
-    oldPaperUnit = PaperUnit();
-    ui->doubleSpinBoxPaperWidth->setMaximum(FromPixel(QIMAGE_MAX, oldPaperUnit));
-    ui->doubleSpinBoxPaperHeight->setMaximum(FromPixel(QIMAGE_MAX, oldPaperUnit));
+    m_oldPaperUnit = PaperUnit();
+    ui->doubleSpinBoxPaperWidth->setMaximum(FromPixel(QIMAGE_MAX, m_oldPaperUnit));
+    ui->doubleSpinBoxPaperHeight->setMaximum(FromPixel(QIMAGE_MAX, m_oldPaperUnit));
 
     ui->doubleSpinBoxPaperWidth->setValue(size.width());
     ui->doubleSpinBoxPaperHeight->setValue(size.height());
@@ -1112,3 +1087,28 @@ void DialogLayoutSettings::SetAdditionalOptions(bool value)
     SetUnitePages(value);
     SetStripOptimization(value);
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogLayoutSettings::SetMinMargins(const QMarginsF &fields, const QMarginsF &minFields)
+{
+    if (fields.left() < minFields.left())
+    {
+        ui->doubleSpinBoxLeftField->setValue(UnitConvertor(minFields.left(), Unit::Px, LayoutUnit()));
+    }
+
+    if (fields.right() < minFields.right())
+    {
+        ui->doubleSpinBoxRightField->setValue(UnitConvertor(minFields.right(), Unit::Px, LayoutUnit()));
+    }
+
+    if (fields.top() < minFields.top())
+    {
+        ui->doubleSpinBoxTopField->setValue(UnitConvertor(minFields.top(), Unit::Px, LayoutUnit()));
+    }
+
+    if (fields.bottom() < minFields.bottom())
+    {
+        ui->doubleSpinBoxBottomField->setValue(UnitConvertor(minFields.bottom(), Unit::Px,
+                                                             LayoutUnit()));
+    }
+}
