@@ -33,7 +33,7 @@
 #include <QMargins>
 
 #include "../vlayout/dialogs/vabstractlayoutdialog.h"
-#include "../vlayout/vbank.h"
+#include "../vlayout/vlayoutdef.h"
 
 namespace Ui
 {
@@ -44,85 +44,85 @@ class VLayoutGenerator;
 
 class DialogLayoutSettings : public VAbstractLayoutDialog
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 public:
     explicit DialogLayoutSettings(VLayoutGenerator *generator, QWidget *parent = nullptr, bool disableSettings = false);
-    virtual ~DialogLayoutSettings();
+    ~DialogLayoutSettings() override;
 
-    qreal GetPaperHeight() const;
+    auto GetPaperHeight() const -> qreal;
     void SetPaperHeight(qreal value);
 
-    qreal GetPaperWidth() const;
+    auto GetPaperWidth() const -> qreal;
     void SetPaperWidth(qreal value);
 
-    int  GetNestingTime() const;
+    auto GetNestingTime() const -> int;
     void SetNestingTime(int value);
 
-    qreal GetEfficiencyCoefficient() const;
-    void  SetEfficiencyCoefficient(qreal ration);
+    auto GetEfficiencyCoefficient() const -> qreal;
+    void SetEfficiencyCoefficient(qreal ration);
 
-    qreal GetLayoutWidth() const;
+    auto GetLayoutWidth() const -> qreal;
     void SetLayoutWidth(qreal value);
 
-    QMarginsF GetFields() const;
+    auto GetFields() const -> QMarginsF;
     void SetFields(const QMarginsF &value);
 
-    Cases GetGroup() const;
+    auto GetGroup() const -> Cases;
     void SetGroup(const Cases &value);
 
-    bool GetFollowGrainline() const;
+    auto GetFollowGrainline() const -> bool;
     void SetFollowGrainline(bool state);
 
-    bool GetManualPriority() const;
+    auto GetManualPriority() const -> bool;
     void SetManualPriority(bool state);
 
-    bool GetAutoCropLength() const;
+    auto GetAutoCropLength() const -> bool;
     void SetAutoCropLength(bool autoCropLength);
 
-    bool GetAutoCropWidth() const;
+    auto GetAutoCropWidth() const -> bool;
     void SetAutoCropWidth(bool autoCropWidth);
 
-    bool IsSaveLength() const;
+    auto IsSaveLength() const -> bool;
     void SetSaveLength(bool save);
 
-    bool IsPreferOneSheetSolution() const;
+    auto IsPreferOneSheetSolution() const -> bool;
     void SetPreferOneSheetSolution(bool prefer);
 
-    bool IsUnitePages() const;
+    auto IsUnitePages() const -> bool;
     void SetUnitePages(bool save);
 
-    bool IsStripOptimization() const;
+    auto IsStripOptimization() const -> bool;
     void SetStripOptimization(bool save);
 
-    quint8 GetMultiplier() const;
-    void   SetMultiplier(const quint8 &value);
+    auto GetMultiplier() const -> quint8;
+    void SetMultiplier(const quint8 &value);
 
-    bool IsIgnoreAllFields() const;
+    auto IsIgnoreAllFields() const -> bool;
     void SetIgnoreAllFields(bool value);
 
-    bool IsTextAsPaths() const;
+    auto IsTextAsPaths() const -> bool;
     void SetTextAsPaths(bool value);
 
-    bool IsNestQuantity() const;
+    auto IsNestQuantity() const -> bool;
     void SetNestQuantity(bool state);
 
-    QString SelectedPrinter() const;
+    auto SelectedPrinter() const -> QString;
 
     void EnableLandscapeOrientation();
 
     //support functions for the command line parser which uses invisible dialog to properly build layout generator
-    bool SelectTemplate(const PaperSizeTemplate& id);
-    static QString MakeHelpTemplateList();
-    static QString MakeHelpTiledPdfTemplateList();
-    bool SelectPaperUnit(const QString& units);
-    bool SelectLayoutUnit(const QString& units);
-    qreal LayoutToPixels(qreal value) const;
-    qreal PageToPixels(qreal value) const;
-    static QString MakeGroupsHelp();
+    auto SelectTemplate(const PaperSizeTemplate& id) -> bool;
+    static auto MakeHelpTemplateList() -> QString;
+    static auto MakeHelpTiledPdfTemplateList() -> QString;
+    auto SelectPaperUnit(const QString& units) -> bool;
+    auto SelectLayoutUnit(const QString& units) -> bool;
+    auto LayoutToPixels(qreal value) const -> qreal;
+    auto PageToPixels(qreal value) const -> qreal;
+    static auto MakeGroupsHelp() -> QString;
 protected:
     void showEvent(QShowEvent *event) override;
     void resizeEvent(QResizeEvent *event) override;
-    QSizeF GetTemplateSize(const PaperSizeTemplate &tmpl, const Unit &unit) const;
+    auto GetTemplateSize(const PaperSizeTemplate &tmpl, const Unit &unit) const -> QSizeF;
 
 public slots:
     void DialogAccepted();
@@ -139,26 +139,27 @@ private slots:
     void CorrectMaxFileds();
     void IgnoreAllFields(int state);
 private:
-    Q_DISABLE_COPY(DialogLayoutSettings)
+    // cppcheck-suppress unknownMacro
+    Q_DISABLE_COPY_MOVE(DialogLayoutSettings) // NOLINT
 
-    bool disableSettings;
+    bool m_disableSettings;
 
     Ui::DialogLayoutSettings *ui;
-    Unit oldPaperUnit;
-    Unit oldLayoutUnit;
-    VLayoutGenerator *generator;
-    bool isInitialized;
+    Unit m_oldPaperUnit;
+    Unit m_oldLayoutUnit;
+    VLayoutGenerator *m_generator;
+    bool m_isInitialized;
 
     void InitPaperUnits();
     void InitLayoutUnits();
     void InitPrinter();
-    QSizeF Template();
+    auto Template() -> QSizeF;
 
-    QMarginsF MinPrinterFields() const;
-    QMarginsF GetDefPrinterFields() const;
+    auto MinPrinterFields() const -> QMarginsF;
+    auto GetDefPrinterFields() const -> QMarginsF;
 
-    Unit PaperUnit() const;
-    Unit LayoutUnit() const;
+    auto PaperUnit() const -> Unit;
+    auto LayoutUnit() const -> Unit;
 
     void CorrectPaperDecimals();
     void CorrectLayoutDecimals();
@@ -171,6 +172,8 @@ private:
 
     void SheetSize(const QSizeF &size);
     void SetAdditionalOptions(bool value);
+
+    void SetMinMargins(const QMarginsF &fields, const QMarginsF &minFields);
 };
 
 #endif // DIALOGLAYOUTSETTINGS_H
