@@ -43,6 +43,9 @@
 #include "../vtools/undocommands/image/resetbackgroundimage.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/lambdaconstants.h"
+#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
+#include "../vmisc/backport/qoverload.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
 
 #include <QMenu>
 #include <QPushButton>
