@@ -37,18 +37,30 @@
 #include <QMenu>
 #include <QTimer>
 #include <QUndoStack>
+#include <chrono>
+
+#if (defined(Q_CC_GNU) && Q_CC_GNU < 409) && !defined(Q_CC_CLANG)
+// DO NOT WORK WITH GCC 4.8
+#else
+#if __cplusplus >= 201402L
+using namespace std::chrono_literals;
+#else
+#include "../vmisc/bpstd/chrono.hpp"
+using namespace bpstd::literals::chrono_literals;
+#endif // __cplusplus >= 201402L
+#endif //(defined(Q_CC_GNU) && Q_CC_GNU < 409) && !defined(Q_CC_CLANG)
 
 namespace
 {
-    enum PieceColumn
-    {
-        InLayout = 0,
-        PieceName = 1
-    };
+enum PieceColumn
+{
+    InLayout = 0,
+    PieceName = 1
+};
 
-    Q_GLOBAL_STATIC_WITH_ARGS(const QString, allowDetailIcon, (QLatin1String("://icon/16x16/allow_detail.png")))
-    Q_GLOBAL_STATIC_WITH_ARGS(const QString, forbidDetailIcon, (QLatin1String("://icon/16x16/forbid_detail.png")))
-}
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, allowDetailIcon, (QLatin1String("://icon/16x16/allow_detail.png"))) // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, forbidDetailIcon, (QLatin1String("://icon/16x16/forbid_detail.png"))) // NOLINT
+}  // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 VWidgetDetails::VWidgetDetails(VContainer *data, VAbstractPattern *doc, QWidget *parent)
@@ -88,7 +100,7 @@ void VWidgetDetails::UpdateList()
     // The filling table is a very expensive operation. This optimization will postpone it.
     // Each time a new request happen we will wait 800 ms before calling it. If at this time a new request will arrive
     // we will wait 800 ms more. And so on, until nothing happens within 800ms.
-    m_updateListTimer->start(800);
+    m_updateListTimer->start(V_MSECONDS(800));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -123,6 +135,17 @@ void VWidgetDetails::ToggledPiece(quint32 id)
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VWidgetDetails::changeEvent(QEvent *event)
+{
+    if (event->type() == QEvent::LanguageChange)
+    {
+        ui->retranslateUi(this);
+    }
+    // remember to call base class implementation
+    QWidget::changeEvent(event);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void VWidgetDetails::InLayoutStateChanged(int row, int column)
 {
@@ -138,7 +161,7 @@ void VWidgetDetails::InLayoutStateChanged(int row, int column)
     const QHash<quint32, VPiece> *allDetails = m_data->DataPieces();
     const bool inLayout = not allDetails->value(id).IsInLayout();
 
-    TogglePieceInLayout *togglePrint = new TogglePieceInLayout(id, inLayout, m_data, m_doc);
+    auto *togglePrint = new TogglePieceInLayout(id, inLayout, m_data, m_doc);
     connect(togglePrint, &TogglePieceInLayout::Toggled, this, &VWidgetDetails::ToggledPiece);
     VAbstractApplication::VApp()->getUndoStack()->push(togglePrint);
 }
@@ -187,7 +210,7 @@ void VWidgetDetails::ToggleSectionDetails(bool select)
         {
             if (not (select == allDetails->value(id).IsInLayout()))
             {
-                TogglePieceInLayout *togglePrint = new TogglePieceInLayout(id, select, m_data, m_doc);
+                auto *togglePrint = new TogglePieceInLayout(id, select, m_data, m_doc);
                 connect(togglePrint, &TogglePieceInLayout::Toggled, this, &VWidgetDetails::ToggledPiece);
                 VAbstractApplication::VApp()->getUndoStack()->push(togglePrint);
             }
@@ -223,9 +246,9 @@ void VWidgetDetails::ToggledPieceItem(QTableWidgetItem *item)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QTableWidgetItem *VWidgetDetails::PrepareInLayoutColumnCell(const VPiece &det, quint32 id) const
+auto VWidgetDetails::PrepareInLayoutColumnCell(const VPiece &det, quint32 id) -> QTableWidgetItem *
 {
-    QTableWidgetItem *item = new QTableWidgetItem();
+    auto *item = new QTableWidgetItem();
     item->setTextAlignment(Qt::AlignHCenter);
     item->setIcon(det.IsInLayout() ? QIcon(*allowDetailIcon) : QIcon(*forbidDetailIcon));
     item->setData(Qt::UserRole, id);
@@ -238,7 +261,7 @@ QTableWidgetItem *VWidgetDetails::PrepareInLayoutColumnCell(const VPiece &det, q
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QTableWidgetItem *VWidgetDetails::PreparePieceNameColumnCell(const VPiece &det) const
+auto VWidgetDetails::PreparePieceNameColumnCell(const VPiece &det) -> QTableWidgetItem *
 {
     QString name = det.GetName();
     if (name.isEmpty())
@@ -246,7 +269,7 @@ QTableWidgetItem *VWidgetDetails::PreparePieceNameColumnCell(const VPiece &det)
         name = tr("Unnamed");
     }
 
-    QTableWidgetItem *item = new QTableWidgetItem(name);
+    auto *item = new QTableWidgetItem(name);
     item->setTextAlignment(Qt::AlignLeft | Qt::AlignVCenter);
 
     // set the item non-editable (view only), and non-selectable
@@ -357,7 +380,7 @@ void VWidgetDetails::ShowContextMenu(const QPoint &pos)
             {
                 select = not allDetails->value(id).IsInLayout();
 
-                TogglePieceInLayout *togglePrint = new TogglePieceInLayout(id, select, m_data, m_doc);
+                auto *togglePrint = new TogglePieceInLayout(id, select, m_data, m_doc);
                 connect(togglePrint, &TogglePieceInLayout::Toggled, this, &VWidgetDetails::ToggledPiece);
                 VAbstractApplication::VApp()->getUndoStack()->push(togglePrint);
             }
