@@ -45,7 +45,7 @@
 
 //---------------------------------------------------------------------------------------------------------------------
 
-int main(int argc, char *argv[])
+auto main(int argc, char *argv[]) -> int
 {
 #if defined(APPIMAGE) && defined(Q_OS_LINUX)
     /* Fix path to ICU_DATA when run AppImage.*/
@@ -53,16 +53,16 @@ int main(int argc, char *argv[])
     auto FreeMemory = qScopeGuard([exe_dir] {free(exe_dir);});
 #endif // defined(APPIMAGE) && defined(Q_OS_LINUX)
 
-    Q_INIT_RESOURCE(cursor);
-    Q_INIT_RESOURCE(icon);
-    Q_INIT_RESOURCE(schema);
-    Q_INIT_RESOURCE(theme);
-    Q_INIT_RESOURCE(flags);
-    Q_INIT_RESOURCE(icons);
-    Q_INIT_RESOURCE(toolicon);
-    Q_INIT_RESOURCE(style);
+    Q_INIT_RESOURCE(cursor); // NOLINT
+    Q_INIT_RESOURCE(icon); // NOLINT
+    Q_INIT_RESOURCE(schema); // NOLINT
+    Q_INIT_RESOURCE(theme); // NOLINT
+    Q_INIT_RESOURCE(flags); // NOLINT
+    Q_INIT_RESOURCE(icons); // NOLINT
+    Q_INIT_RESOURCE(toolicon); // NOLINT
+    Q_INIT_RESOURCE(style); // NOLINT
 
-    QT_REQUIRE_VERSION(argc, argv, "5.4.0")// clazy:exclude=qstring-arg,qstring-allocations
+    QT_REQUIRE_VERSION(argc, argv, "5.4.0")// clazy:exclude=qstring-arg,qstring-allocations NOLINT
 
 #if defined(Q_OS_WIN)
     VAbstractApplication::WinAttachConsole();
@@ -112,5 +112,5 @@ int main(int argc, char *argv[])
     }
 #endif // defined(APPIMAGE) && defined(Q_OS_LINUX)
 
-    return app.exec();
+    return VApplication::exec();
 }
