@@ -65,19 +65,19 @@ class VWidgetBackgroundImages;
  */
 class MainWindow : public MainWindowsNoGUI
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 public:
     explicit MainWindow(QWidget *parent = nullptr);
-    virtual ~MainWindow() override;
+    ~MainWindow() override;
 
-    bool LoadPattern(QString fileName, const QString &customMeasureFile = QString());
+    auto LoadPattern(QString fileName, const QString &customMeasureFile = QString()) -> bool;
 
 public slots:
     void ProcessCMD();
-    virtual void ShowToolTip(const QString &toolTip) override;
-    virtual void UpdateVisibilityGroups() override;
-    virtual void UpdateDetailsList() override;
-    virtual void ZoomFitBestCurrent() override;
+    void ShowToolTip(const QString &toolTip) override;
+    void UpdateVisibilityGroups() override;
+    void UpdateDetailsList() override;
+    void ZoomFitBestCurrent() override;
     void PlaceBackgroundImage(const QPointF &pos, const QString &fileName);
     void RemoveBackgroundImage(const QUuid &id);
 
@@ -110,16 +110,15 @@ signals:
     void EnableDetailHover(bool enable);
     void EnableImageBackgroundHover(bool enable);
 protected:
-    virtual void keyPressEvent(QKeyEvent *event) override;
-    virtual void showEvent(QShowEvent *event) override;
-    virtual void changeEvent(QEvent* event) override;
-    virtual void closeEvent(QCloseEvent *event) override;
-    virtual void customEvent(QEvent * event) override;
-    virtual void CleanLayout() override;
-    virtual void PrepareSceneList(PreviewQuatilty quality) override;
-    virtual void ExportToCSVData(const QString &fileName, bool withHeader, int mib,
-                                 const QChar &separator) final;
-    virtual void ToolBarStyle(QToolBar *bar) const override;
+    void keyPressEvent(QKeyEvent *event) override;
+    void showEvent(QShowEvent *event) override;
+    void changeEvent(QEvent* event) override;
+    void closeEvent(QCloseEvent *event) override;
+    void customEvent(QEvent * event) override;
+    void CleanLayout() override;
+    void PrepareSceneList(PreviewQuatilty quality) override;
+    void ExportToCSVData(const QString &fileName, bool withHeader, int mib, const QChar &separator) final;
+    void ToolBarStyle(QToolBar *bar) const override;
 private slots:
     void ScaleChanged(qreal scale);
     void MouseMove(const QPointF &scenePos);
@@ -192,8 +191,8 @@ private slots:
     void ActionLayout(bool checked);
 
     void on_actionNew_triggered();
-    bool on_actionSaveAs_triggered();
-    bool on_actionSave_triggered();
+    bool on_actionSaveAs_triggered(); // NOLINT(modernize-use-trailing-return-type)
+    bool on_actionSave_triggered(); // NOLINT(modernize-use-trailing-return-type)
     void on_actionOpen_triggered();
 
     void on_actionOpenPuzzle_triggered();
@@ -243,72 +242,81 @@ private slots:
 
     void ParseBackgroundImages();
 
-private:
-    Q_DISABLE_COPY(MainWindow)
-    /** @brief ui keeps information about user interface */
-    Ui::MainWindow     *ui;
+    void ActionHistory_triggered(bool checked);
+    void ActionExportRecipe_triggered();
+    void ActionNewDraw_triggered();
+    void ActionTable_triggered();
+    void ActionFinalMeasurements_triggered();
+    void ActionShowMainPath_triggered(bool checked);
+    void ActionOpenTape_triggered();
 
-    QFileSystemWatcher *watcher;
+private:
+    // cppcheck-suppress unknownMacro
+    Q_DISABLE_COPY_MOVE(MainWindow) // NOLINT
+    /** @brief ui keeps information about user interface */
+    Ui::MainWindow *ui;
+
+    QFileSystemWatcher *m_watcher;
 
     /** @brief tool current tool */
-    Tool               currentTool;
+    Tool m_currentTool{Tool::Arrow};
 
     /** @brief tool last used tool */
-    Tool               lastUsedTool;
+    Tool m_lastUsedTool{Tool::Arrow};
 
     /** @brief sceneDraw draw scene. */
-    VMainGraphicsScene *sceneDraw;
+    VMainGraphicsScene *m_sceneDraw{nullptr};
 
     /** @brief sceneDetails details scene. */
-    VMainGraphicsScene *sceneDetails;
+    VMainGraphicsScene *m_sceneDetails{nullptr};
 
     /** @brief isInitialized true after first show window. */
-    bool               isInitialized;
+    bool m_isInitialized{false};
 
     /** @brief mChanges true if measurement file was changed. */
-    bool               mChanges;
-    bool               mChangesAsked;
+    bool m_mChanges{false};
+    bool m_mChangesAsked{true};
 
-    bool               patternReadOnly;
+    bool m_patternReadOnly{false};
 
-    QPointer<DialogIncrements>        dialogTable;
-    QPointer<DialogTool>              dialogTool;
-    QPointer<DialogHistory>           dialogHistory;
-    QPointer<DialogFinalMeasurements> dialogFMeasurements;
+    QPointer<DialogIncrements>        m_dialogTable;
+    QPointer<DialogTool>              m_dialogTool{};
+    QPointer<DialogHistory>           m_dialogHistory;
+    QPointer<DialogFinalMeasurements> m_dialogFMeasurements;
 
     /** @brief comboBoxDraws comboc who show name of pattern peaces. */
-    QComboBox          *comboBoxDraws;
-    QLabel             *patternPieceLabel;
+    QComboBox *m_comboBoxDraws{nullptr};
+    QLabel    *m_patternPieceLabel{nullptr};
 
     /** @brief currentDrawIndex save current selected pattern peace. */
-    qint32             currentDrawIndex;
+    qint32 m_currentDrawIndex{0};
 
     /** @brief currentToolBoxIndex save current set of tools. */
-    qint32             currentToolBoxIndex;
+    qint32 m_currentToolBoxIndex{0};
 
     /** @brief drawMode true if we current draw scene. */
-    bool               drawMode;
+    bool m_drawMode{true};
 
-    QLabel             *leftGoToStage;
-    QLabel             *rightGoToStage;
-    QTimer             *autoSaveTimer;
-    QTimer             *measurementsSyncTimer;
-    bool               guiEnabled;
-    QPointer<QComboBox> dimensionA{nullptr};
-    QPointer<QComboBox> dimensionB{nullptr};
-    QPointer<QComboBox> dimensionC{nullptr};
-    QPointer<QLabel>   dimensionALabel{nullptr};
-    QPointer<QLabel>   dimensionBLabel{nullptr};
-    QPointer<QLabel>   dimensionCLabel{nullptr};
-    QPointer<QLabel>   zoomScale{nullptr};
-    QPointer<QDoubleSpinBox> doubleSpinBoxScale{nullptr};
-    VToolOptionsPropertyBrowser *toolOptions;
-    VWidgetGroups *groupsWidget;
-    VWidgetDetails *detailsWidget;
-    VWidgetBackgroundImages *backgroundImagesWidget{nullptr};
-    QSharedPointer<VLockGuard<char>> lock;
+    QLabel *m_leftGoToStage{nullptr};
+    QLabel *m_rightGoToStage{nullptr};
+    QTimer *m_autoSaveTimer{nullptr};
+    QTimer *m_measurementsSyncTimer;
+    bool m_guiEnabled{true};
+    QPointer<QComboBox> m_dimensionA{nullptr};
+    QPointer<QComboBox> m_dimensionB{nullptr};
+    QPointer<QComboBox> m_dimensionC{nullptr};
+    QPointer<QLabel> m_dimensionALabel{nullptr};
+    QPointer<QLabel> m_dimensionBLabel{nullptr};
+    QPointer<QLabel> m_dimensionCLabel{nullptr};
+    QPointer<QLabel> m_zoomScale{nullptr};
+    QPointer<QDoubleSpinBox> m_doubleSpinBoxScale{nullptr};
+    VToolOptionsPropertyBrowser *m_toolOptions{nullptr};
+    VWidgetGroups *m_groupsWidget{nullptr};
+    VWidgetDetails *m_detailsWidget{nullptr};
+    VWidgetBackgroundImages *m_backgroundImagesWidget{nullptr};
+    QSharedPointer<VLockGuard<char>> m_lock{nullptr};
 
-    QList<QToolButton*> toolButtonPointerList;
+    QList<QToolButton*> m_toolButtonPointerList{};
 
     QProgressBar *m_progressBar;
     QLabel       *m_statusLabel;
@@ -319,7 +327,7 @@ private:
     qreal m_currentDimensionB{0};
     qreal m_currentDimensionC{0};
 
-    QSharedPointer<VMeasurements> m{};
+    QSharedPointer<VMeasurements> m_m{};
 
     QTimer *m_gradation;
 
@@ -333,30 +341,33 @@ private:
 
     void InitDimensionControls();
     void InitDimensionGradation(int index, const MeasurementDimension_p &dimension, const QPointer<QComboBox> &control);
+    static void InitDimensionXGradation(const QVector<qreal> &bases, const DimesionLabels &labels,
+                                        const QPointer<QComboBox> &control);
+    void InitDimensionYWZGradation(const QVector<qreal> &bases, const DimesionLabels &labels,
+                                   const QPointer<QComboBox> &control, bool bodyMeasurement);
 
-    void               ToolBarOption();
-    void               ToolBarStages();
-    void               ToolBarDraws();
-    void               ToolBarTools();
-    void               InitToolButtons();
-    void               CancelTool();
+    void ToolBarOption();
+    void ToolBarStages();
+    void ToolBarDraws();
+    void ToolBarTools();
+    void InitToolButtons();
+    void CancelTool();
 
-    void               SetEnableWidgets(bool enable);
-    void               SetEnableTool(bool enable);
-    void               SetLayoutModeActions();
+    void SetEnableWidgets(bool enable);
+    void SetEnableTool(bool enable);
+    void SetLayoutModeActions();
 
-    void               SaveCurrentScene();
-    void               RestoreCurrentScene();
-    void               MinimumScrollBar();
+    void SaveCurrentScene();
+    void RestoreCurrentScene();
+    void MinimumScrollBar();
 
     template <typename Dialog, typename Func>
-    void               SetToolButton(bool checked, Tool t, const QString &cursor, const QString &toolTip,
-                                     Func closeDialogSlot);
+    void SetToolButton(bool checked, Tool t, const QString &cursor, const QString &toolTip, Func closeDialogSlot);
     template <typename Dialog, typename Func, typename Func2>
-    void               SetToolButtonWithApply(bool checked, Tool t, const QString &cursor, const QString &toolTip,
-                                              Func closeDialogSlot, Func2 applyDialogSlot);
+    void SetToolButtonWithApply(bool checked, Tool t, const QString &cursor, const QString &toolTip,
+                                Func closeDialogSlot, Func2 applyDialogSlot);
     template <typename DrawTool>
-    void               ClosedDialog(int result);
+    void ClosedDialog(int result);
 
     template <typename DrawTool>
     void ClosedDialogWithApply(int result, VMainGraphicsScene *scene);
@@ -371,54 +382,55 @@ private:
     template <typename DrawTool>
     void ApplyDetailsDialog();
 
-    bool               SavePattern(const QString &fileName, QString &error);
-    void               AutoSavePattern();
-    void               setCurrentFile(const QString &fileName);
+    auto SavePattern(const QString &fileName, QString &error) -> bool;
+    void AutoSavePattern();
+    void setCurrentFile(const QString &fileName);
 
-    void               ReadSettings();
-    void               WriteSettings();
+    void ReadSettings();
+    void WriteSettings();
 
-    bool               MaybeSave();
-    void               CreateMenus();
-    void               CreateActions();
-    void               InitAutoSave();
-    bool               PatternPieceName(QString &name);
-    QString            CheckPathToMeasurements(const QString &patternPath, const QString &path);
-    void               ChangePP(int index, bool zoomBestFit = true);
+    auto MaybeSave() -> bool;
+    void CreateMenus();
+    void CreateActions();
+    void InitAutoSave();
+    auto PatternPieceName(QString &name) -> bool;
+    auto CheckPathToMeasurements(const QString &patternPath, const QString &path) -> QString;
+    void ChangePP(int index, bool zoomBestFit = true);
     /**
      * @brief EndVisualization try show dialog after and working with tool visualization.
      */
-    void               EndVisualization(bool click = false);
-    void               ZoomFirstShow();
+    void EndVisualization(bool click = false);
+    void ZoomFirstShow();
 
-    void               AddDocks();
-    void               InitDocksContain();
-    bool               OpenNewValentina(const QString &fileName = QString())const;
-    void               FileClosedCorrect();
-    QStringList        GetUnlokedRestoreFileList()const;
+    void AddDocks();
+    void InitDocksContain();
+    auto OpenNewValentina(const QString &fileName = QString())const -> bool;
+    void FileClosedCorrect();
+    static auto GetUnlokedRestoreFileList() -> QStringList;
 
-    void               AddPP(const QString &PPName);
-    QPointF            StartPositionNewPP() const;
+    void AddPP(const QString &PPName);
+    auto StartPositionNewPP() const -> QPointF;
 
-    void               InitScenes();
+    void InitScenes();
 
-    bool               LoadMeasurements(const QString &path);
-    bool               UpdateMeasurements(const QString &path, qreal baseA, qreal baseB, qreal baseC);
-    bool               UpdateMeasurements(const QSharedPointer<VMeasurements> &mFile, qreal baseA, qreal baseB,
-                                          qreal baseC);
+    auto LoadMeasurements(const QString &path) -> bool;
+    auto UpdateMeasurements(const QString &path, qreal baseA, qreal baseB, qreal baseC) -> bool;
+    auto UpdateMeasurements(const QSharedPointer<VMeasurements> &mFile, qreal baseA, qreal baseB, qreal baseC) -> bool;
 
-    void               ReopenFilesAfterCrash(QStringList &args);
-    bool               DoExport(const VCommandLinePtr& expParams);
-    bool               DoFMExport(const VCommandLinePtr& expParams);
+    void ReadMeasurements(qreal baseA, qreal baseB, qreal baseC);
 
-    bool               SetDimensionA(int value);
-    bool               SetDimensionB(int value);
-    bool               SetDimensionC(int value);
+    void ReopenFilesAfterCrash(QStringList &args);
+    auto DoExport(const VCommandLinePtr& expParams) -> bool;
+    auto DoFMExport(const VCommandLinePtr& expParams) -> bool;
 
-    QString            GetPatternFileName();
-    QString            GetMeasurementFileName();
+    auto SetDimensionA(int value) -> bool;
+    auto SetDimensionB(int value) -> bool;
+    auto SetDimensionC(int value) -> bool;
 
-    void               UpdateWindowTitle();
+    static auto GetPatternFileName() -> QString;
+    auto GetMeasurementFileName() -> QString;
+
+    void UpdateWindowTitle();
 
     void ToolSelectPoint();
     void ToolSelectPointByPress();
@@ -441,7 +453,10 @@ private:
     void StoreMultisizeMDimensions();
     void StoreIndividualMDimensions();
 
-    QVector<qreal> DimensionRestrictedValues(int index, const MeasurementDimension_p &dimension);
+    void StoreMultisizeMDimension(const QList<MeasurementDimension_p> &dimensions, int index, qreal currentBase);
+    void StoreIndividualMDimension(const QMap<QString, QSharedPointer<VMeasurement> > &measurements, IMD type);
+
+    auto DimensionRestrictedValues(int index, const MeasurementDimension_p &dimension) -> QVector<qreal>;
     void SetDimensionBases();
 
     void StoreDimensions();
@@ -450,6 +465,10 @@ private:
 
     void NewBackgroundImageItem(const VBackgroundPatternImage &image);
     auto InitBackgroundImageItem(const VBackgroundPatternImage &image) -> VBackgroundImageItem *;
+
+    auto SavePatternAs(const QString &fileName) -> bool;
+
+    auto FullParsePattern() -> bool;
 };
 
 #endif // MAINWINDOW_H
