@@ -33,7 +33,13 @@
 
 #include "../ifcdef.h"
 
-//Q_LOGGING_CATEGORY(vExcep, "v.excep") //Commented because don't use now
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_CLANG("-Wmissing-prototypes")
+QT_WARNING_DISABLE_INTEL(1418)
+
+//Q_LOGGING_CATEGORY(vExcep, "v.excep") // NOLINT //Commented because don't use now
+
+QT_WARNING_POP
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
