@@ -46,7 +46,7 @@ class VAbstractConverter :public VDomDocument
 {
 public:
     explicit VAbstractConverter(const QString &fileName);
-    virtual ~VAbstractConverter() Q_DECL_EQ_DEFAULT;
+    virtual ~VAbstractConverter() = default;
 
     QString Convert();
 
@@ -81,7 +81,7 @@ protected:
     void ValidateXML(const QString &schema) const;
 
 private:
-    Q_DISABLE_COPY(VAbstractConverter)
+    Q_DISABLE_COPY_MOVE(VAbstractConverter) // NOLINT
 
     QTemporaryFile m_tmpFile{};
 
