@@ -41,7 +41,7 @@ class VAbstractMConverter : public VAbstractConverter
 {
 public:
     explicit VAbstractMConverter(const QString &fileName);
-    virtual ~VAbstractMConverter() Q_DECL_EQ_DEFAULT;
+    virtual ~VAbstractMConverter() = default;
 
     auto Units() const -> Unit;
 
@@ -51,7 +51,7 @@ protected:
     static QMap<QString, QString> OldNamesToNewNames_InV0_3_3();
 
 private:
-    Q_DISABLE_COPY(VAbstractMConverter)
+    Q_DISABLE_COPY_MOVE(VAbstractMConverter) // NOLINT
 };
 
 #endif // VABSTRACTMCONVERTER_H
