@@ -97,7 +97,7 @@ QT_WARNING_DISABLE_GCC("-Wsuggest-final-types")
 
 class VAbstractPattern : public VDomDocument
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 public:
     explicit VAbstractPattern(QObject *parent = nullptr);
     virtual ~VAbstractPattern();
@@ -233,6 +233,15 @@ public:
     QStringList    GetGroupTags(vidtype id);
     void           SetGroupTags(quint32 id, const QStringList &tags);
 
+    auto GetDimensionAValue() -> double;
+    void SetDimensionAValue(double value);
+
+    auto GetDimensionBValue() -> double;
+    void SetDimensionBValue(double value);
+
+    auto GetDimensionCValue() -> double;
+    void SetDimensionCValue(double value);
+
     QStringList GetGroupCategories() const;
 
     QMap<quint32, VGroupData> GetGroups(const QString &patternPieceName = QString());
@@ -332,11 +341,15 @@ public:
     static const QString AttrHold;
     static const QString AttrZValue;
     static const QString AttrImageId;
+    static const QString AttrDimensionA;
+    static const QString AttrDimensionB;
+    static const QString AttrDimensionC;
 
     static const QString AttrContentType;
 
     static const QString AttrFormula;
     static const QString AttrDescription;
+    static const QString AttrSpecialUnits;
 
     static const QString NodeArc;
     static const QString NodeElArc;
@@ -472,7 +485,7 @@ protected:
     auto ReadCompanyName() const -> QString;
 
 private:
-    Q_DISABLE_COPY(VAbstractPattern)
+    Q_DISABLE_COPY_MOVE(VAbstractPattern) // NOLINT
 
     QStringList ListIncrements() const;
     QVector<VFormulaField> ListPointExpressions() const;
