@@ -234,7 +234,13 @@ bool LessThen(const QDomNode &element1, const QDomNode &element2)
 }
 }  // namespace
 
-Q_LOGGING_CATEGORY(vXML, "v.xml")
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_CLANG("-Wmissing-prototypes")
+QT_WARNING_DISABLE_INTEL(1418)
+
+Q_LOGGING_CATEGORY(vXML, "v.xml") // NOLINT
+
+QT_WARNING_POP
 
 const QString VDomDocument::AttrId          = QStringLiteral("id");
 const QString VDomDocument::AttrText        = QStringLiteral("text");
@@ -635,33 +641,20 @@ quint32 VDomDocument::GetParametrId(const QDomElement &domElement)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VDomDocument::UniqueTagText(const QString &tagName, const QString &defVal) const
+auto VDomDocument::UniqueTagText(const QString &tagName, const QString &defVal) const -> QString
 {
-    const QDomNodeList nodeList = this->elementsByTagName(tagName);
-    if (nodeList.isEmpty())
+    QDomElement domElement = UniqueTag(tagName);
+    if (not domElement.isNull())
     {
-        return defVal;
-    }
-    else
-    {
-        const QDomNode domNode = nodeList.at(0);
-        if (domNode.isNull() == false && domNode.isElement())
+        const QString text = domElement.text();
+        if (text.isEmpty())
         {
-            const QDomElement domElement = domNode.toElement();
-            if (domElement.isNull() == false)
-            {
-                const QString text = domElement.text();
-                if (text.isEmpty())
-                {
-                    return defVal;
-                }
-                else
-                {
-                    return text;
-                }
-            }
+            return defVal;
         }
+
+        return text;
     }
+
     return defVal;
 }
 
@@ -724,7 +717,6 @@ void VDomDocument::CacheRefreshed()
 void VDomDocument::setXMLContent(const QString &fileName)
 {
     QFile file(fileName);
-    // cppcheck-suppress ConfigurationNotChecked
     if (file.open(QIODevice::ReadOnly) == false)
     {
         const QString errorMsg(tr("Can't open file %1:\n%2.").arg(fileName, file.errorString()));
@@ -779,7 +771,6 @@ bool VDomDocument::SaveDocument(const QString &fileName, QString &error)
     }
     bool success = false;
     QSaveFile file(fileName);
-    // cppcheck-suppress ConfigurationNotChecked
     if (file.open(QIODevice::WriteOnly))
     {
         // See issue #666. QDomDocument produces random attribute order.
@@ -940,6 +931,27 @@ auto VDomDocument::setTagText(QDomElement &domElement, const QString &text) -> b
     return false;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+QDomElement VDomDocument::UniqueTag(const QString &tagName) const
+{
+    const QDomNodeList nodeList = this->elementsByTagName(tagName);
+    if (nodeList.isEmpty())
+    {
+        return {};
+    }
+
+    const QDomNode domNode = nodeList.at(0);
+    if (not domNode.isNull() && domNode.isElement())
+    {
+        const QDomElement domElement = domNode.toElement();
+        if (not domElement.isNull())
+        {
+            return domElement;
+        }
+    }
+    return {};
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief RemoveAllChildren remove all children from file.
@@ -992,7 +1004,6 @@ bool VDomDocument::SafeCopy(const QString &source, const QString &destination, Q
 
     QTemporaryFile destFile(destination + QLatin1String(".XXXXXX"));
     destFile.setAutoRemove(false);// Will be renamed to be destination file
-    // cppcheck-suppress ConfigurationNotChecked
     if (not destFile.open())
     {
         error = destFile.errorString();
@@ -1000,7 +1011,6 @@ bool VDomDocument::SafeCopy(const QString &source, const QString &destination, Q
     else
     {
         QFile sourceFile(source);
-        // cppcheck-suppress ConfigurationNotChecked
         if (sourceFile.open(QIODevice::ReadOnly))
         {
             result = true;
