@@ -46,7 +46,9 @@
 
 #include "../ifc/ifcdef.h"
 #include "../vmisc/def.h"
+#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #include "../vmisc/diagnostic.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #include "../vmisc/literals.h"
 
 class QDomElement;
@@ -83,7 +85,7 @@ QT_WARNING_DISABLE_GCC("-Wnon-virtual-dtor")
  */
 class VDomDocument : public QObject, public QDomDocument
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 public:
     static const QString AttrId;
     static const QString AttrText;
@@ -151,6 +153,7 @@ public:
 protected:
     bool           setTagText(const QString &tag, const QString &text);
     bool           setTagText(QDomElement &domElement, const QString &text);
+    QDomElement    UniqueTag(const QString &tagName) const;
     QString        UniqueTagText(const QString &tagName, const QString &defVal = QString()) const;
     void           CollectId(const QDomElement &node, QVector<quint32> &vector)const;
 
@@ -160,7 +163,8 @@ private slots:
     void CacheRefreshed();
 
 private:
-    Q_DISABLE_COPY(VDomDocument)
+    // cppcheck-suppress unknownMacro
+    Q_DISABLE_COPY_MOVE(VDomDocument) // NOLINT
     /** @brief Map used for finding element by id. */
     QHash<quint32, QDomElement>  m_elementIdCache;
     QFutureWatcher<QHash<quint32, QDomElement>> *m_watcher;
