@@ -35,7 +35,7 @@ class VLabelTemplateConverter : public VAbstractConverter
 {
 public:
     explicit VLabelTemplateConverter(const QString &fileName);
-    virtual ~VLabelTemplateConverter() Q_DECL_EQ_DEFAULT;
+    virtual ~VLabelTemplateConverter() = default;
 
     static const QString LabelTemplateMaxVerStr;
     static const QString CurrentSchema;
@@ -56,7 +56,7 @@ protected:
     virtual bool IsReadOnly() const override {return false;}
 
 private:
-    Q_DISABLE_COPY(VLabelTemplateConverter)
+    Q_DISABLE_COPY_MOVE(VLabelTemplateConverter) // NOLINT
     static const QString LabelTemplateMinVerStr;
 };
 
