@@ -41,10 +41,10 @@ class QDomElement;
 
 class VVITConverter final : public VAbstractMConverter
 {
-    Q_DECLARE_TR_FUNCTIONS(VVITConverter)
+    Q_DECLARE_TR_FUNCTIONS(VVITConverter) // NOLINT
 public:
     explicit VVITConverter(const QString &fileName);
-    virtual ~VVITConverter() Q_DECL_EQ_DEFAULT;
+    virtual ~VVITConverter() = default;
 
     static const QString MeasurementMaxVerStr;
     static const QString CurrentSchema;
@@ -64,7 +64,7 @@ protected:
     virtual bool    IsReadOnly() const override;
 
 private:
-    Q_DISABLE_COPY(VVITConverter)
+    Q_DISABLE_COPY_MOVE(VVITConverter) // NOLINT
     static const QString MeasurementMinVerStr;
 
     void AddNewTagsForV0_3_0();
