@@ -41,15 +41,15 @@ class QDomElement;
 
 class VVSTConverter final : public VAbstractMConverter
 {
-    Q_DECLARE_TR_FUNCTIONS(VVSTConverter)
+    Q_DECLARE_TR_FUNCTIONS(VVSTConverter) // NOLINT
 public:
     explicit VVSTConverter(const QString &fileName);
-    virtual ~VVSTConverter() Q_DECL_EQ_DEFAULT;
+    virtual ~VVSTConverter() = default;
 
     static const QString MeasurementMaxVerStr;
     static const QString CurrentSchema;
     static Q_DECL_CONSTEXPR const unsigned MeasurementMinVer = FormatVersion(0, 3, 0);
-    static Q_DECL_CONSTEXPR const unsigned MeasurementMaxVer = FormatVersion(0, 5, 3);
+    static Q_DECL_CONSTEXPR const unsigned MeasurementMaxVer = FormatVersion(0, 5, 4);
 
 protected:
     virtual unsigned MinVer() const override;
@@ -64,7 +64,7 @@ protected:
     virtual bool    IsReadOnly() const override;
 
 private:
-    Q_DISABLE_COPY(VVSTConverter)
+    Q_DISABLE_COPY_MOVE(VVSTConverter) // NOLINT
     static const QString MeasurementMinVerStr;
 
     void AddNewTagsForV0_4_0();
@@ -78,11 +78,13 @@ private:
     void RemoveTagsForV0_5_0();
     void ConvertMeasurementsToV0_5_0();
 
+    void ConvertCircumferenceAttreibuteToV0_5_4();
+
     void ToV0_4_0();
     void ToV0_4_1();
     void ToV0_4_2();
     void ToV0_5_0();
-    void ToV0_5_3();
+    void ToV0_5_4();
 };
 
 //---------------------------------------------------------------------------------------------------------------------
