@@ -34,7 +34,7 @@ class VWatermarkConverter final : public VAbstractConverter
 {
 public:
     explicit VWatermarkConverter(const QString &fileName);
-    virtual ~VWatermarkConverter() Q_DECL_EQ_DEFAULT;
+    virtual ~VWatermarkConverter() = default;
 
     static const QString WatermarkMaxVerStr;
     static const QString CurrentSchema;
@@ -55,7 +55,7 @@ protected:
     virtual bool IsReadOnly() const override {return false;}
 
 private:
-    Q_DISABLE_COPY(VWatermarkConverter)
+    Q_DISABLE_COPY_MOVE(VWatermarkConverter) // NOLINT
     static const QString WatermarkMinVerStr;
 
     void ToV1_1_0();
