@@ -82,6 +82,15 @@
 #endif // defined(__cplusplus)
 #endif // QT_VERSION < QT_VERSION_CHECK(5, 8, 0)
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
+#define Q_DISABLE_MOVE(Class) \
+Class(Class &&) = delete; \
+    Class &operator=(Class &&) = delete;
+#define Q_DISABLE_COPY_MOVE(Class) \
+Q_DISABLE_COPY(Class) \
+    Q_DISABLE_MOVE(Class)
+#endif
+
 typedef signed char dint8;              /* 8 bit signed */
 typedef signed short dint16;            /* 16 bit signed */
 typedef signed int dint32;              /* 32 bit signed */
@@ -158,7 +167,7 @@ BAD_READ_BLOCKS,      /*!< error in block read process. */
 BAD_READ_ENTITIES,    /*!< error in entities read process. */
 BAD_READ_OBJECTS,     /*!< error in objects read process. */
 BAD_READ_SECTION,     /*!< error in sections read process. */
-BAD_CODE_PARSED, /*!< error in any parseCodes() method. */
+BAD_CODE_PARSED,      /*!< error in any parseCodes() method. */
 };
 
 enum class DebugLevel {
