@@ -4,6 +4,7 @@
 #include <string>
 #include <QtGlobal>
 #include "../drw_base.h"
+#include "../vmisc/defglobal.h"
 
 class QTextCodec;
 class QStringList;
@@ -25,10 +26,11 @@ public:
     static QTextCodec* CodecForName(const QString &name);
 
 private:
-    std::string correctCodePage(const std::string& s);
+    static auto correctCodePage(const std::string& s) -> std::string;
 
 private:
-    Q_DISABLE_COPY(DRW_TextCodec)
+    // cppcheck-suppress unknownMacro
+    Q_DISABLE_COPY_MOVE(DRW_TextCodec) // NOLINT
     DRW::Version version{DRW::UNKNOWNV};
     std::string cp{};
     QTextCodec *conv{nullptr};
