@@ -93,7 +93,7 @@ const QString VMeasurements::AttrFullName          = QStringLiteral("full_name")
 const QString VMeasurements::AttrMin               = QStringLiteral("min");
 const QString VMeasurements::AttrMax               = QStringLiteral("max");
 const QString VMeasurements::AttrStep              = QStringLiteral("step");
-const QString VMeasurements::AttrCircumference     = QStringLiteral("circumference");
+const QString VMeasurements::AttrMeasurement       = QStringLiteral("measurement");
 const QString VMeasurements::AttrFullCircumference = QStringLiteral("fullCircumference");
 const QString VMeasurements::AttrLabel             = QStringLiteral("label");
 const QString VMeasurements::AttrDimension         = QStringLiteral("dimension");
@@ -111,7 +111,7 @@ const QString VMeasurements::DimensionZ    = QStringLiteral("z");
 
 namespace
 {
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, defBirthDate, (QLatin1String("1800-01-01")))
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, defBirthDate, (QLatin1String("1800-01-01"))) // NOLINT
 
 //---------------------------------------------------------------------------------------------------------------------
 QString FileComment()
@@ -459,11 +459,22 @@ void VMeasurements::ClearForExport()
     for (int i=0; i < list.size(); ++i)
     {
         QDomElement domElement = list.at(i).toElement();
-        if (domElement.isNull() == false)
+        if (not domElement.isNull())
         {
-            if (qmu::QmuTokenParser::IsSingle(domElement.attribute(AttrValue)))
+            if (Type() == MeasurementsType::Individual)
             {
-                SetAttribute(domElement, AttrValue, QChar('0'));
+                if (qmu::QmuTokenParser::IsSingle(domElement.attribute(AttrValue)))
+                {
+                    SetAttribute(domElement, AttrValue, QChar('0'));
+                }
+            }
+            else if (Type() == MeasurementsType::Multisize)
+            {
+                SetAttribute(domElement, AttrBase, QChar('0'));
+                domElement.removeAttribute(AttrShiftA);
+                domElement.removeAttribute(AttrShiftB);
+                domElement.removeAttribute(AttrShiftC);
+                RemoveAllChildren(domElement);
             }
         }
     }
@@ -1239,7 +1250,7 @@ void VMeasurements::CreateEmptyIndividualFile(Unit unit)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QDomElement VMeasurements::CreateDimensions(const QVector<MeasurementDimension_p > &dimensions)
+auto VMeasurements::CreateDimensions(const QVector<MeasurementDimension_p > &dimensions) -> QDomElement
 {
     QDomElement dimensionsTag = createElement(TagDimensions);
 
@@ -1252,8 +1263,8 @@ QDomElement VMeasurements::CreateDimensions(const QVector<MeasurementDimension_p
         SetAttribute(dimensionTag, AttrMin, dimension->MinValue());
         SetAttribute(dimensionTag, AttrMax, dimension->MaxValue());
         SetAttribute(dimensionTag, AttrStep, dimension->Step());
-        SetAttributeOrRemoveIf<bool>(dimensionTag, AttrCircumference, dimension->IsCircumference(),
-                                     [](bool c) noexcept {return c;});
+        SetAttributeOrRemoveIf<bool>(dimensionTag, AttrMeasurement, dimension->IsBodyMeasurement(),
+                                     [](bool m) noexcept {return m;});
         SetAttributeOrRemoveIf<QString>(dimensionTag, AttrCustomName, dimension->CustomName(),
                                      [](const QString &name) noexcept {return name.isEmpty();});
 
@@ -1416,7 +1427,7 @@ auto VMeasurements::ReadDimensions() const -> VDimensions
         }
 
         dimension->SetBaseValue(GetParametrDouble(dom, AttrBase, QChar('0')));
-        dimension->SetCircumference(GetParametrBool(dom, AttrCircumference, trueStr));
+        dimension->SetBodyMeasurement(GetParametrBool(dom, AttrMeasurement, trueStr));
         dimension->SetCustomName(GetParametrEmptyString(dom, AttrCustomName));
         dimension->SetLabels(ReadDimensionLabels(dom));
         dimensions.insert(type, dimension);
