@@ -48,42 +48,42 @@ class VAbstractArc : public VAbstractCurve
 {
 public:
     explicit VAbstractArc(const GOType &type, const quint32 &idObject = NULL_ID, const Draw &mode = Draw::Calculation);
-    VAbstractArc (const GOType &type, const VPointF &center, qreal f1, const QString &formulaF1, qreal f2,
-                  const QString &formulaF2, quint32 idObject = 0, Draw mode = Draw::Calculation);
-    VAbstractArc (const GOType &type, const VPointF &center, qreal f1, qreal f2, quint32 idObject = 0,
-                  Draw mode = Draw::Calculation);
-    VAbstractArc (const GOType &type, const QString &formulaLength, const VPointF &center, qreal f1,
-                  const QString &formulaF1, quint32 idObject = 0, Draw mode = Draw::Calculation);
-    VAbstractArc (const GOType &type, const VPointF &center, qreal f1, quint32 idObject = 0,
-                  Draw mode = Draw::Calculation);
-    explicit VAbstractArc(const VAbstractArc &arc);
-    virtual ~VAbstractArc();
+    VAbstractArc(const GOType &type, const VPointF &center, qreal f1, const QString &formulaF1, qreal f2,
+                 const QString &formulaF2, quint32 idObject = 0, Draw mode = Draw::Calculation);
+    VAbstractArc(const GOType &type, const VPointF &center, qreal f1, qreal f2, quint32 idObject = 0,
+                 Draw mode = Draw::Calculation);
+    VAbstractArc(const GOType &type, const QString &formulaLength, const VPointF &center, qreal f1,
+                 const QString &formulaF1, quint32 idObject = 0, Draw mode = Draw::Calculation);
+    VAbstractArc(const GOType &type, const VPointF &center, qreal f1, quint32 idObject = 0,
+                 Draw mode = Draw::Calculation);
+    VAbstractArc(const VAbstractArc &arc);
+    ~VAbstractArc() override;
 
-    VAbstractArc& operator= (const VAbstractArc &arc);
+    auto operator= (const VAbstractArc &arc) -> VAbstractArc&;
 #ifdef Q_COMPILER_RVALUE_REFS
     VAbstractArc(VAbstractArc &&arc) Q_DECL_NOTHROW;
-    VAbstractArc &operator=(VAbstractArc &&arc) Q_DECL_NOTHROW;
+    auto operator=(VAbstractArc &&arc) Q_DECL_NOTHROW -> VAbstractArc &;
 #endif
 
-    QString       GetFormulaF1 () const;
-    void          SetFormulaF1 (const QString &formula, qreal value);
-    virtual qreal GetStartAngle () const override;
+    auto GetFormulaF1 () const -> QString;
+    void SetFormulaF1 (const QString &formula, qreal value);
+    auto GetStartAngle () const -> qreal override;
 
-    QString       GetFormulaF2 () const;
-    void          SetFormulaF2 (const QString &formula, qreal value);
-    virtual qreal GetEndAngle () const override;
+    auto GetFormulaF2 () const -> QString;
+    void SetFormulaF2 (const QString &formula, qreal value);
+    auto GetEndAngle () const -> qreal override;
 
-    virtual VPointF GetCenter () const;
-    void    SetCenter (const VPointF &point);
+    auto GetCenter () const -> VPointF;
+    void SetCenter (const VPointF &point);
 
-    QString GetFormulaLength () const;
-    void    SetFormulaLength (const QString &formula, qreal value);
+    auto GetFormulaLength () const -> QString;
+    void SetFormulaLength (const QString &formula, qreal value);
 
-    virtual void    setId(const quint32 &id) override;
-    virtual QString NameForHistory(const QString &toolName) const override;
+    void setId(const quint32 &id) override;
+    auto NameForHistory(const QString &toolName) const -> QString override;
 
-    bool IsFlipped() const;
-    qreal AngleArc() const;
+    auto IsFlipped() const -> bool;
+    auto AngleArc() const -> qreal;
 protected:
     void SetFlipped(bool value);
     virtual void FindF2(qreal length)=0;
