@@ -52,7 +52,7 @@ namespace
  * @param y2 у coordinate second point.
  * @return squared length.
  */
-inline qreal CalcSqDistance(qreal x1, qreal y1, qreal x2, qreal y2)
+inline auto CalcSqDistance(qreal x1, qreal y1, qreal x2, qreal y2) -> qreal
 {
     const qreal dx = x2 - x1;
     const qreal dy = y2 - y1;
@@ -74,8 +74,8 @@ inline qreal CalcSqDistance(qreal x1, qreal y1, qreal x2, qreal y2)
  * @param points spline points coordinates.
  * @param approximationScale curve approximation scale.
  */
-QVector<QPointF> PointBezier_r(qreal x1, qreal y1, qreal x2, qreal y2, qreal x3, qreal y3, qreal x4, qreal y4,
-                               qint16 level, QVector<QPointF> points, qreal approximationScale)
+auto PointBezier_r(qreal x1, qreal y1, qreal x2, qreal y2, qreal x3, qreal y3, qreal x4, qreal y4,
+                   qint16 level, QVector<QPointF> points, qreal approximationScale) -> QVector<QPointF>
 {
     if (points.size() >= 2)
     {
@@ -373,17 +373,10 @@ QVector<QPointF> PointBezier_r(qreal x1, qreal y1, qreal x2, qreal y2, qreal x3,
 //---------------------------------------------------------------------------------------------------------------------
 VAbstractCubicBezier::VAbstractCubicBezier(const GOType &type, const quint32 &idObject, const Draw &mode)
     : VAbstractBezier(type, idObject, mode)
-{
-}
+{}
 
 //---------------------------------------------------------------------------------------------------------------------
-VAbstractCubicBezier::VAbstractCubicBezier(const VAbstractCubicBezier &curve)
-    : VAbstractBezier(curve)
-{
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-VAbstractCubicBezier &VAbstractCubicBezier::operator=(const VAbstractCubicBezier &curve)
+auto VAbstractCubicBezier::operator=(const VAbstractCubicBezier &curve) -> VAbstractCubicBezier &
 {
     if ( &curve == this )
     {
@@ -393,11 +386,6 @@ VAbstractCubicBezier &VAbstractCubicBezier::operator=(const VAbstractCubicBezier
     return *this;
 }
 
-//---------------------------------------------------------------------------------------------------------------------
-VAbstractCubicBezier::~VAbstractCubicBezier()
-{
-}
-
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief CutSpline cut spline.
@@ -406,13 +394,13 @@ VAbstractCubicBezier::~VAbstractCubicBezier()
  * @param spl1p3 third point of first spline
  * @param spl2p2 second point of second spline
  * @param spl2p3 third point of second spline
+ * @param pointName cutting point name.
  * @return point of cutting. This point is forth point of first spline and first point of second spline.
  */
-QPointF VAbstractCubicBezier::CutSpline(qreal length, QPointF &spl1p2, QPointF &spl1p3, QPointF &spl2p2,
-                                        QPointF &spl2p3) const
+auto VAbstractCubicBezier::CutSpline(qreal length, QPointF &spl1p2, QPointF &spl1p3, QPointF &spl2p2,
+                                     QPointF &spl2p3, const QString &pointName) const -> QPointF
 {
     //Always need return two splines, so we must correct wrong length.
-    const qreal minLength = ToPixel(1, Unit::Mm);
     const qreal fullLength = GetLength();
 
     if (fullLength <= minLength)
@@ -423,7 +411,7 @@ QPointF VAbstractCubicBezier::CutSpline(qreal length, QPointF &spl1p2, QPointF &
         VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
                                           qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
 
-        return QPointF();
+        return {};
     }
 
     const qreal maxLength = fullLength - minLength;
@@ -432,8 +420,17 @@ QPointF VAbstractCubicBezier::CutSpline(qreal length, QPointF &spl1p2, QPointF &
     {
         length = minLength;
 
-        const QString errorMsg = QObject::tr("Curve '%1'. Length of a cut segment is too small. Optimize it to minimal "
-                                             "value.").arg(name());
+        QString errorMsg;
+        if (not pointName.isEmpty())
+        {
+            errorMsg = QObject::tr("Curve '%1'. Length of a cut segment (%2) is too small. Optimize it to minimal "
+                                   "value.").arg(name(), pointName);
+        }
+        else
+        {
+            errorMsg = QObject::tr("Curve '%1'. Length of a cut segment is too small. Optimize it to minimal value.")
+                    .arg(name());
+        }
         VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
                                           qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
     }
@@ -441,8 +438,17 @@ QPointF VAbstractCubicBezier::CutSpline(qreal length, QPointF &spl1p2, QPointF &
     {
         length = maxLength;
 
-        const QString errorMsg = QObject::tr("Curve '%1'. Length of a cut segment is too big. Optimize it to maximal "
-                                             "value.").arg(name());
+        QString errorMsg;
+        if (not pointName.isEmpty())
+        {
+            errorMsg = QObject::tr("Curve '%1'. Length of a cut segment (%2) is too big. Optimize it to maximal value.")
+                    .arg(name(), pointName);
+        }
+        else
+        {
+            errorMsg = QObject::tr("Curve '%1'. Length of a cut segment is too big. Optimize it to maximal value.")
+                    .arg(name());
+        }
         VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
                                           qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
     }
@@ -481,22 +487,22 @@ QPointF VAbstractCubicBezier::CutSpline(qreal length, QPointF &spl1p2, QPointF &
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VAbstractCubicBezier::NameForHistory(const QString &toolName) const
+auto VAbstractCubicBezier::NameForHistory(const QString &toolName) const -> QString
 {
-    QString name = toolName + QString(" %1_%2").arg(GetP1().name(), GetP4().name());
+    QString name = toolName + QStringLiteral(" %1_%2").arg(GetP1().name(), GetP4().name());
     if (GetDuplicate() > 0)
     {
-        name += QString("_%1").arg(GetDuplicate());
+        name += QStringLiteral("_%1").arg(GetDuplicate());
     }
 
     QString alias;
 
     if (not GetAliasSuffix().isEmpty())
     {
-        alias = QString("%1 %2").arg(toolName, GetAliasSuffix());
+        alias = QStringLiteral("%1 %2").arg(toolName, GetAliasSuffix());
     }
 
-    return not alias.isEmpty() ? QString("%1 (%2)").arg(alias, name) : name;
+    return not alias.isEmpty() ? QStringLiteral("%1 (%2)").arg(alias, name) : name;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -513,7 +519,7 @@ auto VAbstractCubicBezier::GetParmT(qreal length) const -> qreal
         length = base;
     }
 
-    Q_DECL_RELAXED_CONSTEXPR qreal eps = ToPixel(0.001, Unit::Mm);
+    Q_DECL_RELAXED_CONSTEXPR qreal eps = ToPixel(0.00001, Unit::Mm);
     qreal parT = 0.5;
     qreal step = parT;
     qreal splLength = 0;
@@ -538,10 +544,10 @@ auto VAbstractCubicBezier::GetParmT(qreal length) const -> qreal
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractCubicBezier::CreateName()
 {
-    QString name = SPL_ + QString("%1_%2").arg(GetP1().name(), GetP4().name());
+    QString name = SPL_ + QStringLiteral("%1_%2").arg(GetP1().name(), GetP4().name());
     if (GetDuplicate() > 0)
     {
-        name += QString("_%1").arg(GetDuplicate());
+        name += QStringLiteral("_%1").arg(GetDuplicate());
     }
 
     setName(name);
@@ -570,8 +576,8 @@ void VAbstractCubicBezier::CreateAlias()
  * @param approximationScale curve approximation scale.
  * @return list of points.
  */
-QVector<QPointF> VAbstractCubicBezier::GetCubicBezierPoints(const QPointF &p1, const QPointF &p2, const QPointF &p3,
-                                                            const QPointF &p4, qreal approximationScale)
+auto VAbstractCubicBezier::GetCubicBezierPoints(const QPointF &p1, const QPointF &p2, const QPointF &p3,
+                                                const QPointF &p4, qreal approximationScale) -> QVector<QPointF>
 {
     QVector<QPointF> pvector;
     pvector.append(p1);
@@ -591,14 +597,14 @@ QVector<QPointF> VAbstractCubicBezier::GetCubicBezierPoints(const QPointF &p1, c
  * @param approximationScale curve approximation scale.
  * @return length.
  */
-qreal VAbstractCubicBezier::LengthBezier(const QPointF &p1, const QPointF &p2, const QPointF &p3, const QPointF &p4,
-                                         qreal approximationScale)
+auto VAbstractCubicBezier::LengthBezier(const QPointF &p1, const QPointF &p2, const QPointF &p3, const QPointF &p4,
+                                        qreal approximationScale) -> qreal
 {
     return PathLength(GetCubicBezierPoints(p1, p2, p3, p4, approximationScale));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VAbstractCubicBezier::RealLengthByT(qreal t) const
+auto VAbstractCubicBezier::RealLengthByT(qreal t) const -> qreal
 {
     if (t < 0 || t > 1)
     {
