@@ -34,14 +34,199 @@
 #include <QtDebug>
 
 #include "../vmisc/def.h"
-#include "../vmisc/vmath.h"
 #include "../ifc/ifcdef.h"
 #include "../ifc/exception/vexception.h"
 #include "../vmisc/vabstractapplication.h"
+#include "../vmisc/fpm/fixed.hpp"
+#include "../vmisc/fpm/math.hpp"
 #include "../vmisc/compatibility.h"
 #include "vabstractcurve.h"
 #include "vellipticalarc_p.h"
-#include "vspline.h"
+#include "../vmisc/vmath.h"
+
+namespace
+{
+constexpr qreal tolerance = accuracyPointOnLine/8;
+
+// Because of overflow we cannot generate arcs more than maxRadius
+constexpr int maxRadius = 10000;
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VLen(fpm::fixed_16_16 x, fpm::fixed_16_16 y) -> fpm::fixed_16_16
+{
+    x = fpm::abs(x);
+    y = fpm::abs(y);
+    if (x > y)
+    {
+        return x + qMax(y/8, y/2 - x/8);
+    }
+
+    return y + qMax(x/8, x/2 - y/8);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto AuxRadius(fpm::fixed_16_16 xP, fpm::fixed_16_16 yP, fpm::fixed_16_16 xQ, fpm::fixed_16_16 yQ) -> fpm::fixed_16_16
+{
+    fpm::fixed_16_16 dP = VLen(xP, yP);
+    fpm::fixed_16_16 dQ = VLen(xQ, yQ);
+    fpm::fixed_16_16 dJ = VLen(xP + xQ, yP + yQ);
+    fpm::fixed_16_16 dK = VLen(xP - xQ, yP - yQ);
+    fpm::fixed_16_16 r1 = qMax(dP, dQ);
+    fpm::fixed_16_16 r2 = qMax(dJ, dK);
+    return qMax(r1 + r1/16, r2 - r2/4);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto AngularInc(fpm::fixed_16_16 xP, fpm::fixed_16_16 yP, fpm::fixed_16_16 xQ, fpm::fixed_16_16 yQ,
+                fpm::fixed_16_16 flatness) -> int
+{
+
+    fpm::fixed_16_16 r = AuxRadius(xP, yP, xQ, yQ);
+    fpm::fixed_16_16 err2{r >> 3};
+    // 2nd-order term
+    fpm::fixed_16_16 err4{r >> 7};
+    // 4th-order term
+    const int kmax = qRound(0.5 * std::log2(maxSceneSize / (8. * tolerance)));
+    for (int k = 0; k < kmax; ++k)
+    {
+        if (flatness >= err2 + err4)
+        {
+            return k;
+        }
+        err2 >>= 2;
+        err4 >>= 4;
+    }
+    return kmax;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+inline void CircleGen(fpm::fixed_16_16& u, fpm::fixed_16_16& v, uint k)
+{
+    u -= v >> k;
+    v += u >> k;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto InitialValue(fpm::fixed_16_16 u0, fpm::fixed_16_16 v0, uint k) -> fpm::fixed_16_16
+{
+    uint shift = 2*k + 3;
+    fpm::fixed_16_16 w {u0 >> shift};
+
+    fpm::fixed_16_16 U0 = u0 - w + (v0 >> (k + 1));
+    w >>= (shift + 1);
+    U0 -= w;
+    w >>= shift;
+    U0 -= w;
+    return U0;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto EllipseCore(fpm::fixed_16_16 xC, fpm::fixed_16_16 yC, fpm::fixed_16_16 xP, fpm::fixed_16_16 yP,
+                 fpm::fixed_16_16 xQ, fpm::fixed_16_16 yQ, fpm::fixed_16_16 sweep,
+                 fpm::fixed_16_16 flatness) -> QVector<QPointF>
+{
+    uint k = qMin(static_cast<uint>(AngularInc(xP, yP, xQ, yQ, flatness)), 16U);
+    const uint count = static_cast<std::uint32_t>(sweep.raw_value()) >> (16 - k);
+
+    QVector<QPointF> arc;
+    arc.reserve(static_cast<int>(count) + 1);
+
+    // Arc start point
+    arc.append({static_cast<qreal>(xP + xC), static_cast<qreal>(yP + yC)});
+
+    xQ = InitialValue(xQ, xP, k);
+    yQ = InitialValue(yQ, yP, k);
+
+    for (uint i = 0; i < count; ++i)
+    {
+        CircleGen(xQ, xP, k);
+        CircleGen(yQ, yP, k);
+        arc.append({static_cast<qreal>(xP + xC), static_cast<qreal>(yP + yC)});
+    }
+
+    return arc;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto EllipticArcPoints(QPointF c, qreal radius1, qreal radius2, qreal astart, qreal asweep,
+                       qreal approximationScale) -> QVector<QPointF>
+{
+    fpm::fixed_16_16 xC{c.x()};
+    fpm::fixed_16_16 yC{c.y()};
+
+    fpm::fixed_16_16 xP{c.x() + radius1};
+    fpm::fixed_16_16 yP{c.y()};
+
+    fpm::fixed_16_16 xQ{c.x()};
+    fpm::fixed_16_16 yQ{c.y() - radius2};
+
+    xP -= xC;
+    yP -= yC;
+    xQ -= xC;
+    yQ -= yC;
+
+    if (not qFuzzyIsNull(astart))
+    {
+        // Set new conjugate diameter end points P’ and Q’
+        fpm::fixed_16_16 cosa {cos(astart)};
+        fpm::fixed_16_16 sina {sin(astart)};
+        fpm::fixed_16_16 x {xP * cosa + xQ * sina};
+        fpm::fixed_16_16 y {yP * cosa + yQ * sina};
+
+        xQ = xQ * cosa - xP * sina;
+        yQ = yQ * cosa - yP * sina;
+        xP = x;
+        yP = y;
+    }
+
+    // If sweep angle is negative, switch direction
+    if (asweep < 0)
+    {
+        xQ = -xQ;
+        yQ = -yQ;
+        asweep = -asweep;
+    }
+
+    if(approximationScale < minCurveApproximationScale || approximationScale > maxCurveApproximationScale)
+    {
+        approximationScale = VAbstractApplication::VApp()->Settings()->GetCurveApproximationScale();
+    }
+
+    fpm::fixed_16_16 flatness {maxCurveApproximationScale / approximationScale * tolerance};
+    fpm::fixed_16_16 swangle{asweep};
+    QVector<QPointF> arc = EllipseCore(xC, yC, xP, yP, xQ, yQ, swangle, flatness);
+
+    // Arc end point
+    fpm::fixed_16_16 cosb {qCos(asweep)};
+    fpm::fixed_16_16 sinb {qSin(asweep)};
+    xP = xP*cosb + xQ*sinb;
+    yP = yP*cosb + yQ*sinb;
+    arc.append({static_cast<qreal>(xP+xC), static_cast<qreal>(yP+yC)});
+
+    return arc;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto JoinVectors(const QVector<QPointF> &v1, const QVector<QPointF> &v2) -> QVector<QPointF>
+{
+    QVector<QPointF> v;
+    v.reserve(v1.size() + v2.size());
+
+    v = v1;
+
+    constexpr qreal accuracy = MmToPixel(0.0001);
+
+    for (auto p : v2)
+    {
+        if (not VFuzzyComparePoints(ConstLast(v), p, accuracy))
+        {
+            v.append(p);
+        }
+    }
+
+    return v;
+}
+}  // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -61,11 +246,11 @@ VEllipticalArc::VEllipticalArc()
  * @param f2 end angle (degree).
  */
 VEllipticalArc::VEllipticalArc (const VPointF &center, qreal radius1, qreal radius2, const QString &formulaRadius1,
-                                const QString &formulaRadius2, qreal f1, const QString &formulaF1, qreal f2,
-                                const QString &formulaF2, qreal rotationAngle, const QString &formulaRotationAngle,
-                                quint32 idObject, Draw mode)
+                               const QString &formulaRadius2, qreal f1, const QString &formulaF1, qreal f2,
+                               const QString &formulaF2, qreal rotationAngle, const QString &formulaRotationAngle,
+                               quint32 idObject, Draw mode)
     : VAbstractArc(GOType::EllipticalArc, center, f1, formulaF1, f2, formulaF2, idObject, mode),
-      d (new VEllipticalArcData(radius1, radius2, formulaRadius1, formulaRadius2, rotationAngle, formulaRotationAngle))
+    d (new VEllipticalArcData(radius1, radius2, formulaRadius1, formulaRadius2, rotationAngle, formulaRotationAngle))
 {
     CreateName();
 }
@@ -74,7 +259,7 @@ VEllipticalArc::VEllipticalArc (const VPointF &center, qreal radius1, qreal radi
 VEllipticalArc::VEllipticalArc(const VPointF &center, qreal radius1, qreal radius2, qreal f1, qreal f2,
                                qreal rotationAngle)
     : VAbstractArc(GOType::EllipticalArc, center, f1, f2, NULL_ID, Draw::Calculation),
-      d (new VEllipticalArcData(radius1, radius2, rotationAngle))
+    d (new VEllipticalArcData(radius1, radius2, rotationAngle))
 {
     CreateName();
 }
@@ -85,7 +270,7 @@ VEllipticalArc::VEllipticalArc(qreal length, const QString &formulaLength, const
                                const QString &formulaF1, qreal rotationAngle, const QString &formulaRotationAngle,
                                quint32 idObject, Draw mode)
     : VAbstractArc(GOType::EllipticalArc, formulaLength, center, f1, formulaF1, idObject, mode),
-      d (new VEllipticalArcData(radius1, radius2, formulaRadius1, formulaRadius2, rotationAngle, formulaRotationAngle))
+    d (new VEllipticalArcData(radius1, radius2, formulaRadius1, formulaRadius2, rotationAngle, formulaRotationAngle))
 {
     CreateName();
     FindF2(length);
@@ -95,7 +280,7 @@ VEllipticalArc::VEllipticalArc(qreal length, const QString &formulaLength, const
 VEllipticalArc::VEllipticalArc(qreal length, const VPointF &center, qreal radius1, qreal radius2, qreal f1,
                                qreal rotationAngle)
     : VAbstractArc(GOType::EllipticalArc, center, f1, NULL_ID, Draw::Calculation),
-      d (new VEllipticalArcData(radius1, radius2, rotationAngle))
+    d (new VEllipticalArcData(radius1, radius2, rotationAngle))
 {
     CreateName();
     FindF2(length);
@@ -116,7 +301,7 @@ VEllipticalArc::VEllipticalArc(const VEllipticalArc &arc)
  * @param arc arc
  * @return arc
  */
-VEllipticalArc &VEllipticalArc::operator =(const VEllipticalArc &arc)
+auto VEllipticalArc::operator =(const VEllipticalArc &arc) -> VEllipticalArc &
 {
     if ( &arc == this )
     {
@@ -129,12 +314,13 @@ VEllipticalArc &VEllipticalArc::operator =(const VEllipticalArc &arc)
 
 #ifdef Q_COMPILER_RVALUE_REFS
 //---------------------------------------------------------------------------------------------------------------------
-VEllipticalArc::VEllipticalArc(const VEllipticalArc &&arc) Q_DECL_NOTHROW
-    : VAbstractArc(arc), d (arc.d)
+VEllipticalArc::VEllipticalArc(VEllipticalArc &&arc) Q_DECL_NOTHROW
+    : VAbstractArc(std::move(arc)),
+      d(std::move(arc.d))
 {}
 
 //---------------------------------------------------------------------------------------------------------------------
-VEllipticalArc &VEllipticalArc::operator=(VEllipticalArc &&arc) Q_DECL_NOTHROW
+auto VEllipticalArc::operator=(VEllipticalArc &&arc) Q_DECL_NOTHROW -> VEllipticalArc &
 {
     VAbstractArc::operator=(arc);
     std::swap(d, arc.d);
@@ -143,7 +329,7 @@ VEllipticalArc &VEllipticalArc::operator=(VEllipticalArc &&arc) Q_DECL_NOTHROW
 #endif
 
 //---------------------------------------------------------------------------------------------------------------------
-VEllipticalArc VEllipticalArc::Rotate(QPointF originPoint, qreal degrees, const QString &prefix) const
+auto VEllipticalArc::Rotate(QPointF originPoint, qreal degrees, const QString &prefix) const -> VEllipticalArc
 {
     originPoint = d->m_transform.inverted().map(originPoint);
 
@@ -165,11 +351,12 @@ VEllipticalArc VEllipticalArc::Rotate(QPointF originPoint, qreal degrees, const
     elArc.SetPenStyle(GetPenStyle());
     elArc.SetFlipped(IsFlipped());
     elArc.SetTransform(t);
+    elArc.SetApproximationScale(GetApproximationScale());
     return elArc;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VEllipticalArc VEllipticalArc::Flip(const QLineF &axis, const QString &prefix) const
+auto VEllipticalArc::Flip(const QLineF &axis, const QString &prefix) const -> VEllipticalArc
 {
     VEllipticalArc elArc(VAbstractArc::GetCenter(), GetRadius1(), GetRadius2(), VAbstractArc::GetStartAngle(),
                          VAbstractArc::GetEndAngle(), GetRotationAngle());
@@ -184,17 +371,18 @@ VEllipticalArc VEllipticalArc::Flip(const QLineF &axis, const QString &prefix) c
     elArc.SetPenStyle(GetPenStyle());
     elArc.SetFlipped(not IsFlipped());
     elArc.SetTransform(d->m_transform * VGObject::FlippingMatrix(d->m_transform.inverted().map(axis)));
+    elArc.SetApproximationScale(GetApproximationScale());
     return elArc;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VEllipticalArc VEllipticalArc::Move(qreal length, qreal angle, const QString &prefix) const
+auto VEllipticalArc::Move(qreal length, qreal angle, const QString &prefix) const -> VEllipticalArc
 {
     const VPointF oldCenter = VAbstractArc::GetCenter();
     const VPointF center = oldCenter.Move(length, angle);
 
     const QPointF position = d->m_transform.inverted().map(center.toQPointF()) -
-            d->m_transform.inverted().map(oldCenter.toQPointF());
+                             d->m_transform.inverted().map(oldCenter.toQPointF());
 
     QTransform t = d->m_transform;
     t.translate(position.x(), position.y());
@@ -212,11 +400,12 @@ VEllipticalArc VEllipticalArc::Move(qreal length, qreal angle, const QString &pr
     elArc.SetPenStyle(GetPenStyle());
     elArc.SetFlipped(IsFlipped());
     elArc.SetTransform(t);
+    elArc.SetApproximationScale(GetApproximationScale());
     return elArc;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VEllipticalArc::~VEllipticalArc()
+VEllipticalArc::~VEllipticalArc() // NOLINT(hicpp-use-equals-default, modernize-use-equals-default)
 {}
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -224,7 +413,7 @@ VEllipticalArc::~VEllipticalArc()
  * @brief GetLength return arc length.
  * @return length.
  */
-qreal VEllipticalArc::GetLength() const
+auto VEllipticalArc::GetLength() const -> qreal
 {
     qreal length = PathLength(GetPoints());
 
@@ -241,7 +430,7 @@ qreal VEllipticalArc::GetLength() const
  * @brief GetP1 return point associated with start angle.
  * @return point.
  */
-QPointF VEllipticalArc::GetP1() const
+auto VEllipticalArc::GetP1() const -> QPointF
 {
     return GetTransform().map(GetP(VAbstractArc::GetStartAngle()));
 }
@@ -251,13 +440,13 @@ QPointF VEllipticalArc::GetP1() const
  * @brief GetP2 return point associated with end angle.
  * @return point.
  */
-QPointF VEllipticalArc::GetP2 () const
+auto VEllipticalArc::GetP2 () const -> QPointF
 {
     return GetTransform().map(GetP(VAbstractArc::GetEndAngle()));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QTransform VEllipticalArc::GetTransform() const
+auto VEllipticalArc::GetTransform() const -> QTransform
 {
     return d->m_transform;
 }
@@ -269,7 +458,7 @@ void VEllipticalArc::SetTransform(const QTransform &matrix, bool combine)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VPointF VEllipticalArc::GetCenter() const
+auto VEllipticalArc::GetCenter() const -> VPointF
 {
     VPointF center = VAbstractArc::GetCenter();
     const QPointF p = d->m_transform.map(center.toQPointF());
@@ -283,58 +472,52 @@ VPointF VEllipticalArc::GetCenter() const
  * @brief GetPoints return list of points needed for drawing arc.
  * @return list of points
  */
-QVector<QPointF> VEllipticalArc::GetPoints() const
+auto VEllipticalArc::GetPoints() const -> QVector<QPointF>
 {
     const QPointF center = VAbstractArc::GetCenter().toQPointF();
-    QRectF box(center.x() - d->radius1, center.y() - d->radius2, d->radius1*2, d->radius2*2);
 
-    QLineF startLine(center.x(), center.y(), center.x() + d->radius1, center.y());
-    QLineF endLine = startLine;
+    // Don't work with 0 radius. Always make it bigger than 0.
+    Q_RELAXED_CONSTEXPR qreal threshold = ToPixel(0.001, Unit::Mm);
+    qreal radius1 = qMax(d->radius1, threshold);
+    qreal radius2 = qMax(d->radius2, threshold);
+    qreal max = qMax(d->radius1, d->radius2);
+    qreal scale = 1;
 
-    startLine.setAngle(VAbstractArc::GetStartAngle());
-    endLine.setAngle(RealEndAngle());
-    qreal sweepAngle = startLine.angleTo(endLine);
-
-    if (qFuzzyIsNull(sweepAngle))
+    if (max > maxRadius)
     {
-        sweepAngle = 360;
+        scale = max / maxRadius;
+        radius1 /= scale;
+        radius2 /= scale;
     }
 
-    QPainterPath path;
-    path.moveTo(GetP1());
-    path.arcTo(box, VAbstractArc::GetStartAngle(), sweepAngle);
-    path.moveTo(GetP2());
+    // Generate complete ellipse because angles are not correct and have to be fixed manually
+    QVector<QPointF> points = EllipticArcPoints(center, radius1, radius2, 0.0, M_2PI, GetApproximationScale());
+    points = ArcPoints(points);
 
     QTransform t = d->m_transform;
     t.translate(center.x(), center.y());
+    if (not VFuzzyComparePossibleNulls(scale, 1))
+    {
+        // Because fixed 16.16 type has limitations it is very easy to get overflow error.
+        // To avoid this we calculate an arc for scaled radiuses and then scale up to original size.
+        t.scale(scale, scale);
+    }
     t.rotate(-GetRotationAngle());
     t.translate(-center.x(), -center.y());
 
-    path = t.map(path);
+    std::transform(points.begin(), points.end(), points.begin(), [t](const QPointF &point) { return t.map(point); });
 
-    QPolygonF polygon;
-    const QList<QPolygonF> sub = path.toSubpathPolygons();
-    if (not sub.isEmpty())
-    {
-        polygon = ConstFirst (path.toSubpathPolygons());
-
-        if (not polygon.isEmpty() && not VFuzzyComparePoints(GetP1(), ConstFirst<QPointF> (polygon)))
-        {
-            polygon.removeFirst(); // remove point (0;0)
-        }
-    }
-
-    return static_cast<QVector<QPointF>>(polygon);
+    return points;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VEllipticalArc::GetStartAngle() const
+auto VEllipticalArc::GetStartAngle() const -> qreal
 {
     return QLineF(GetCenter().toQPointF(), GetP1()).angle() - GetRotationAngle();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VEllipticalArc::GetEndAngle() const
+auto VEllipticalArc::GetEndAngle() const -> qreal
 {
     return QLineF(GetCenter().toQPointF(), GetP2()).angle() - GetRotationAngle();
 }
@@ -347,11 +530,11 @@ qreal VEllipticalArc::GetEndAngle() const
  * @param arc2 second arc.
  * @return point cutting
  */
-QPointF VEllipticalArc::CutArc(const qreal &length, VEllipticalArc &arc1, VEllipticalArc &arc2) const
+auto VEllipticalArc::CutArc(const qreal &length, VEllipticalArc &arc1, VEllipticalArc &arc2,
+                            const QString &pointName) const -> QPointF
 {
     //Always need return two arcs, so we must correct wrong length.
     qreal len = 0;
-    const qreal minLength = ToPixel(1, Unit::Mm);
     const qreal fullLength = GetLength();
 
     if (fullLength <= minLength)
@@ -361,9 +544,9 @@ QPointF VEllipticalArc::CutArc(const qreal &length, VEllipticalArc &arc1, VEllip
 
         const QString errorMsg = QObject::tr("Unable to cut curve '%1'. The curve is too short.").arg(name());
         VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-                                          qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
+            qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
 
-        return QPointF();
+        return {};
     }
 
     const qreal maxLength = fullLength - minLength;
@@ -372,19 +555,37 @@ QPointF VEllipticalArc::CutArc(const qreal &length, VEllipticalArc &arc1, VEllip
     {
         len = minLength;
 
-        const QString errorMsg = QObject::tr("Curve '%1'. Length of a cut segment is too small. Optimize it to minimal "
-                                             "value.").arg(name());
+        QString errorMsg;
+        if (not pointName.isEmpty())
+        {
+            errorMsg = QObject::tr("Curve '%1'. Length of a cut segment (%2) is too small. Optimize it to minimal "
+                                   "value.").arg(name(), pointName);
+        }
+        else
+        {
+            errorMsg = QObject::tr("Curve '%1'. Length of a cut segment is too small. Optimize it to minimal value.")
+                           .arg(name());
+        }
         VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-                                          qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
+            qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
     }
     else if (length > maxLength)
     {
         len = maxLength;
 
-        const QString errorMsg = QObject::tr("Curve '%1'. Length of a cut segment is too big. Optimize it to maximal "
-                                             "value.").arg(name());
+        QString errorMsg;
+        if (not pointName.isEmpty())
+        {
+            errorMsg = QObject::tr("Curve '%1'. Length of a cut segment (%2) is too big. Optimize it to maximal value.")
+                           .arg(name(), pointName);
+        }
+        else
+        {
+            errorMsg = QObject::tr("Curve '%1'. Length of a cut segment is too big. Optimize it to maximal value.")
+                           .arg(name());
+        }
         VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-                                          qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
+            qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
     }
     else
     {
@@ -393,42 +594,43 @@ QPointF VEllipticalArc::CutArc(const qreal &length, VEllipticalArc &arc1, VEllip
 
     // the first arc has given length and startAngle just like in the origin arc
     arc1 = VEllipticalArc (len, QString().setNum(length), GetCenter(), d->radius1, d->radius2,
-                           d->formulaRadius1, d->formulaRadius2, GetStartAngle(), GetFormulaF1(), d->rotationAngle,
-                           GetFormulaRotationAngle(), getIdObject(), getMode());
+                          d->formulaRadius1, d->formulaRadius2, GetStartAngle(), GetFormulaF1(), d->rotationAngle,
+                          GetFormulaRotationAngle(), getIdObject(), getMode());
     // the second arc has startAngle just like endAngle of the first arc
     // and it has endAngle just like endAngle of the origin arc
     arc2 = VEllipticalArc (GetCenter(), d->radius1, d->radius2, d->formulaRadius1, d->formulaRadius2,
-                           arc1.GetEndAngle(), arc1.GetFormulaF2(), GetEndAngle(), GetFormulaF2(), d->rotationAngle,
-                           GetFormulaRotationAngle(), getIdObject(), getMode());
+                          arc1.GetEndAngle(), arc1.GetFormulaF2(), GetEndAngle(), GetFormulaF2(), d->rotationAngle,
+                          GetFormulaRotationAngle(), getIdObject(), getMode());
     return arc1.GetP1();
 }
 
 
 //---------------------------------------------------------------------------------------------------------------------
-QPointF VEllipticalArc::CutArc(const qreal &length) const
+auto VEllipticalArc::CutArc(const qreal &length, const QString &pointName) const -> QPointF
 {
     VEllipticalArc arc1;
     VEllipticalArc arc2;
-    return this->CutArc(length, arc1, arc2);
+    return this->CutArc(length, arc1, arc2, pointName);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VEllipticalArc::CreateName()
 {
-    QString name = ELARC_ + QString("%1").arg(this->GetCenter().name());
+    QString name = ELARC_ + QStringLiteral("%1").arg(this->GetCenter().name());
+    const QString nameStr = QStringLiteral("_%1");
 
     if (getMode() == Draw::Modeling && getIdObject() != NULL_ID)
     {
-        name += QString("_%1").arg(getIdObject());
+        name += nameStr.arg(getIdObject());
     }
     else if (VAbstractCurve::id() != NULL_ID)
     {
-        name += QString("_%1").arg(VAbstractCurve::id());
+        name += nameStr.arg(VAbstractCurve::id());
     }
 
     if (GetDuplicate() > 0)
     {
-        name += QString("_%1").arg(GetDuplicate());
+        name += nameStr.arg(GetDuplicate());
     }
 
     setName(name);
@@ -500,7 +702,7 @@ void VEllipticalArc::FindF2(qreal length)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VEllipticalArc::MaxLength() const
+auto VEllipticalArc::MaxLength() const -> qreal
 {
     const qreal h = qPow(d->radius1 - d->radius2, 2) / qPow(d->radius1 + d->radius2, 2);
     const qreal ellipseLength = M_PI * (d->radius1 + d->radius2) * (1+3*h/(10+qSqrt(4-3*h)));
@@ -508,7 +710,7 @@ qreal VEllipticalArc::MaxLength() const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QPointF VEllipticalArc::GetP(qreal angle) const
+auto VEllipticalArc::GetP(qreal angle) const -> QPointF
 {
     if (qFuzzyIsNull(GetRadius1()) && qFuzzyIsNull(GetRadius2()))
     {
@@ -537,23 +739,105 @@ QPointF VEllipticalArc::GetP(qreal angle) const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VEllipticalArc::RealEndAngle() const
+auto VEllipticalArc::ArcPoints(QVector<QPointF> points) const -> QVector<QPointF>
 {
-    qreal endAngle = VEllipticalArc::OptimizeAngle(VAbstractArc::GetEndAngle());
-
-    if (qFuzzyIsNull(endAngle) ||
-            VFuzzyComparePossibleNulls(endAngle, 90) ||
-            VFuzzyComparePossibleNulls(endAngle, 180) ||
-            VFuzzyComparePossibleNulls(endAngle, 270) ||
-            VFuzzyComparePossibleNulls(endAngle, 360))
+    if (points.size() < 2 || (qFuzzyIsNull(d->radius1) && qFuzzyIsNull(d->radius2)))
     {
-        return endAngle;
+        return points;
     }
 
-    endAngle = qRadiansToDegrees(qAtan2(d->radius1 * qSin(qDegreesToRadians(endAngle)),
-                                        d->radius2 * qCos(qDegreesToRadians(endAngle))));
+    QPointF center = VAbstractArc::GetCenter().toQPointF();
+    qreal radius = qMax(d->radius1, d->radius2) * 2;
 
-    return endAngle;
+    QLineF start(center.x(), center.y(), center.x() + radius, center.y());
+    start.setAngle(VAbstractArc::GetStartAngle());
+
+    QLineF end(center.x(), center.y(), center.x() + radius, center.y());
+    end.setAngle(VAbstractArc::GetEndAngle());
+
+    auto IsBoundedIntersection = [](QLineF::IntersectType type, QPointF p, const QLineF &segment1,
+                                    const QLineF &segment2)
+    {
+        return type == QLineF::BoundedIntersection ||
+               (type == QLineF::UnboundedIntersection &&
+                VGObject::IsPointOnLineSegment (p, segment1.p1(), segment2.p1()) &&
+                VGObject::IsPointOnLineSegment (p, segment2.p1(), segment2.p2()));
+    };
+
+    bool begin = true;
+
+    if (start.angle() >= end.angle())
+    {
+        for (int i=0; i < points.size()-1; ++i)
+        {
+            QLineF edge(points.at(i), points.at(i+1));
+
+            QPointF p;
+            QLineF::IntersectType type = Intersects(start, edge, &p);
+
+            // QLineF::intersects not always accurate on edge cases
+            if (IsBoundedIntersection(type, p, edge, start))
+            {
+                QVector<QPointF> head = points.mid(0, i+1);
+                QVector<QPointF> tail = points.mid(i+1, -1);
+
+                tail = JoinVectors({p}, tail);
+                points = JoinVectors(tail, head);
+                points = JoinVectors(points, {p});
+
+                if (VFuzzyComparePossibleNulls(start.angle(), end.angle()))
+                {
+                    return points;
+                }
+
+                begin = false;
+                break;
+            }
+        }
+    }
+
+    QVector<QPointF> arc;
+    arc.reserve(points.size());
+
+    for (int i=0; i < points.size()-1; ++i)
+    {
+        QLineF edge(points.at(i), points.at(i+1));
+
+        if (begin)
+        {
+            QPointF p;
+            QLineF::IntersectType type = Intersects(start, edge, &p);
+
+            // QLineF::intersects not always accurate on edge cases
+            if (IsBoundedIntersection(type, p, edge, start))
+            {
+                arc.append(p);
+                begin = false;
+            }
+        }
+        else
+        {
+            QPointF p;
+            QLineF::IntersectType type = Intersects(end, edge, &p);
+
+            // QLineF::intersects not always accurate on edge cases
+            if (IsBoundedIntersection(type, p, edge, end))
+            {
+                arc.append(points.at(i));
+                arc.append(p);
+                break;
+            }
+
+            arc.append(points.at(i));
+        }
+    }
+
+    if (arc.isEmpty())
+    {
+        return points;
+    }
+
+    return arc;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -561,7 +845,7 @@ qreal VEllipticalArc::RealEndAngle() const
  * @brief GetFormulaRadius1 return formula for major radius.
  * @return radius.
  */
-QString VEllipticalArc::GetFormulaRadius1() const
+auto VEllipticalArc::GetFormulaRadius1() const -> QString
 {
     return d->formulaRadius1;
 }
@@ -571,7 +855,7 @@ QString VEllipticalArc::GetFormulaRadius1() const
  * @brief GetFormulaRadius2 return formula for minor radius.
  * @return radius.
  */
-QString VEllipticalArc::GetFormulaRadius2() const
+auto VEllipticalArc::GetFormulaRadius2() const -> QString
 {
     return d->formulaRadius2;
 }
@@ -581,7 +865,7 @@ QString VEllipticalArc::GetFormulaRadius2() const
  * @brief GetFormulaRotationAngle return formula for rotation angle.
  * @return rotationAngle.
  */
-QString VEllipticalArc::GetFormulaRotationAngle() const
+auto VEllipticalArc::GetFormulaRotationAngle() const -> QString
 {
     return d->formulaRotationAngle;
 }
@@ -633,7 +917,7 @@ void VEllipticalArc::SetRotationAngle(qreal value)
  * @brief GetRadius1 return elliptical arc major radius.
  * @return string with formula.
  */
-qreal VEllipticalArc::GetRadius1() const
+auto VEllipticalArc::GetRadius1() const -> qreal
 {
     return d->radius1;
 }
@@ -643,7 +927,7 @@ qreal VEllipticalArc::GetRadius1() const
  * @brief GetRadius2 return elliptical arc minor radius.
  * @return string with formula.
  */
-qreal VEllipticalArc::GetRadius2() const
+auto VEllipticalArc::GetRadius2() const -> qreal
 {
     return d->radius2;
 }
@@ -653,7 +937,7 @@ qreal VEllipticalArc::GetRadius2() const
  * @brief GetRotationAngle return rotation angle.
  * @return rotationAngle.
  */
-qreal VEllipticalArc::GetRotationAngle() const
+auto VEllipticalArc::GetRotationAngle() const -> qreal
 {
     return d->rotationAngle;
 }
