@@ -34,6 +34,10 @@
 #include <QPushButton>
 #include <QShowEvent>
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
+#include "../vmisc/backport/qoverload.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
+
 //---------------------------------------------------------------------------------------------------------------------
 DialogLayoutScale::DialogLayoutScale(bool printTiled, QWidget *parent)
     :QDialog(parent),
@@ -44,6 +48,7 @@ DialogLayoutScale::DialogLayoutScale(bool printTiled, QWidget *parent)
     VAbstractApplication::VApp()->Settings()->GetOsSeparator() ? setLocale(QLocale()) : setLocale(QLocale::c());
 
     QPushButton *bOk = ui->buttonBox->button(QDialogButtonBox::Ok);
+    // cppcheck-suppress unknownMacro
     SCASSERT(bOk != nullptr)
     connect(bOk, &QPushButton::clicked, this, &DialogLayoutScale::Save);
 
