@@ -34,7 +34,9 @@
 #include <QCoreApplication>
 #include <QUuid>
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #include "../vmisc/diagnostic.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
 #   include "../vmisc/vdatastreamenum.h"
 #endif
@@ -47,7 +49,7 @@ QT_WARNING_DISABLE_GCC("-Wnon-virtual-dtor")
 
 class VAbstractPieceData : public QSharedData
 {
-    Q_DECLARE_TR_FUNCTIONS(VAbstractPieceData)
+    Q_DECLARE_TR_FUNCTIONS(VAbstractPieceData) // NOLINT
 public:
     VAbstractPieceData()
     {}
@@ -67,7 +69,7 @@ public:
           m_uuid(piece.m_uuid)
     {}
 
-    ~VAbstractPieceData() Q_DECL_EQ_DEFAULT;
+    ~VAbstractPieceData() = default;
 
     friend QDataStream& operator<<(QDataStream& dataStream, const VAbstractPieceData& piece);
     friend QDataStream& operator>>(QDataStream& dataStream, VAbstractPieceData& piece);
