@@ -59,7 +59,7 @@ public:
 
     VLayoutPaper &operator=(const VLayoutPaper &paper);
 #ifdef Q_COMPILER_RVALUE_REFS
-    VLayoutPaper(const VLayoutPaper &&paper) Q_DECL_NOTHROW;
+    VLayoutPaper(VLayoutPaper &&paper) Q_DECL_NOTHROW;
     VLayoutPaper &operator=(VLayoutPaper &&paper) Q_DECL_NOTHROW;
 #endif
 
@@ -117,6 +117,6 @@ private:
 
 };
 
-Q_DECLARE_TYPEINFO(VLayoutPaper, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(VLayoutPaper, Q_MOVABLE_TYPE); // NOLINT
 
 #endif // VLAYOUTPAPER_H
