@@ -37,7 +37,9 @@
 #include "../vpatterndb/floatItemData/vpiecelabeldata.h"
 #include "../vpatterndb/floatItemData/vpatternlabeldata.h"
 #include "../vpatterndb/floatItemData/vgrainlinedata.h"
+#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #include "../vmisc/diagnostic.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
 #   include "../vmisc/vdatastreamenum.h"
 #endif
@@ -83,7 +85,7 @@ public:
           m_yScale(detail.m_yScale)
     {}
 
-    ~VLayoutPieceData() Q_DECL_EQ_DEFAULT;
+    ~VLayoutPieceData() = default;
 
     friend QDataStream& operator<<(QDataStream& dataStream, const VLayoutPieceData& piece);
     friend QDataStream& operator>>(QDataStream& dataStream, VLayoutPieceData& piece);
