@@ -120,7 +120,7 @@ QPixmap WatermarkImageFromCache(const VWatermarkData &watermarkData, const QStri
 
 //---------------------------------------------------------------------------------------------------------------------
 VPoster::VPoster(const QPrinter *printer)
-    :printer(printer), allowance(static_cast<quint32>(qRound(10./25.4*PrintDPI)))//1 cm
+    :printer(printer), allowance(static_cast<quint32>(qRound(CmToPixel(1.))))
 {
 }
 
@@ -157,7 +157,11 @@ QVector<QGraphicsItem *> VPoster::Tile(QGraphicsItem *parent, const PosterData &
                                        const VWatermarkData &watermarkData, const QString &watermarkPath) const
 {
     QVector<QGraphicsItem *> data;
+#if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
     data.append(Borders(parent, img, sheets));
+#else
+    data += Borders(parent, img, sheets);
+#endif
 
     if (watermarkData.opacity > 0)
     {
