@@ -42,7 +42,7 @@ struct VWatermarkData;
 
 class VPrintLayout : public QObject
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 public:
     explicit VPrintLayout(QObject *parent = nullptr);
     virtual ~VPrintLayout();
@@ -122,12 +122,13 @@ public:
 
     static auto ContinueIfLayoutStale(QWidget *parent) -> int;
     static auto SceneTargetRect(QPrinter *printer, const QRectF &source) -> QRectF;
+    static auto PrinterScaleDiff(QPrinter *printer) -> QPair<qreal, qreal>;
 
 private slots:
     void PrintPages (QPrinter *printer);
 
 private:
-    Q_DISABLE_COPY(VPrintLayout)
+    Q_DISABLE_COPY_MOVE(VPrintLayout) // NOLINT
 
     QString         m_fileName{};
     QSizeF          m_layoutPaperSize{};
