@@ -51,7 +51,7 @@ const quint16 TextLine::classVersion = 1;
 
 // Friend functions
 //---------------------------------------------------------------------------------------------------------------------
-QDataStream& operator<<(QDataStream &dataStream, const TextLine &data)
+auto operator<<(QDataStream &dataStream, const TextLine &data) -> QDataStream&
 {
     dataStream << TextLine::streamHeader << TextLine::classVersion;
 
@@ -68,7 +68,7 @@ QDataStream& operator<<(QDataStream &dataStream, const TextLine &data)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QDataStream& operator>>(QDataStream &dataStream, TextLine &data)
+auto operator>>(QDataStream &dataStream, TextLine &data) -> QDataStream&
 {
     quint32 actualStreamHeader = 0;
     dataStream >> actualStreamHeader;
@@ -113,7 +113,7 @@ const quint16 VTextManager::classVersion = 1;
 
 // Friend functions
 //---------------------------------------------------------------------------------------------------------------------
-QDataStream& operator<<(QDataStream &dataStream, const VTextManager &data)
+auto operator<<(QDataStream &dataStream, const VTextManager &data) -> QDataStream&
 {
     dataStream << VTextManager::streamHeader << VTextManager::classVersion;
 
@@ -127,7 +127,7 @@ QDataStream& operator<<(QDataStream &dataStream, const VTextManager &data)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QDataStream& operator>>(QDataStream &dataStream, VTextManager &data)
+auto operator>>(QDataStream &dataStream, VTextManager &data) -> QDataStream&
 {
     quint32 actualStreamHeader = 0;
     dataStream >> actualStreamHeader;
@@ -167,7 +167,7 @@ namespace
 {
 
 //---------------------------------------------------------------------------------------------------------------------
-QMap<QString, QString> PreparePlaceholders(const VAbstractPattern *doc, const VContainer *data)
+auto PreparePlaceholders(const VAbstractPattern *doc, const VContainer *data) -> QMap<QString, QString>
 {
     SCASSERT(doc != nullptr)
     SCASSERT(data != nullptr)
@@ -217,15 +217,19 @@ QMap<QString, QString> PreparePlaceholders(const VAbstractPattern *doc, const VC
 
     QString heightValue = QString::number(VAbstractValApplication::VApp()->GetDimensionHeight());
     placeholders.insert(pl_height, heightValue);
+    placeholders.insert(pl_dimensionX, heightValue);
 
     QString sizeValue = QString::number(VAbstractValApplication::VApp()->GetDimensionSize());
     placeholders.insert(pl_size, sizeValue);
+    placeholders.insert(pl_dimensionY, sizeValue);
 
     QString hipValue = QString::number(VAbstractValApplication::VApp()->GetDimensionHip());
     placeholders.insert(pl_hip, hipValue);
+    placeholders.insert(pl_dimensionZ, hipValue);
 
     QString waistValue = QString::number(VAbstractValApplication::VApp()->GetDimensionWaist());
     placeholders.insert(pl_waist, waistValue);
+    placeholders.insert(pl_dimensionW, waistValue);
 
     {
         QString label = VAbstractValApplication::VApp()->GetDimensionHeightLabel();
@@ -331,7 +335,7 @@ void InitPiecePlaceholders(QMap<QString, QString> &placeholders, const QString &
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString ReplacePlaceholders(const QMap<QString, QString> &placeholders, QString line)
+auto ReplacePlaceholders(const QMap<QString, QString> &placeholders, QString line) -> QString
 {
     QChar per('%');
 
@@ -349,6 +353,11 @@ QString ReplacePlaceholders(const QMap<QString, QString> &placeholders, QString
     TestDimension(pl_hip, QObject::tr("No data for the hip dimension."));
     TestDimension(pl_waist, QObject::tr("No data for the waist dimension."));
 
+    TestDimension(pl_dimensionX, QObject::tr("No data for the X dimension."));
+    TestDimension(pl_dimensionY, QObject::tr("No data for the Y dimension."));
+    TestDimension(pl_dimensionZ, QObject::tr("No data for the Z dimension."));
+    TestDimension(pl_dimensionW, QObject::tr("No data for the W dimension."));
+
     auto i = placeholders.constBegin();
     while (i != placeholders.constEnd())
     {
@@ -359,7 +368,7 @@ QString ReplacePlaceholders(const QMap<QString, QString> &placeholders, QString
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<TextLine> PrepareLines(const QVector<VLabelTemplateLine> &lines)
+auto PrepareLines(const QVector<VLabelTemplateLine> &lines) -> QVector<TextLine>
 {
     QVector<TextLine> textLines;
 
@@ -412,7 +421,7 @@ VTextManager &VTextManager::operator=(const VTextManager &text)
  * @brief GetSpacing returns the vertical spacing between the lines
  * @return spacing
  */
-int VTextManager::GetSpacing() const
+auto VTextManager::GetSpacing() const -> int
 {
     return 0;
 }
@@ -432,7 +441,7 @@ void VTextManager::SetFont(const QFont& font)
  * @brief GetFont returns the text base font
  * @return text base font
  */
-const QFont& VTextManager::GetFont() const
+auto VTextManager::GetFont() const -> const QFont&
 {
     return m_font;
 }
@@ -448,17 +457,23 @@ void VTextManager::SetFontSize(int iFS)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<TextLine> VTextManager::GetAllSourceLines() const
+auto VTextManager::GetAllSourceLines() const -> QVector<TextLine>
 {
     return m_liLines;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VTextManager::SetAllSourceLines(const QVector<TextLine> &lines)
+{
+    m_liLines = lines;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief VTextManager::GetSourceLinesCount returns the number of input text lines
  * @return number of text lines that were added to the list by calling AddLine
  */
-int VTextManager::GetSourceLinesCount() const
+auto VTextManager::GetSourceLinesCount() const -> int
 {
     return m_liLines.count();
 }
@@ -469,13 +484,41 @@ int VTextManager::GetSourceLinesCount() const
  * @param i index of the requested line
  * @return reference to the requested TextLine object
  */
-const TextLine& VTextManager::GetSourceLine(int i) const
+auto VTextManager::GetSourceLine(int i) const -> const TextLine&
 {
     Q_ASSERT(i >= 0);
     Q_ASSERT(i < m_liLines.count());
     return m_liLines.at(i);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto VTextManager::MaxLineWidth(int width) const -> int
+{
+    int maxWidth = 0;
+    for (int i = 0; i < m_liLines.count(); ++i)
+    {
+        const TextLine& tl = m_liLines.at(i);
+
+        QFont fnt = m_font;
+        fnt.setPixelSize(fnt.pixelSize() + tl.m_iFontSize);
+        fnt.setBold(tl.m_bold);
+        fnt.setItalic(tl.m_italic);
+
+        QFontMetrics fm(fnt);
+
+        QString qsText = tl.m_qsText;
+
+        if (TextWidth(fm, qsText) > width)
+        {
+            qsText = fm.elidedText(qsText, Qt::ElideMiddle, width);
+        }
+
+        maxWidth = qMax(TextWidth(fm, qsText), maxWidth);
+    }
+
+    return maxWidth;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief VTextManager::FitFontSize sets the font size just big enough, so that the text fits into rectangle of
@@ -509,11 +552,7 @@ void VTextManager::FitFontSize(qreal fW, qreal fH)
         fnt.setBold(tl.m_bold);
         fnt.setItalic(tl.m_italic);
         QFontMetrics fm(fnt);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
-        const int iTW = fm.horizontalAdvance(tl.m_qsText);
-#else
-        const int iTW = fm.width(tl.m_qsText);
-#endif
+        const int iTW = TextWidth(fm, tl.m_qsText);
         if (iTW > iMaxLen)
         {
             iMaxLen = iTW;
@@ -532,11 +571,7 @@ void VTextManager::FitFontSize(qreal fW, qreal fH)
             --iFS;
             fnt.setPixelSize(iFS + maxLine.m_iFontSize);
             QFontMetrics fm(fnt);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
-            lineLength = fm.horizontalAdvance(maxLine.m_qsText);
-#else
-            lineLength = fm.width(maxLine.m_qsText);
-#endif
+            lineLength = TextWidth(fm, maxLine.m_qsText);
         }
         while (lineLength > fW && iFS > MIN_FONT_SIZE);
     }
