@@ -34,6 +34,10 @@
 #include <QVector>
 #include <QFontMetrics>
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
+#include "diagnostic.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
+
 class QPointF;
 
 // Contains helpful methods to hide version dependent code. It can be deprecation of method or change in API
@@ -104,6 +108,13 @@ inline auto ConvertToList(const C<T> &container) -> QList<T>
 #endif
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+template <typename T, template <typename> class C>
+inline auto ConvertToStringList(const C<T> &container) -> QStringList
+{
+    return {ConvertToList(container)};
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 template <typename T, template <typename> class C>
 inline auto ConvertToSet(const C<T> &container) -> QSet<T>
@@ -165,6 +176,7 @@ template <typename T>
 inline void Move(T &vector, int from, int to)
 {
     QT_WARNING_PUSH
+    // cppcheck-suppress unknownMacro
     QT_WARNING_DISABLE_GCC("-Wstrict-overflow")
 
 #if QT_VERSION < QT_VERSION_CHECK(5, 6, 0)
