@@ -64,12 +64,9 @@
 #include "../ifc/exception/vexception.h"
 #include "literals.h"
 
-const qreal   defCurveApproximationScale = 0.5;
-const qreal   minCurveApproximationScale = 0.2;
-const qreal   maxCurveApproximationScale = 10.0;
-
-const int minLabelFontSize = 5;
-const int maxLabelFontSize = 100;
+#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
+#include "../vmisc/diagnostic.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 
 //---------------------------------------------------------------------------------------------------------------------
 QPixmap QPixmapFromCache(const QString &pixmapPath)
@@ -240,8 +237,38 @@ void ShowInGraphicalShell(const QString &filePath)
 #elif defined(Q_OS_WIN)
     QProcess::startDetached(QStringLiteral("explorer"), QStringList{"/select", QDir::toNativeSeparators(filePath)});
 #else
-    // we cannot select a file here, because no file browser really supports it...
-    QDesktopServices::openUrl(QUrl::fromLocalFile(QFileInfo(filePath).path()));
+    const int timeout = 1000; // ms
+    QString command = QStringLiteral("dbus-send --reply-timeout=%1 --session --dest=org.freedesktop.FileManager1 "
+                                     "--type=method_call /org/freedesktop/FileManager1 "
+                                     "org.freedesktop.FileManager1.ShowItems array:string:\"%2\" string:\"\"")
+                          .arg(timeout).arg(QUrl::fromLocalFile(filePath).toString());
+
+    // Sending message through dbus will highlighting file
+    QProcess dbus;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    QT_WARNING_PUSH
+    QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
+    QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
+
+    dbus.start(command); // clazy:exclude=qt6-deprecated-api-fixes
+
+    QT_WARNING_POP
+#else
+    dbus.startCommand(command);
+#endif
+    if (not dbus.waitForStarted(timeout))
+    {
+        // This way will open only window without highlighting file
+        QDesktopServices::openUrl(QUrl::fromLocalFile(QFileInfo(filePath).path()));
+        return;
+    }
+
+    if (not dbus.waitForFinished(timeout))
+    {
+        // This way will open only window without highlighting file
+        QDesktopServices::openUrl(QUrl::fromLocalFile(QFileInfo(filePath).path()));
+        return;
+    }
 #endif
 }
 
@@ -281,11 +308,11 @@ void InitHighDpiScaling(int argc, char *argv[])
     }
 }
 
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, strTMark, (QLatin1String("tMark")))
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, strVMark, (QLatin1String("vMark")))
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, strVMark2, (QLatin1String("vMark2")))
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, strUMark, (QLatin1String("uMark")))
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, strBoxMark, (QLatin1String("boxMark")))
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, strTMark, (QLatin1String("tMark"))) // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, strVMark, (QLatin1String("vMark"))) // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, strVMark2, (QLatin1String("vMark2"))) // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, strUMark, (QLatin1String("uMark"))) // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, strBoxMark, (QLatin1String("boxMark"))) // NOLINT
 
 //---------------------------------------------------------------------------------------------------------------------
 QString PassmarkLineTypeToString(PassmarkLineType type)
@@ -473,7 +500,7 @@ void InitLanguages(QComboBox *combobox)
     combobox->clear();
 
     QStringList fileNames;
-    QDirIterator it(VAbstractApplication::VApp()->translationsPath(), QStringList("valentina_*.qm"), QDir::Files,
+    QDirIterator it(VAbstractApplication::translationsPath(), QStringList("valentina_*.qm"), QDir::Files,
                     QDirIterator::Subdirectories);
     while (it.hasNext())
     {
