@@ -45,6 +45,9 @@
 
 #include "debugbreak.h"
 #include "defglobal.h"
+#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
+#include "diagnostic.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 
 template <class T> class QSharedPointer;
 
@@ -71,13 +74,14 @@ class QMarginsF;
 class VTranslateMeasurements;
 class QGraphicsItem;
 
-#define SceneSize 50000  
-extern const qreal   defCurveApproximationScale;
-extern const qreal   minCurveApproximationScale;
-extern const qreal   maxCurveApproximationScale;
+constexpr qreal maxSceneSize = ((20.0 * 1000.0) / 25.4) * PrintDPI; // 20 meters in pixels
 
-extern const int minLabelFontSize;
-extern const int maxLabelFontSize;
+constexpr qreal defCurveApproximationScale = 0.5;
+constexpr qreal minCurveApproximationScale = 0.2;
+constexpr qreal maxCurveApproximationScale = 10.0;
+
+constexpr int minLabelFontSize = 5;
+constexpr int maxLabelFontSize = 100;
 
 enum class NodeDetail : qint8 { Contour, Modeling };
 enum class SceneObject : qint8 { Point, Line, Spline, Arc, ElArc, SplinePath, Detail, Unknown };
@@ -371,17 +375,21 @@ const int userMaterialPlaceholdersQuantity = 20;
 QPixmap QPixmapFromCache(const QString &pixmapPath);
 void SetItemOverrideCursor(QGraphicsItem *item, const QString & pixmapPath, int hotX = -1, int hotY = -1);
 
+template<typename T> constexpr inline auto MmToPixel(T val) -> T { return (val / 25.4) * PrintDPI; }
+template<typename T> constexpr inline auto CmToPixel(T val) -> T { return ((val * 10.0) / 25.4) * PrintDPI; }
+template<typename T> constexpr inline auto InchToPixel(T val) -> T { return val * PrintDPI; }
+
 //---------------------------------------------------------------------------------------------------------------------
-Q_DECL_RELAXED_CONSTEXPR inline double ToPixel(double val, const Unit &unit)
+Q_DECL_RELAXED_CONSTEXPR inline auto ToPixel(double val, const Unit &unit) -> double
 {
     switch (unit)
     {
         case Unit::Mm:
-            return (val / 25.4) * PrintDPI;
+            return MmToPixel(val);
         case Unit::Cm:
-            return ((val * 10.0) / 25.4) * PrintDPI;
+            return CmToPixel(val);
         case Unit::Inch:
-            return val * PrintDPI;
+            return InchToPixel(val);
         case Unit::Px:
             return val;
         default:
@@ -390,17 +398,21 @@ Q_DECL_RELAXED_CONSTEXPR inline double ToPixel(double val, const Unit &unit)
     return 0;
 }
 
+template<typename T> constexpr inline auto PixelToMm(T pix) -> T { return (pix / PrintDPI) * 25.4; }
+template<typename T> constexpr inline auto PixelToCm(T pix) -> T { return ((pix / PrintDPI) * 25.4) / 10.0; }
+template<typename T> constexpr inline auto PixelToInch(T pix) -> T { return pix / PrintDPI; }
+
 //---------------------------------------------------------------------------------------------------------------------
-Q_DECL_RELAXED_CONSTEXPR inline double FromPixel(double pix, const Unit &unit)
+Q_DECL_RELAXED_CONSTEXPR inline auto FromPixel(double pix, const Unit &unit) -> double
 {
     switch (unit)
     {
         case Unit::Mm:
-            return (pix / PrintDPI) * 25.4;
+            return PixelToMm(pix);
         case Unit::Cm:
-            return ((pix / PrintDPI) * 25.4) / 10.0;
+            return PixelToCm(pix);
         case Unit::Inch:
-            return pix / PrintDPI;
+            return PixelToInch(pix);
         case Unit::Px:
             return pix;
         default:
@@ -410,7 +422,7 @@ Q_DECL_RELAXED_CONSTEXPR inline double FromPixel(double pix, const Unit &unit)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-Q_DECL_RELAXED_CONSTEXPR inline qreal UnitConvertor(qreal value, const Unit &from, const Unit &to)
+Q_DECL_RELAXED_CONSTEXPR inline auto UnitConvertor(qreal value, const Unit &from, const Unit &to) -> qreal
 {
     switch (from)
     {
@@ -485,14 +497,15 @@ Q_DECL_RELAXED_CONSTEXPR inline qreal UnitConvertor(qreal value, const Unit &fro
  * @brief UnitConvertor Converts the values of the given margin from given unit to the new unit.
  * returns a new instand of QMarginsF.
  */
-Q_DECL_RELAXED_CONSTEXPR inline QMarginsF UnitConvertor(const QMarginsF &margins, const Unit &from, const Unit &to)
+Q_DECL_RELAXED_CONSTEXPR inline auto UnitConvertor(const QMarginsF &margins, const Unit &from,
+                                                   const Unit &to) -> QMarginsF
 {
     const qreal left = UnitConvertor(margins.left(), from, to);
     const qreal top = UnitConvertor(margins.top(), from, to);
     const qreal right = UnitConvertor(margins.right(), from, to);
     const qreal bottom = UnitConvertor(margins.bottom(), from, to);
 
-    return QMarginsF(left, top, right, bottom);
+    return {left, top, right, bottom};
 }
 
 void InitLanguages(QComboBox *combobox);
@@ -556,7 +569,7 @@ private:
 };
 
 Q_DECLARE_METATYPE(CustomSARecord)
-Q_DECLARE_TYPEINFO(CustomSARecord, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(CustomSARecord, Q_MOVABLE_TYPE); // NOLINT
 /****************************************************************************
 ** This file is derived from code bearing the following notice:
 ** The sole author of this file, Adam Higerd, has explicitly disclaimed all
@@ -611,10 +624,11 @@ protected:
     }
 
 private:
-    Q_DISABLE_COPY(QxtPrivate)
+    Q_DISABLE_COPY_MOVE(QxtPrivate) // NOLINT
     PUB* qxt_p_ptr;
 };
 
+// cppcheck-suppress unknownMacro
 QT_WARNING_POP
 
 template <typename PUB, typename PVT>
@@ -650,7 +664,7 @@ public:
     return static_cast<PVT*>(pvt);
     }
 private:
-    Q_DISABLE_COPY(QxtPrivateInterface)
+    Q_DISABLE_COPY_MOVE(QxtPrivateInterface) // NOLINT
     QxtPrivate<PUB>* pvt;
 };
 
