@@ -41,7 +41,9 @@
 #include <QTextStream>
 #include <Qt>
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #include "../vmisc/diagnostic.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 
 class QxtCsvModelPrivate : public QxtPrivate<QxtCsvModel>
 {
@@ -49,7 +51,7 @@ public:
     QxtCsvModelPrivate() : csvData(), header(), maxColumn(0), quoteMode(QxtCsvModel::DefaultQuoteMode)
     {}
     QXT_DECLARE_PUBLIC(QxtCsvModel)
-    virtual ~QxtCsvModelPrivate() Q_DECL_EQ_DEFAULT;
+    virtual ~QxtCsvModelPrivate() = default;
 
     QList<QStringList> csvData;
     QStringList header;
@@ -57,7 +59,7 @@ public:
     QxtCsvModel::QuoteMode quoteMode;
 
 private:
-    Q_DISABLE_COPY(QxtCsvModelPrivate)
+    Q_DISABLE_COPY_MOVE(QxtCsvModelPrivate) // NOLINT
 };
 
 QT_WARNING_PUSH
@@ -584,7 +586,6 @@ static QString qxt_addCsvQuotes(QxtCsvModel::QuoteMode mode, QString field)
   Fields in the output file will be separated by \a separator. Set \a withHeader to true
   to output a row of headers at the top of the file.
  */
-// cppcheck-suppress funcArgNamesDifferent
 bool QxtCsvModel::toCSV(QIODevice* dest, QString &error, bool withHeader, QChar separator, QTextCodec* codec) const
 {
     const QxtCsvModelPrivate& d_ptr = qxt_d();
@@ -707,7 +708,6 @@ void QxtCsvModel::setQuoteMode(QuoteMode mode)
   */
 void QxtCsvModel::setText(int row, int column, const QString& value)
 {
-// cppcheck-suppress indexCalled
     setData(index(row, column), value);
 }
 
@@ -718,7 +718,6 @@ void QxtCsvModel::setText(int row, int column, const QString& value)
   */
 QString QxtCsvModel::text(int row, int column) const
 {
-// cppcheck-suppress indexCalled
     return data(index(row, column)).toString();
 }
 
