@@ -38,7 +38,10 @@
 #include <QString>
 #include <stdint.h>
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #include "../vmisc/diagnostic.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
+#include "../vmisc/defglobal.h"
 
 #include <QFileInfo>
 #include <QLockFile>
@@ -70,14 +73,14 @@ public:
     QString         GetLockFile() const;
 
 private:
-    Q_DISABLE_COPY(VLockGuard<Guarded>)
+    // cppcheck-suppress unknownMacro
+    Q_DISABLE_COPY_MOVE(VLockGuard<Guarded>) // NOLINT
 
     QSharedPointer<Guarded>   holder;
     int                       lockError;
     QString                   lockFile;
     QSharedPointer<QLockFile> lock;
 
-    // cppcheck-suppress functionStatic
     bool TryLock(const QString &lockName, int stale, int timeout);
 };
 
