@@ -61,14 +61,14 @@ class Calculator final : public qmu::QmuFormulaBase
 {
 public:
     Calculator();
-    virtual ~Calculator() Q_DECL_EQ_DEFAULT;
+    virtual ~Calculator() = default;
 
     qreal EvalFormula(const QHash<QString, QSharedPointer<VInternalVariable> > *vars, const QString &formula);
 protected:
     static qreal* VarFactory(const QString &a_szName, void *a_pUserData);
     static qreal Warning(const QString &warningMsg, qreal value);
 private:
-    Q_DISABLE_COPY(Calculator)
+    Q_DISABLE_COPY_MOVE(Calculator) // NOLINT
     QVector<QSharedPointer<qreal>> m_varsValues;
     const QHash<QString, QSharedPointer<VInternalVariable> > *m_vars;
 };
