@@ -31,16 +31,18 @@
 
 #include <QPointF>
 #include <QSharedData>
+#include <QString>
 
-#include "../vmisc/diagnostic.h"
+#include "../vmisc/typedef.h"
 #include "../vmisc/defglobal.h"
-#include "../ifc/ifcdef.h"
+#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
+#include "../vmisc/diagnostic.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_GCC("-Weffc++")
 QT_WARNING_DISABLE_GCC("-Wnon-virtual-dtor")
 
-// cppcheck-suppress copyCtorAndEqOperator
 class VPatternLabelDataPrivate : public QSharedData
 {
 public:
@@ -65,7 +67,7 @@ public:
           m_bottomRightPin(data.m_bottomRightPin)
     {}
 
-    ~VPatternLabelDataPrivate() Q_DECL_EQ_DEFAULT;
+    ~VPatternLabelDataPrivate() = default;
 
     /** @brief m_dLabelWidth formula to calculate the width of label */
     QString m_dLabelWidth;
