@@ -31,15 +31,12 @@
 
 #include <QSharedData>
 
-#include "../ifc/ifcdef.h"
-#include "../vmisc/diagnostic.h"
 #include "../vmisc/defglobal.h"
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_GCC("-Weffc++")
 QT_WARNING_DISABLE_GCC("-Wnon-virtual-dtor")
 
-// cppcheck-suppress copyCtorAndEqOperator
 class VCurveVariableData final : public QSharedData
 {
 public:
