@@ -33,7 +33,9 @@
 
 #include "../ifc/ifcdef.h"
 #include "../vcontainer.h"
+#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #include "../vmisc/diagnostic.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_GCC("-Weffc++")
@@ -70,7 +72,8 @@ public:
           formulaOk(incr.formulaOk),
           previewCalculation(incr.previewCalculation),
           data(incr.data),
-          incrType(incr.incrType)
+          incrType(incr.incrType),
+          specialUnits(incr.specialUnits)
     {}
 
     virtual  ~VIncrementData();
@@ -82,6 +85,7 @@ public:
     bool    previewCalculation{false};
     QSharedPointer<VContainer> data;
     IncrementType incrType{IncrementType::Increment};
+    bool specialUnits{false};
 
 private:
     Q_DISABLE_ASSIGN(VIncrementData)
