@@ -53,6 +53,7 @@ VLineAngle::VLineAngle(const VPointF *p1, const quint32 &p1Id, const VPointF *p2
 {
     SetType(VarType::LineAngle);
 
+    // cppcheck-suppress unknownMacro
     SCASSERT(p1 != nullptr)
     SCASSERT(p2 != nullptr)
 
@@ -78,8 +79,8 @@ VLineAngle &VLineAngle::operator=(const VLineAngle &var)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VLineAngle::VLineAngle(const VLineAngle &&var) Q_DECL_NOTHROW
-    :VInternalVariable(var), d(var.d)
+VLineAngle::VLineAngle(VLineAngle &&var) Q_DECL_NOTHROW
+    :VInternalVariable(std::move(var)), d(std::move(var.d))
 {}
 
 #ifdef Q_COMPILER_RVALUE_REFS
