@@ -31,15 +31,13 @@
 
 #include <QSharedData>
 
-#include "../ifc/ifcdef.h"
-#include "../vmisc/diagnostic.h"
 #include "../vmisc/defglobal.h"
+#include "../vmisc/typedef.h"
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_GCC("-Weffc++")
 QT_WARNING_DISABLE_GCC("-Wnon-virtual-dtor")
 
-// cppcheck-suppress copyCtorAndEqOperator
 class VLineAngleData final : public QSharedData
 {
 public:
