@@ -31,19 +31,17 @@
 
 #include <QSharedData>
 
-#include "../ifc/ifcdef.h"
-#include "../vmisc/diagnostic.h"
 #include "../vmisc/defglobal.h"
+#include "../vmisc/def.h"
+#include "../vmisc/typedef.h"
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_GCC("-Weffc++")
 QT_WARNING_DISABLE_GCC("-Wnon-virtual-dtor")
 
-// cppcheck-suppress copyCtorAndEqOperator
 class VLengthLineData final : public QSharedData
 {
 public:
-
     VLengthLineData()
         :p1Id(NULL_ID), p2Id(NULL_ID), patternUnit(Unit::Cm)
     {}
