@@ -31,14 +31,12 @@
 
 #include <QSharedData>
 
-#include "../vmisc/diagnostic.h"
 #include "../vmisc/defglobal.h"
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_GCC("-Weffc++")
 QT_WARNING_DISABLE_GCC("-Wnon-virtual-dtor")
 
-// cppcheck-suppress copyCtorAndEqOperator
 class VVariableData final : public QSharedData
 {
 public:
