@@ -50,7 +50,9 @@
 #include "../vgeometry/vabstractcubicbezierpath.h"
 #include "../vgeometry/vabstractcurve.h"
 #include "../vgeometry/vgobject.h"
+#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #include "../vmisc/diagnostic.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #include "variables.h"
 #include "variables/vinternalvariable.h"
 #include "vpiece.h"
@@ -121,7 +123,7 @@ QT_WARNING_POP
  */
 class VContainer
 {
-    Q_DECLARE_TR_FUNCTIONS(VContainer)
+    Q_DECLARE_TR_FUNCTIONS(VContainer) // NOLINT
 public:
     VContainer(const VTranslateVars *trVars, const Unit *patternUnit, const QString &nspace);
     VContainer(const VContainer &data);
@@ -131,7 +133,7 @@ public:
 
     VContainer &operator=(const VContainer &data);
 #ifdef Q_COMPILER_RVALUE_REFS
-    VContainer(const VContainer &&data) Q_DECL_NOTHROW;
+    VContainer(VContainer &&data) Q_DECL_NOTHROW;
     VContainer &operator=(VContainer &&data) Q_DECL_NOTHROW;
 #endif
 
@@ -246,7 +248,7 @@ private:
     static void ClearNamespace(const QString &nspace);
 };
 
-Q_DECLARE_TYPEINFO(VContainer, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(VContainer, Q_MOVABLE_TYPE); // NOLINT
 
 /*
 *  Defintion of templated member functions of VContainer
