@@ -135,8 +135,8 @@ VPiece &VPiece::operator=(const VPiece &piece)
 
 #ifdef Q_COMPILER_RVALUE_REFS
 //---------------------------------------------------------------------------------------------------------------------
-VPiece::VPiece(const VPiece &&piece) Q_DECL_NOTHROW
-    : VAbstractPiece(piece), d (piece.d)
+VPiece::VPiece(VPiece &&piece) Q_DECL_NOTHROW
+    : VAbstractPiece(std::move(piece)), d (std::move(piece.d))
 {}
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -1102,7 +1102,11 @@ VPassmark VPiece::CreatePassmark(const QVector<VPieceNode> &path, int previousIn
         const QString infoMsg = tr("Notch for point '%1' in piece '%2' will be disabled. Manual length is less than "
                                     "allowed value.")
                 .arg(VPiecePath::NodeName(path, passmarkIndex, data), GetName());
+#if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
         qInfo() << VAbstractValApplication::warningMessageSignature + infoMsg;
+#else
+        qWarning() << VAbstractValApplication::warningMessageSignature + infoMsg;
+#endif
         return VPassmark();
     }
 
