@@ -48,7 +48,6 @@
 
 //---------------------------------------------------------------------------------------------------------------------
 VTranslateVars::VTranslateVars()
-    :VTranslateMeasurements()
 {
     InitPatternMakingSystems();
     InitVariables();
@@ -399,144 +398,187 @@ void VTranslateVars::InitVariables()
 //---------------------------------------------------------------------------------------------------------------------
 void VTranslateVars::InitFunctions()
 {
+    const QString oneArgument = QStringLiteral("()");
+    const QString twoArguments = QStringLiteral("(;)");
+    const QString threeArguments = QStringLiteral("(;;)");
+
     functions.insert(degTorad_F, translate("VTranslateVars", "degTorad", "converts degrees to radian"));
     functionsDescriptions.insert(degTorad_F, translate("VTranslateVars", "converts degrees to radian",
-                                                      "functionm degTorad"));
+                                                      "function degTorad"));
+    functionsArguments.insert(degTorad_F, oneArgument);
 
     functions.insert(radTodeg_F, translate("VTranslateVars", "radTodeg", "converts radian to degrees"));
     functionsDescriptions.insert(radTodeg_F, translate("VTranslateVars", "converts radian to degrees",
                                                       "function radTodeg"));
+    functionsArguments.insert(radTodeg_F, oneArgument);
 
     functions.insert(sin_F, translate("VTranslateVars", "sin", "sine function working with radians"));
     functionsDescriptions.insert(sin_F, translate("VTranslateVars", "sine function working with radians",
                                                  "function sin"));
+    functionsArguments.insert(sin_F, oneArgument);
 
     functions.insert(cos_F, translate("VTranslateVars", "cos", "cosine function working with radians"));
     functionsDescriptions.insert(cos_F, translate("VTranslateVars", "cosine function working with radians",
                                                  "function cos"));
+    functionsArguments.insert(cos_F, oneArgument);
 
     functions.insert(tan_F, translate("VTranslateVars", "tan", "tangens function working with radians"));
     functionsDescriptions.insert(tan_F, translate("VTranslateVars", "tangens function working with radians",
                                                  "function tan"));
+    functionsArguments.insert(tan_F, oneArgument);
 
     functions.insert(asin_F, translate("VTranslateVars", "asin", "arcus sine function working with radians"));
     functionsDescriptions.insert(asin_F, translate("VTranslateVars", "arcus sine function working with radians",
                                                   "function asin"));
+    functionsArguments.insert(asin_F, oneArgument);
 
     functions.insert(acos_F, translate("VTranslateVars", "acos", "arcus cosine function working with radians"));
     functionsDescriptions.insert(acos_F, translate("VTranslateVars", "arcus cosine function working with radians",
                                                   "function acos"));
+    functionsArguments.insert(acos_F, oneArgument);
 
     functions.insert(atan_F, translate("VTranslateVars", "atan", "arcus tangens function working with radians"));
     functionsDescriptions.insert(atan_F, translate("VTranslateVars", "arcus tangens function working with radians",
                                                   "function atan"));
+    functionsArguments.insert(atan_F, oneArgument);
 
     functions.insert(sinh_F, translate("VTranslateVars", "sinh", "hyperbolic sine function"));
     functionsDescriptions.insert(sinh_F, translate("VTranslateVars", "hyperbolic sine function", "function sinh"));
+    functionsArguments.insert(sinh_F, oneArgument);
 
     functions.insert(cosh_F, translate("VTranslateVars", "cosh", "hyperbolic cosine"));
     functionsDescriptions.insert(cosh_F, translate("VTranslateVars", "hyperbolic cosine", "function cosh"));
+    functionsArguments.insert(sinh_F, oneArgument);
 
     functions.insert(tanh_F, translate("VTranslateVars", "tanh", "hyperbolic tangens function"));
     functionsDescriptions.insert(tanh_F, translate("VTranslateVars", "hyperbolic tangens function", "function tanh"));
+    functionsArguments.insert(tanh_F, oneArgument);
 
     functions.insert(asinh_F, translate("VTranslateVars", "asinh", "hyperbolic arcus sine function"));
     functionsDescriptions.insert(asinh_F, translate("VTranslateVars", "hyperbolic arcus sine function",
                                                    "function asinh"));
+    functionsArguments.insert(asinh_F, oneArgument);
 
     functions.insert(acosh_F, translate("VTranslateVars", "acosh", "hyperbolic arcus cosine function"));
     functionsDescriptions.insert(acosh_F, translate("VTranslateVars", "hyperbolic arcus cosine function",
                                                    "function acosh"));
+    functionsArguments.insert(acosh_F, oneArgument);
 
     functions.insert(atanh_F, translate("VTranslateVars", "atanh", "hyperbolic arcur tangens function"));
     functionsDescriptions.insert(atanh_F, translate("VTranslateVars", "hyperbolic arcur tangens function",
                                                    "function atanh"));
+    functionsArguments.insert(atanh_F, oneArgument);
 
     functions.insert(sinD_F, translate("VTranslateVars", "sinD", "sine function working with degrees"));
     functionsDescriptions.insert(sinD_F, translate("VTranslateVars", "sine function working with degrees",
                                                   "function sinD"));
+    functionsArguments.insert(sinD_F, oneArgument);
 
     functions.insert(cosD_F, translate("VTranslateVars", "cosD", "cosine function working with degrees"));
     functionsDescriptions.insert(cosD_F, translate("VTranslateVars", "cosine function working with degrees",
                                                   "function cosD"));
+    functionsArguments.insert(cosD_F, oneArgument);
 
     functions.insert(tanD_F, translate("VTranslateVars", "tanD", "tangens function working with degrees"));
     functionsDescriptions.insert(tanD_F, translate("VTranslateVars", "tangens function working with degrees",
                                                   "function tanD"));
+    functionsArguments.insert(tanD_F, oneArgument);
 
     functions.insert(asinD_F, translate("VTranslateVars", "asinD", "arcus sine function working with degrees"));
     functionsDescriptions.insert(asinD_F, translate("VTranslateVars", "arcus sine function working with degrees",
                                                    "function asinD"));
+    functionsArguments.insert(asinD_F, oneArgument);
 
     functions.insert(acosD_F, translate("VTranslateVars", "acosD", "arcus cosine function working with degrees"));
     functionsDescriptions.insert(acosD_F, translate("VTranslateVars", "arcus cosine function working with degrees",
                                                    "function acosD"));
+    functionsArguments.insert(acosD_F, oneArgument);
 
     functions.insert(atanD_F, translate("VTranslateVars", "atanD", "arcus tangens function working with degrees"));
     functionsDescriptions.insert(atanD_F, translate("VTranslateVars", "arcus tangens function working with degrees",
                                                    "function atanD"));
+    functionsArguments.insert(atanD_F, oneArgument);
 
     functions.insert(log2_F, translate("VTranslateVars", "log2", "logarithm to the base 2"));
     functionsDescriptions.insert(log2_F, translate("VTranslateVars", "logarithm to the base 2",  "function log2"));
+    functionsArguments.insert(log2_F, oneArgument);
 
     functions.insert(log10_F, translate("VTranslateVars", "log10", "logarithm to the base 10"));
     functionsDescriptions.insert(log10_F, translate("VTranslateVars", "logarithm to the base 10", "function log10"));
+    functionsArguments.insert(log10_F, oneArgument);
 
     functions.insert(log_F, translate("VTranslateVars", "log", "logarithm to the base 10"));
     functionsDescriptions.insert(log_F, translate("VTranslateVars", "logarithm to the base 10", "function log"));
+    functionsArguments.insert(log_F, oneArgument);
 
     functions.insert(ln_F, translate("VTranslateVars", "ln", "logarithm to base e (2.71828...)"));
     functionsDescriptions.insert(ln_F, translate("VTranslateVars", "logarithm to base e (2.71828...)", "function ln"));
+    functionsArguments.insert(ln_F, oneArgument);
 
     functions.insert(exp_F, translate("VTranslateVars", "exp", "e raised to the power of x"));
     functionsDescriptions.insert(exp_F, translate("VTranslateVars", "e raised to the power of x", "function exp"));
+    functionsArguments.insert(exp_F, oneArgument);
 
     functions.insert(sqrt_F, translate("VTranslateVars", "sqrt", "square root of a value"));
     functionsDescriptions.insert(sqrt_F, translate("VTranslateVars", "square root of a value", "function sqrt"));
+    functionsArguments.insert(sqrt_F, oneArgument);
 
     functions.insert(sign_F, translate("VTranslateVars", "sign", "sign function -1 if x<0; 1 if x>0"));
     functionsDescriptions.insert(sign_F, translate("VTranslateVars", "sign function -1 if x<0; 1 if x>0",
                                                   "function sign"));
+    functionsArguments.insert(sign_F, oneArgument);
 
     functions.insert(rint_F, translate("VTranslateVars", "rint", "round to nearest integer"));
     functionsDescriptions.insert(rint_F, translate("VTranslateVars", "round to nearest integer", "function rint"));
+    functionsArguments.insert(rint_F, oneArgument);
 
     functions.insert(r2cm_F, translate("VTranslateVars", "r2cm", "round to up to 1 decimal"));
     functionsDescriptions.insert(r2cm_F, translate("VTranslateVars", "round to up to 1 decimal", "function r2cm"));
+    functionsArguments.insert(r2cm_F, oneArgument);
 
     functions.insert(csrCm_F, translate("VTranslateVars", "csrCm", "cut, split and rotate modeling operation. Takes"
                                                                    " cm units."));
     functionsDescriptions.insert(csrCm_F, translate("VTranslateVars", "cut, split and rotate modeling operation. Takes "
                                                                      "cm units.", "function csrCm"));
+    functionsArguments.insert(csrCm_F, threeArguments);
 
     functions.insert(csrInch_F, translate("VTranslateVars", "csrInch", "cut, split and rotate modeling operation. Takes"
                                                                        " inch units."));
-    functionsDescriptions.insert(csrInch_F, translate("VTranslateVars", "cut, split and rotate modeling operation. Takes"
-                                                                       " inch units.", "function csrInch"));
+    functionsDescriptions.insert(csrInch_F, translate("VTranslateVars", "cut, split and rotate modeling operation. "
+                                                                        "Takes inch units.", "function csrInch"));
+    functionsArguments.insert(csrInch_F, threeArguments);
 
     functions.insert(abs_F, translate("VTranslateVars", "abs", "absolute value"));
     functionsDescriptions.insert(abs_F, translate("VTranslateVars", "absolute value", "function abs"));
+    functionsArguments.insert(abs_F, oneArgument);
 
     functions.insert(min_F, translate("VTranslateVars", "min", "min of all arguments"));
     functionsDescriptions.insert(min_F, translate("VTranslateVars", "min of all arguments", "function min"));
+    functionsArguments.insert(min_F, twoArguments);
 
     functions.insert(max_F, translate("VTranslateVars", "max", "max of all arguments"));
     functionsDescriptions.insert(max_F, translate("VTranslateVars", "max of all arguments", "function max"));
+    functionsArguments.insert(max_F, twoArguments);
 
     functions.insert(sum_F, translate("VTranslateVars", "sum", "sum of all arguments"));
     functionsDescriptions.insert(sum_F, translate("VTranslateVars", "sum of all arguments", "function sum"));
+    functionsArguments.insert(sum_F, threeArguments);
 
     functions.insert(avg_F, translate("VTranslateVars", "avg", "mean value of all arguments"));
     functionsDescriptions.insert(avg_F, translate("VTranslateVars", "mean value of all arguments", "function avg"));
+    functionsArguments.insert(avg_F, threeArguments);
 
     functions.insert(fmod_F, translate("VTranslateVars", "fmod",
                                        "Returns the floating-point remainder of numer/denom (rounded towards zero)"));
     functionsDescriptions.insert(fmod_F, translate("VTranslateVars", "Returns the floating-point remainder of "
                                                                     "numer/denom (rounded towards zero)",
                                                   "function fmod"));
+    functionsArguments.insert(fmod_F, twoArguments);
+
     functions.insert(warning_F, translate("VTranslateVars", "warning", "Calculation warning"));
     functionsDescriptions.insert(warning_F, translate("VTranslateVars", "Show a warning in calculations",
                                                       "function warning"));
+    functionsArguments.insert(warning_F, twoArguments);
 }
 
 #undef translate
@@ -579,7 +621,7 @@ void VTranslateVars::InitSystem(const QString &code, const qmu::QmuTranslation &
  * @param numbers all numbers
  */
 void VTranslateVars::CorrectionsPositions(int position, int bias, QMap<int, QString> &tokens,
-                                          QMap<int, QString> &numbers) const
+                                          QMap<int, QString> &numbers)
 {
     if (bias == 0)
     {
@@ -590,6 +632,188 @@ void VTranslateVars::CorrectionsPositions(int position, int bias, QMap<int, QStr
     BiasTokens(position, bias, numbers);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VTranslateVars::TranslateVarsFromUser(QString &newFormula, QMap<int, QString> &tokens,
+                                           QMap<int, QString> &numbers) const
+{
+    QList<int> tKeys = tokens.keys();// Take all tokens positions
+    QList<QString> tValues = tokens.values();
+    for (int i = 0; i < tKeys.size(); ++i)
+    {
+        int bias = 0;
+        if (MeasurementsFromUser(newFormula, tKeys.at(i), tValues.at(i), bias))
+        {
+            if (bias != 0)
+            {// Translated token has different length than original. Position of next tokens need to be corrected.
+                CorrectionsPositions(tKeys.at(i), bias, tokens, numbers);
+                tKeys = tokens.keys();
+                tValues = tokens.values();
+            }
+            continue;
+        }
+
+        if (VariablesFromUser(newFormula, tKeys.at(i), tValues.at(i), bias))
+        {
+            if (bias != 0)
+            {// Translated token has different length than original. Position of next tokens need to be corrected.
+                CorrectionsPositions(tKeys.at(i), bias, tokens, numbers);
+                tKeys = tokens.keys();
+                tValues = tokens.values();
+            }
+            continue;
+        }
+
+        if (FunctionsFromUser(newFormula, tKeys.at(i), tValues.at(i), bias))
+        {
+            if (bias != 0)
+            {// Translated token has different length than original. Position of next tokens need to be corrected.
+                CorrectionsPositions(tKeys.at(i), bias, tokens, numbers);
+                tKeys = tokens.keys();
+                tValues = tokens.values();
+            }
+            continue;
+        }
+
+        if (tValues.at(i) == QLocale().negativeSign())
+        {// unary minus
+            newFormula.replace(tKeys.at(i), 1, '-');
+        }
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VTranslateVars::TranslateNumbersFromUser(QString &newFormula, QMap<int, QString> &tokens,
+                                              QMap<int, QString> &numbers, bool osSeparator)
+{
+    QLocale loc = QLocale(); // User locale
+    if (loc != QLocale::c() && osSeparator)
+    {// User want use Os separator
+        QList<int> nKeys = numbers.keys();// Positions for all numbers in expression
+        QList<QString> nValues = numbers.values();
+        for (int i = 0; i < nKeys.size(); ++i)
+        {
+            loc = QLocale();// From system locale
+            bool ok = false;
+            const qreal d = loc.toDouble(nValues.at(i), &ok);
+            if (not ok)
+            {
+                qDebug()<<"Can't convert to double token"<<nValues.at(i);
+                continue;//Leave with out translation
+            }
+
+            loc = QLocale::c();// To internal locale
+            const QString dStr = loc.toString(d);// Internal look for number
+            newFormula.replace(nKeys.at(i), nValues.at(i).length(), dStr);
+            const int bias = nValues.at(i).length() - dStr.length();
+            if (bias != 0)
+            {// Translated number has different length than original. Position next tokens need to be corrected.
+                CorrectionsPositions(nKeys.at(i), bias, tokens, numbers);
+                nKeys = numbers.keys();
+                nValues = numbers.values();
+            }
+        }
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VTranslateVars::TranslateVarsToUser(QString &newFormula, QMap<int, QString> &tokens,
+                                         QMap<int, QString> &numbers) const
+{
+    QList<int> tKeys = tokens.keys();
+    QList<QString> tValues = tokens.values();
+    for (int i = 0; i < tKeys.size(); ++i)
+    {
+        if (measurements.contains(tValues.at(i)))
+        {
+            newFormula.replace(tKeys.at(i), tValues.at(i).length(),
+                               measurements.value(tValues.at(i))
+                                   .translate(VAbstractApplication::VApp()->Settings()->GetLocale()));
+            int bias = tValues.at(i).length() -
+                       measurements.value(tValues.at(i))
+                           .translate(VAbstractApplication::VApp()->Settings()->GetLocale()).length();
+            if (bias != 0)
+            {// Translated token has different length than original. Position next tokens need to be corrected.
+                CorrectionsPositions(tKeys.at(i), bias, tokens, numbers);
+                tKeys = tokens.keys();
+                tValues = tokens.values();
+            }
+            continue;
+        }
+
+        if (functions.contains(tValues.at(i)))
+        {
+            newFormula.replace(tKeys.at(i), tValues.at(i).length(),
+                               functions.value(tValues.at(i))
+                                   .translate(VAbstractApplication::VApp()->Settings()->GetLocale()));
+            int bias = tValues.at(i).length() -
+                       functions.value(tValues.at(i))
+                           .translate(VAbstractApplication::VApp()->Settings()->GetLocale()).length();
+            if (bias != 0)
+            {// Translated token has different length than original. Position next tokens need to be corrected.
+                CorrectionsPositions(tKeys.at(i), bias, tokens, numbers);
+                tKeys = tokens.keys();
+                tValues = tokens.values();
+            }
+            continue;
+        }
+
+        int bias = 0;
+        if (VariablesToUser(newFormula, tKeys.at(i), tValues.at(i), bias))
+        {
+            if (bias != 0)
+            {// Translated token has different length than original. Position next tokens need to be corrected.
+                CorrectionsPositions(tKeys.at(i), bias, tokens, numbers);
+                tKeys = tokens.keys();
+                tValues = tokens.values();
+            }
+            continue;
+        }
+
+        if (tValues.at(i) == QChar('-'))
+        {// unary minus
+            newFormula.replace(tKeys.at(i), 1, QLocale().negativeSign());
+        }
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VTranslateVars::TranslateNumbersToUser(QString &newFormula, QMap<int, QString> &tokens,
+                                            QMap<int, QString> &numbers, bool osSeparator)
+{
+    QLocale loc = QLocale();// User locale
+    if (loc != QLocale::C && osSeparator)
+    {// User want use Os separator
+        QList<int> nKeys = numbers.keys();// Positions for all numbers in expression
+        QList<QString> nValues = numbers.values();
+        for (int i = 0; i < nKeys.size(); ++i)
+        {
+            loc = QLocale::c();// From pattern locale
+            bool ok = false;
+            const qreal d = loc.toDouble(nValues.at(i), &ok);
+            if (not ok)
+            {
+                qDebug()<<"Can't convert to double token"<<nValues.at(i);
+                continue;//Leave with out translation
+            }
+
+            loc = QLocale();// To user locale
+            QString dStr = loc.toString(d);// Number string in user locale
+            if (loc.groupSeparator().isSpace())
+            {
+                dStr.replace(loc.groupSeparator(), QString());
+            }
+            newFormula.replace(nKeys.at(i), nValues.at(i).length(), dStr);
+            const int bias = nValues.at(i).length() - dStr.length();
+            if (bias != 0)
+            {// Translated number has different length than original. Position next tokens need to be corrected.
+                CorrectionsPositions(nKeys.at(i), bias, tokens, numbers);
+                nKeys = numbers.keys();
+                nValues = numbers.values();
+            }
+        }
+    }
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief BiasTokens change position for each token that have position more then "position".
@@ -627,7 +851,7 @@ void VTranslateVars::BiasTokens(int position, int bias, QMap<int, QString> &toke
  * @param bias hold change of length between translated and origin token string
  * @return true if was found variable with same name.
  */
-bool VTranslateVars::VariablesFromUser(QString &newFormula, int position, const QString &token, int &bias) const
+auto VTranslateVars::VariablesFromUser(QString &newFormula, int position, const QString &token, int &bias) const -> bool
 {
     const QString currentLengthTr =
             variables.value(currentLength).translate(VAbstractApplication::VApp()->Settings()->GetLocale());
@@ -668,7 +892,7 @@ bool VTranslateVars::VariablesFromUser(QString &newFormula, int position, const
  * @param bias hold change of length between translated and origin token string
  * @return true if was found function with same name.
  */
-bool VTranslateVars::FunctionsFromUser(QString &newFormula, int position, const QString &token, int &bias) const
+auto VTranslateVars::FunctionsFromUser(QString &newFormula, int position, const QString &token, int &bias) const -> bool
 {
     QMap<QString, qmu::QmuTranslation>::const_iterator i = functions.constBegin();
     while (i != functions.constEnd())
@@ -693,7 +917,7 @@ bool VTranslateVars::FunctionsFromUser(QString &newFormula, int position, const
  * @param bias hold change of length between translated and origin token string
  * @return true if was found variable with same name.
  */
-bool VTranslateVars::VariablesToUser(QString &newFormula, int position, const QString &token, int &bias) const
+auto VTranslateVars::VariablesToUser(QString &newFormula, int position, const QString &token, int &bias) const -> bool
 {
     QMap<QString, qmu::QmuTranslation>::const_iterator i = variables.constBegin();
     while (i != variables.constEnd())
@@ -721,7 +945,7 @@ bool VTranslateVars::VariablesToUser(QString &newFormula, int position, const QS
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VTranslateVars::InternalVarToUser(const QString &var) const
+auto VTranslateVars::InternalVarToUser(const QString &var) const -> QString
 {
     QString newVar = var;
     int bias = 0;
@@ -729,14 +953,12 @@ QString VTranslateVars::InternalVarToUser(const QString &var) const
     {
         return newVar;
     }
-    else
-    {
-        return var;
-    }
+
+    return var;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VTranslateVars::VarToUser(const QString &var) const
+auto VTranslateVars::VarToUser(const QString &var) const -> QString
 {
     if (VAbstractApplication::VApp()->Settings()->GetLocale() == QStringLiteral("zh_CN"))
     {
@@ -757,7 +979,7 @@ QString VTranslateVars::VarToUser(const QString &var) const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VTranslateVars::VarFromUser(const QString &var) const
+auto VTranslateVars::VarFromUser(const QString &var) const -> QString
 {
     if (VAbstractApplication::VApp()->Settings()->GetLocale() == QStringLiteral("zh_CN"))
     {
@@ -784,19 +1006,19 @@ QString VTranslateVars::VarFromUser(const QString &var) const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VTranslateVars::PMSystemName(const QString &code) const
+auto VTranslateVars::PMSystemName(const QString &code) const -> QString
 {
     return PMSystemNames.value(code).translate(VAbstractApplication::VApp()->Settings()->GetLocale());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VTranslateVars::PMSystemAuthor(const QString &code) const
+auto VTranslateVars::PMSystemAuthor(const QString &code) const -> QString
 {
     return PMSystemAuthors.value(code).translate(VAbstractApplication::VApp()->Settings()->GetLocale());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VTranslateVars::PMSystemBook(const QString &code) const
+auto VTranslateVars::PMSystemBook(const QString &code) const -> QString
 {
     return PMSystemBooks.value(code).translate(VAbstractApplication::VApp()->Settings()->GetLocale());
 }
@@ -809,98 +1031,30 @@ QString VTranslateVars::PMSystemBook(const QString &code) const
  * @throw qmu::QmuParserError in case of a wrong expression
  * @return translated expression
  */
-QString VTranslateVars::FormulaFromUser(const QString &formula, bool osSeparator) const
+auto VTranslateVars::FormulaFromUser(const QString &formula, bool osSeparator) const -> QString
 {
     if (formula.isEmpty())
     {
         return formula;
     }
-    QString newFormula = formula;// Local copy for making changes
 
     // Eval formula
-    QScopedPointer<qmu::QmuTokenParser> cal(new qmu::QmuTokenParser(formula, osSeparator, true, GetTranslatedFunctions()));
+    QScopedPointer<qmu::QmuTokenParser> cal(
+        new qmu::QmuTokenParser(formula, osSeparator, true, GetTranslatedFunctions()));
     QMap<int, QString> tokens = cal->GetTokens();// Tokens (variables, measurements)
     QMap<int, QString> numbers = cal->GetNumbers();// All numbers in expression for changing decimal separator
     delete cal.take();
 
-    QList<int> tKeys = tokens.keys();// Take all tokens positions
-    QList<QString> tValues = tokens.values();
-    for (int i = 0; i < tKeys.size(); ++i)
-    {
-        int bias = 0;
-        if (MeasurementsFromUser(newFormula, tKeys.at(i), tValues.at(i), bias))
-        {
-            if (bias != 0)
-            {// Translated token has different length than original. Position next tokens need to be corrected.
-                CorrectionsPositions(tKeys.at(i), bias, tokens, numbers);
-                tKeys = tokens.keys();
-                tValues = tokens.values();
-            }
-            continue;
-        }
+    QString newFormula = formula;// Local copy for making changes
 
-        if (VariablesFromUser(newFormula, tKeys.at(i), tValues.at(i), bias))
-        {
-            if (bias != 0)
-            {// Translated token has different length than original. Position next tokens need to be corrected.
-                CorrectionsPositions(tKeys.at(i), bias, tokens, numbers);
-                tKeys = tokens.keys();
-                tValues = tokens.values();
-            }
-            continue;
-        }
-
-        if (FunctionsFromUser(newFormula, tKeys.at(i), tValues.at(i), bias))
-        {
-            if (bias != 0)
-            {// Translated token has different length than original. Position next tokens need to be corrected.
-                CorrectionsPositions(tKeys.at(i), bias, tokens, numbers);
-                tKeys = tokens.keys();
-                tValues = tokens.values();
-            }
-            continue;
-        }
-
-        if (tValues.at(i) == QLocale().negativeSign())
-        {// unary minus
-            newFormula.replace(tKeys.at(i), 1, '-');
-        }
-    }
-
-    QLocale loc = QLocale(); // User locale
-    if (loc != QLocale::c() && osSeparator)
-    {// User want use Os separator
-        QList<int> nKeys = numbers.keys();// Positions for all numbers in expression
-        QList<QString> nValues = numbers.values();
-        for (int i = 0; i < nKeys.size(); ++i)
-        {
-            loc = QLocale();// From system locale
-            bool ok = false;
-            const qreal d = loc.toDouble(nValues.at(i), &ok);
-            if (ok == false)
-            {
-                qDebug()<<"Can't convert to double token"<<nValues.at(i);
-                continue;//Leave with out translation
-            }
-
-            loc = QLocale::c();// To internal locale
-            const QString dStr = loc.toString(d);// Internal look for number
-            newFormula.replace(nKeys.at(i), nValues.at(i).length(), dStr);
-            const int bias = nValues.at(i).length() - dStr.length();
-            if (bias != 0)
-            {// Translated number has different length than original. Position next tokens need to be corrected.
-                CorrectionsPositions(nKeys.at(i), bias, tokens, numbers);
-                nKeys = numbers.keys();
-                nValues = numbers.values();
-            }
-        }
-    }
+    TranslateVarsFromUser(newFormula, tokens, numbers);
+    TranslateNumbersFromUser(newFormula, tokens, numbers, osSeparator);
 
     return newFormula;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VTranslateVars::TryFormulaFromUser(const QString &formula, bool osSeparator)
+auto VTranslateVars::TryFormulaFromUser(const QString &formula, bool osSeparator) -> QString
 {
     try
     {
@@ -921,7 +1075,7 @@ QString VTranslateVars::TryFormulaFromUser(const QString &formula, bool osSepara
  * @param formula expression that need translate
  * @return translated expression
  */
-QString VTranslateVars::FormulaToUser(const QString &formula, bool osSeparator) const
+auto VTranslateVars::FormulaToUser(const QString &formula, bool osSeparator) const -> QString
 {
     if (formula.isEmpty())
     {
@@ -948,98 +1102,14 @@ QString VTranslateVars::FormulaToUser(const QString &formula, bool osSeparator)
         return newFormula;
     }
 
-    QList<int> tKeys = tokens.keys();
-    QList<QString> tValues = tokens.values();
-    for (int i = 0; i < tKeys.size(); ++i)
-    {
-        if (measurements.contains(tValues.at(i)))
-        {
-            newFormula.replace(tKeys.at(i), tValues.at(i).length(),
-                               measurements.value(tValues.at(i))
-                               .translate(VAbstractApplication::VApp()->Settings()->GetLocale()));
-            int bias = tValues.at(i).length() - measurements.value(tValues.at(i))
-                    .translate(VAbstractApplication::VApp()->Settings()->GetLocale()).length();
-            if (bias != 0)
-            {// Translated token has different length than original. Position next tokens need to be corrected.
-                CorrectionsPositions(tKeys.at(i), bias, tokens, numbers);
-                tKeys = tokens.keys();
-                tValues = tokens.values();
-            }
-            continue;
-        }
-
-        if (functions.contains(tValues.at(i)))
-        {
-            newFormula.replace(tKeys.at(i), tValues.at(i).length(),
-                               functions.value(tValues.at(i))
-                               .translate(VAbstractApplication::VApp()->Settings()->GetLocale()));
-            int bias = tValues.at(i).length() - functions.value(tValues.at(i))
-                    .translate(VAbstractApplication::VApp()->Settings()->GetLocale()).length();
-            if (bias != 0)
-            {// Translated token has different length than original. Position next tokens need to be corrected.
-                CorrectionsPositions(tKeys.at(i), bias, tokens, numbers);
-                tKeys = tokens.keys();
-                tValues = tokens.values();
-            }
-            continue;
-        }
-
-        int bias = 0;
-        if (VariablesToUser(newFormula, tKeys.at(i), tValues.at(i), bias))
-        {
-            if (bias != 0)
-            {// Translated token has different length than original. Position next tokens need to be corrected.
-                CorrectionsPositions(tKeys.at(i), bias, tokens, numbers);
-                tKeys = tokens.keys();
-                tValues = tokens.values();
-            }
-            continue;
-        }
-
-        if (tValues.at(i) == QChar('-'))
-        {// unary minus
-            newFormula.replace(tKeys.at(i), 1, QLocale().negativeSign());
-        }
-    }
-
-    QLocale loc = QLocale();// User locale
-    if (loc != QLocale::C && osSeparator)
-    {// User want use Os separator
-        QList<int> nKeys = numbers.keys();// Positions for all numbers in expression
-        QList<QString> nValues = numbers.values();
-        for (int i = 0; i < nKeys.size(); ++i)
-        {
-            loc = QLocale::c();// From pattern locale
-            bool ok = false;
-            const qreal d = loc.toDouble(nValues.at(i), &ok);
-            if (ok == false)
-            {
-                qDebug()<<"Can't convert to double token"<<nValues.at(i);
-                continue;//Leave with out translation
-            }
-
-            loc = QLocale();// To user locale
-            QString dStr = loc.toString(d);// Number string in user locale
-            if (loc.groupSeparator().isSpace())
-            {
-                dStr.replace(loc.groupSeparator(), QString());
-            }
-            newFormula.replace(nKeys.at(i), nValues.at(i).length(), dStr);
-            const int bias = nValues.at(i).length() - dStr.length();
-            if (bias != 0)
-            {// Translated number has different length than original. Position next tokens need to be corrected.
-                CorrectionsPositions(nKeys.at(i), bias, tokens, numbers);
-                nKeys = numbers.keys();
-                nValues = numbers.values();
-            }
-        }
-    }
+    TranslateVarsToUser(newFormula, tokens, numbers);
+    TranslateNumbersToUser(newFormula, tokens, numbers, osSeparator);
 
     return newFormula;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VTranslateVars::TryFormulaToUser(const QString &formula, bool osSeparator)
+auto VTranslateVars::TryFormulaToUser(const QString &formula, bool osSeparator) -> QString
 {
     try
     {
@@ -1073,19 +1143,25 @@ void VTranslateVars::Retranslate()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QMap<QString, QString> VTranslateVars::GetTranslatedFunctions() const
+auto VTranslateVars::GetTranslatedFunctions() const -> QMap<QString, QString>
 {
     return translatedFunctions;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QMap<QString, qmu::QmuTranslation> VTranslateVars::GetFunctions() const
+auto VTranslateVars::GetFunctions() const -> QMap<QString, qmu::QmuTranslation>
 {
     return functions;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QMap<QString, qmu::QmuTranslation> VTranslateVars::GetFunctionsDescriptions() const
+auto VTranslateVars::GetFunctionsDescriptions() const -> QMap<QString, qmu::QmuTranslation>
 {
     return functionsDescriptions;
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VTranslateVars::GetFunctionsArguments() const -> QMap<QString, QString>
+{
+    return functionsArguments;
+}
