@@ -29,4 +29,13 @@
 #  define VPROPERTYEXPLORERSHARED_EXPORT Q_DECL_IMPORT
 #endif
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
+#define Q_DISABLE_MOVE(Class) \
+Class(Class &&) = delete; \
+    Class &operator=(Class &&) = delete;
+#define Q_DISABLE_COPY_MOVE(Class) \
+Q_DISABLE_COPY(Class) \
+    Q_DISABLE_MOVE(Class)
+#endif
+
 #endif // VPROPERTYEXPLORER_GLOBAL_H
