@@ -42,6 +42,7 @@
 #include "../vgeometry/vcubicbezierpath.h"
 #include "../vgeometry/vspline.h"
 #include "../vgeometry/vsplinepath.h"
+#include "../qmuparser/qmudef.h"
 
 #include <QDialog>
 #include <QLabel>
@@ -146,8 +147,9 @@ auto DoubleCurve(const VPieceNode &firstNode, const VPieceNode &secondNode, cons
         }
 
         // The same curve, but different modeling objects
-        if (curve1->getIdObject() != NULL_ID && curve2->getIdObject() != NULL_ID &&
-                curve1->getIdObject() == curve2->getIdObject())
+        if (curve1->getMode() == Draw::Modeling && curve2->getMode() == Draw::Modeling &&
+            curve1->getIdObject() != NULL_ID && curve2->getIdObject() != NULL_ID &&
+            curve1->getIdObject() == curve2->getIdObject())
         {
             error = QObject::tr("Leave only one copy of curve '%1'").arg(curve1->name());
             return true;
@@ -198,6 +200,7 @@ void MoveCursorToEnd(QPlainTextEdit *plainTextEdit)
 //---------------------------------------------------------------------------------------------------------------------
 void DeployFormula(QDialog *dialog, QPlainTextEdit *formula, QPushButton *buttonGrowLength, int formulaBaseHeight)
 {
+    // cppcheck-suppress unknownMacro
     SCASSERT(dialog != nullptr)
     SCASSERT(formula != nullptr)
     SCASSERT(buttonGrowLength != nullptr)
