@@ -62,7 +62,6 @@
 #include "../vpatterndb/variables/vlineangle.h"
 #include "../vpatterndb/variables/vlinelength.h"
 #include "../vpatterndb/variables/vmeasurement.h"
-#include "../ifc/xml/vdomdocument.h"
 #include "../vmisc/def.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
@@ -79,14 +78,7 @@ DialogEditWrongFormula::DialogEditWrongFormula(const VContainer *data, quint32 t
       ui(new Ui::DialogEditWrongFormula),
       m_data(data),
       m_toolId(toolId),
-      formula(),
-      formulaBaseHeight(0),
-      checkZero(false),
-      checkLessThanZero(false),
-      postfix(),
-      restoreCursor(false),
-      timerFormula(new QTimer(this)),
-      flagFormula(false)
+      timerFormula(new QTimer(this))
 {
     SCASSERT(data != nullptr)
 
@@ -205,17 +197,10 @@ void DialogEditWrongFormula::ValChanged(int row)
             const QSharedPointer<VMeasurement> stable = m_data->GetVariable<VMeasurement>(name);
             SetDescription(item->text(), *stable->GetValue(), stable->IsSpecialUnits(), stable->GetGuiText());
         }
-        else if (ui->radioButtonIncrements->isChecked())
+        else if (ui->radioButtonIncrements->isChecked() || ui->radioButtonPC->isChecked())
         {
             const QSharedPointer<VIncrement> incr = m_data->GetVariable<VIncrement>(name);
-            const bool specialUnits = false;
-            SetDescription(item->text(), *incr->GetValue(), specialUnits, incr->GetDescription());
-        }
-        else if (ui->radioButtonPC->isChecked())
-        {
-            const QSharedPointer<VIncrement> incr = m_data->GetVariable<VIncrement>(name);
-            const bool specialUnits = false;
-            SetDescription(item->text(), *incr->GetValue(), specialUnits, incr->GetDescription());
+            SetDescription(item->text(), *incr->GetValue(), incr->IsSpecialUnits(), incr->GetDescription());
         }
         else if (ui->radioButtonLengthLine->isChecked())
         {
@@ -264,12 +249,10 @@ void DialogEditWrongFormula::ValChanged(int row)
  */
 void DialogEditWrongFormula::PutHere()
 {
-    const QTableWidgetItem *item = ui->tableWidget->currentItem();
+    QTableWidgetItem *item = ui->tableWidget->currentItem();
     if (item != nullptr)
     {
-        QTextCursor cursor = ui->plainTextEditFormula->textCursor();
-        cursor.insertText(ui->tableWidget->item(item->row(), ColumnName)->text());
-        ui->plainTextEditFormula->setTextCursor(cursor);
+        PutVal(item);
         ui->plainTextEditFormula->setFocus();
     }
 }
@@ -282,8 +265,20 @@ void DialogEditWrongFormula::PutHere()
 void DialogEditWrongFormula::PutVal(QTableWidgetItem *item)
 {
     SCASSERT(item != nullptr)
+    QTableWidgetItem *valItem = ui->tableWidget->item(item->row(), ColumnName);
     QTextCursor cursor = ui->plainTextEditFormula->textCursor();
-    cursor.insertText(ui->tableWidget->item(item->row(), ColumnName)->text());
+    if (ui->radioButtonFunctions->isChecked())
+    {
+        QString function = valItem->data(Qt::UserRole).toString();
+        const VTranslateVars *trVars = VAbstractApplication::VApp()->TrVars();
+        const QMap<QString, QString> functionsArguments = trVars->GetFunctionsArguments();
+        cursor.insertText(valItem->text() + functionsArguments.value(function));
+    }
+    else
+    {
+        cursor.insertText(valItem->text());
+    }
+
     ui->plainTextEditFormula->setTextCursor(cursor);
 }
 
@@ -484,10 +479,9 @@ void DialogEditWrongFormula::SetPreviewCalculationsMode()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogEditWrongFormula::GetFormula() const
+auto DialogEditWrongFormula::GetFormula() const -> QString
 {
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(formula, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(formula, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -544,7 +538,7 @@ void DialogEditWrongFormula::SetDescription(const QString &name, qreal value, bo
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal DialogEditWrongFormula::Eval(const FormulaData &formulaData, bool &flag)
+auto DialogEditWrongFormula::Eval(const FormulaData &formulaData, bool &flag) -> qreal
 {
     const qreal result = EvalToolFormula(this, formulaData, flag);
     CheckState(); // Disable Ok and Apply buttons if something wrong.
@@ -576,7 +570,7 @@ void DialogEditWrongFormula::ShowVariable(const QMap<key, val> &var)
         if (iMap.value()->Filter(m_toolId) == false)
         {// If we create this variable don't show
             ui->tableWidget->setRowCount(ui->tableWidget->rowCount() + 1);
-            QTableWidgetItem *item = new QTableWidgetItem(iMap.key());
+            auto *item = new QTableWidgetItem(iMap.key());
             QFont font = item->font();
             font.setBold(true);
             item->setFont(font);
@@ -609,16 +603,16 @@ void DialogEditWrongFormula::ShowMeasurements(const QMap<QString, QSharedPointer
         {
             continue; //skip this measurement
         }
-        if (iMap.value()->Filter(m_toolId) == false)
+        if (not iMap.value()->Filter(m_toolId))
         {// If we create this variable don't show
             ui->tableWidget->setRowCount(ui->tableWidget->rowCount() + 1);
-            QTableWidgetItem *itemName = new QTableWidgetItem(iMap.key());
+            auto *itemName = new QTableWidgetItem(iMap.key());
             QFont fontName = itemName->font();
             fontName.setBold(true);
             itemName->setFont(fontName);
             itemName->setToolTip(itemName->text());
 
-            QTableWidgetItem *itemFullName = new QTableWidgetItem();
+            auto *itemFullName = new QTableWidgetItem();
             QFont fontFullName = itemName->font();
             fontFullName.setBold(true);
             itemFullName->setFont(fontFullName);
@@ -653,15 +647,15 @@ void DialogEditWrongFormula::ShowFunctions()
     ui->tableWidget->setColumnHidden(ColumnFullName, true);
     ui->labelDescription->setText(QString());
 
-    const QMap<QString, qmu::QmuTranslation> functionsDescriptions =
-            VAbstractApplication::VApp()->TrVars()->GetFunctionsDescriptions();
-    const QMap<QString, qmu::QmuTranslation> functions = VAbstractApplication::VApp()->TrVars()->GetFunctions();
+    const VTranslateVars *trVars = VAbstractApplication::VApp()->TrVars();
+    const QMap<QString, qmu::QmuTranslation> functionsDescriptions = trVars->GetFunctionsDescriptions();
+    const QMap<QString, qmu::QmuTranslation> functions = trVars->GetFunctions();
     QMap<QString, qmu::QmuTranslation>::const_iterator i = functions.constBegin();
     while (i != functions.constEnd())
     {
         ui->tableWidget->setRowCount(ui->tableWidget->rowCount() + 1);
-        QTableWidgetItem *item =
-                new QTableWidgetItem(i.value().translate(VAbstractApplication::VApp()->Settings()->GetLocale()));
+        auto *item = new QTableWidgetItem(i.value().translate(VAbstractApplication::VApp()->Settings()->GetLocale()));
+        item->setData(Qt::UserRole, i.key());
         QFont font = item->font();
         font.setBold(true);
         item->setFont(font);
@@ -725,7 +719,7 @@ void DialogEditWrongFormula::FilterVariablesEdited(const QString &filter)
 
         // show rows with matched filter
         const QList<QTableWidgetItem*> items = ui->tableWidget->findItems(filter, Qt::MatchContains);
-        for (auto item : items)
+        for (auto *item : items)
         {
             // If filter is empty findItems() for unknown reason returns nullptr items.
             if (item)
