@@ -48,80 +48,88 @@ namespace Ui
  */
 class DialogAlongLine final : public DialogTool
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 public:
     DialogAlongLine(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
-    virtual ~DialogAlongLine() override;
+    ~DialogAlongLine() override;
 
-    QString             GetPointName() const;
-    void                SetPointName(const QString &value);
+    auto GetPointName() const -> QString;
+    void SetPointName(const QString &value);
 
-    QString             GetTypeLine() const;
-    void                SetTypeLine(const QString &value);
+    auto GetTypeLine() const -> QString;
+    void SetTypeLine(const QString &value);
 
-    QString             GetLineColor() const;
-    void                SetLineColor(const QString &value);
+    auto GetLineColor() const -> QString;
+    void SetLineColor(const QString &value);
 
-    QString             GetFormula() const;
-    void                SetFormula(const QString &value);
+    auto GetFormula() const -> QString;
+    void SetFormula(const QString &value);
 
-    quint32             GetFirstPointId() const;
-    void                SetFirstPointId(quint32 value);
+    auto GetFirstPointId() const -> quint32;
+    void SetFirstPointId(quint32 value);
 
-    quint32             GetSecondPointId() const;
-    void                SetSecondPointId(quint32 value);
+    auto GetSecondPointId() const -> quint32;
+    void SetSecondPointId(quint32 value);
 
-    void    SetNotes(const QString &notes);
-    QString GetNotes() const;
+    void SetNotes(const QString &notes);
+    auto GetNotes() const -> QString;
 
-    virtual void        Build(const Tool &type) override;
+    void Build(const Tool &type) override;
+    void ShowDialog(bool click) override;
 public slots:
-    virtual void        ChosenObject(quint32 id, const SceneObject &type) override;
+    void ChosenObject(quint32 id, const SceneObject &type) override;
     /**
      * @brief DeployFormulaTextEdit grow or shrink formula input
      */
-    void                DeployFormulaTextEdit();
-    void                PointChanged();
+    void DeployFormulaTextEdit();
+    void PointChanged();
 
-    void                FXLength();
-    void                EvalFormula();
+    void FXLength();
+    void EvalFormula();
 protected:
-    virtual void        ShowVisualization() override;
+    void ShowVisualization() override;
     /**
      * @brief SaveData Put dialog data in local variables
      */
-    virtual void        SaveData() override;
-    virtual void        closeEvent(QCloseEvent *event) override;
-    virtual bool        IsValid() const final;
+    void SaveData() override;
+    void closeEvent(QCloseEvent *event) override;
+    auto IsValid() const -> bool final;
 private:
-    Q_DISABLE_COPY(DialogAlongLine)
+    Q_DISABLE_COPY_MOVE(DialogAlongLine) // NOLINT
 
     /** @brief ui keeps information about user interface */
     Ui::DialogAlongLine *ui;
 
     /** @brief formula formula */
-    QString formula;
+    QString m_formula{};
 
-    QString pointName;
+    QString m_pointName{};
 
     /** @brief formulaBaseHeight base height defined by dialogui */
-    int formulaBaseHeight;
+    int m_formulaBaseHeight{0};
 
-    bool buildMidpoint;
+    bool m_buildMidpoint{false};
 
-    QTimer *timerFormula;
+    QTimer *m_timerFormula;
 
-    bool flagFormula;
-    bool flagError;
-    bool flagName;
+    bool m_flagFormula{false};
+    bool m_flagError{true};
+    bool m_flagName{true};
+
+    bool m_firstRelease{false};
+
+    /** @brief number number of handled objects */
+    qint32 m_number{0};
 
     void SetCurrentLength();
+
+    void ChosenSecondPoint(quint32 id, const QString &toolTip);
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-inline bool DialogAlongLine::IsValid() const
+inline auto DialogAlongLine::IsValid() const -> bool
 {
-    return flagName &&flagFormula && flagError;
+    return m_flagName &&m_flagFormula && m_flagError;
 }
 
 #endif // DIALOGALONGLINE_H
