@@ -38,7 +38,6 @@
 #include <QToolButton>
 #include <Qt>
 
-#include "../ifc/xml/vdomdocument.h"
 #include "../vpatterndb/vtranslatevars.h"
 #include "../vpatterndb/vcontainer.h"
 #include "../../visualization/path/vistoolarc.h"
@@ -49,6 +48,8 @@
 #include "ui_dialogarc.h"
 #include "../vgeometry/varc.h"
 #include "../qmuparser/qmudef.h"
+#include "../vwidgets/vabstractmainwindow.h"
+#include "../vwidgets/global.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -59,41 +60,30 @@
 DialogArc::DialogArc(const VContainer *data, quint32 toolId, QWidget *parent)
     : DialogTool(data, toolId, parent),
       ui(new Ui::DialogArc),
-      flagRadius(false),
-      flagF1(false),
-      flagF2(false),
-      timerRadius(new QTimer(this)),
-      timerF1(new QTimer(this)),
-      timerF2(new QTimer(this)),
-      radius(),
-      f1(),
-      f2(),
-      formulaBaseHeight(0),
-      formulaBaseHeightF1(0),
-      formulaBaseHeightF2(0),
-      angleF1(INT_MIN),
-      angleF2(INT_MIN)
+      m_timerRadius(new QTimer(this)),
+      m_timerF1(new QTimer(this)),
+      m_timerF2(new QTimer(this))
 {
     ui->setupUi(this);
 
     ui->doubleSpinBoxApproximationScale->setMaximum(maxCurveApproximationScale);
 
-    this->formulaBaseHeight = ui->plainTextEditFormula->height();
-    this->formulaBaseHeightF1 = ui->plainTextEditF1->height();
-    this->formulaBaseHeightF2 = ui->plainTextEditF2->height();
+    this->m_formulaBaseHeight = ui->plainTextEditFormula->height();
+    this->m_formulaBaseHeightF1 = ui->plainTextEditF1->height();
+    this->m_formulaBaseHeightF2 = ui->plainTextEditF2->height();
 
     ui->plainTextEditFormula->installEventFilter(this);
     ui->plainTextEditF1->installEventFilter(this);
     ui->plainTextEditF2->installEventFilter(this);
 
-    timerRadius->setSingleShot(true);
-    connect(timerRadius, &QTimer::timeout, this, &DialogArc::EvalRadius);
+    m_timerRadius->setSingleShot(true);
+    connect(m_timerRadius, &QTimer::timeout, this, &DialogArc::EvalRadius);
 
-    timerF1->setSingleShot(true);
-    connect(timerF1, &QTimer::timeout, this, &DialogArc::EvalF);
+    m_timerF1->setSingleShot(true);
+    connect(m_timerF1, &QTimer::timeout, this, &DialogArc::EvalF);
 
-    timerF2->setSingleShot(true);
-    connect(timerF2, &QTimer::timeout, this, &DialogArc::EvalF);
+    m_timerF2->setSingleShot(true);
+    connect(m_timerF2, &QTimer::timeout, this, &DialogArc::EvalF);
 
     InitOkCancelApply(ui);
 
@@ -107,17 +97,17 @@ DialogArc::DialogArc(const VContainer *data, quint32 toolId, QWidget *parent)
 
     connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this, [this]()
     {
-        timerRadius->start(formulaTimerTimeout);
+        m_timerRadius->start(formulaTimerTimeout);
     });
 
     connect(ui->plainTextEditF1, &QPlainTextEdit::textChanged, this, [this]()
     {
-        timerF1->start(formulaTimerTimeout);
+        m_timerF1->start(formulaTimerTimeout);
     });
 
     connect(ui->plainTextEditF2, &QPlainTextEdit::textChanged, this, [this]()
     {
-        timerF2->start(formulaTimerTimeout);
+        m_timerF2->start(formulaTimerTimeout);
     });
 
     connect(ui->pushButtonGrowLength, &QPushButton::clicked, this, &DialogArc::DeployFormulaTextEdit);
@@ -135,19 +125,19 @@ DialogArc::DialogArc(const VContainer *data, quint32 toolId, QWidget *parent)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArc::DeployFormulaTextEdit()
 {
-    DeployFormula(this, ui->plainTextEditFormula, ui->pushButtonGrowLength, formulaBaseHeight);
+    DeployFormula(this, ui->plainTextEditFormula, ui->pushButtonGrowLength, m_formulaBaseHeight);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArc::DeployF1TextEdit()
 {
-    DeployFormula(this, ui->plainTextEditF1, ui->pushButtonGrowLengthF1, formulaBaseHeightF1);
+    DeployFormula(this, ui->plainTextEditF1, ui->pushButtonGrowLengthF1, m_formulaBaseHeightF1);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArc::DeployF2TextEdit()
 {
-    DeployFormula(this, ui->plainTextEditF2, ui->pushButtonGrowLengthF2, formulaBaseHeightF2);
+    DeployFormula(this, ui->plainTextEditF2, ui->pushButtonGrowLengthF2, m_formulaBaseHeightF2);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -164,7 +154,10 @@ DialogArc::~DialogArc()
 void DialogArc::SetCenter(const quint32 &value)
 {
     ChangeCurrentData(ui->comboBoxBasePoint, value);
-    vis->setObject1Id(value);
+
+    auto *path = qobject_cast<VisToolArc *>(vis);
+    SCASSERT(path != nullptr)
+    path->SetCenterId(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -174,24 +167,24 @@ void DialogArc::SetCenter(const quint32 &value)
  */
 void DialogArc::SetF2(const QString &value)
 {
-    f2 = VAbstractApplication::VApp()->TrVars()
+    m_f2 = VAbstractApplication::VApp()->TrVars()
             ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
-    if (f2.length() > 80)
+    if (m_f2.length() > 80)
     {
         this->DeployF2TextEdit();
     }
-    ui->plainTextEditF2->setPlainText(f2);
+    ui->plainTextEditF2->setPlainText(m_f2);
 
-    VisToolArc *path = qobject_cast<VisToolArc *>(vis);
+    auto *path = qobject_cast<VisToolArc *>(vis);
     SCASSERT(path != nullptr)
-    path->setF2(f2);
+    path->SetF2(m_f2);
 
     MoveCursorToEnd(ui->plainTextEditF2);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogArc::GetPenStyle() const
+auto DialogArc::GetPenStyle() const -> QString
 {
     return GetComboBoxCurrentData(ui->comboBoxPenStyle, TypeLineLine);
 }
@@ -203,7 +196,7 @@ void DialogArc::SetPenStyle(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogArc::GetColor() const
+auto DialogArc::GetColor() const -> QString
 {
     return GetComboBoxCurrentData(ui->comboBoxColor, ColorBlack);
 }
@@ -215,7 +208,7 @@ void DialogArc::SetColor(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal DialogArc::GetApproximationScale() const
+auto DialogArc::GetApproximationScale() const -> qreal
 {
     return ui->doubleSpinBoxApproximationScale->value();
 }
@@ -225,9 +218,9 @@ void DialogArc::SetApproximationScale(qreal value)
 {
     ui->doubleSpinBoxApproximationScale->setValue(value);
 
-    VisToolArc *path = qobject_cast<VisToolArc *>(vis);
+    auto *path = qobject_cast<VisToolArc *>(vis);
     SCASSERT(path != nullptr)
-            path->setApproximationScale(value);
+    path->SetApproximationScale(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -237,7 +230,7 @@ void DialogArc::SetNotes(const QString &notes)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogArc::GetNotes() const
+auto DialogArc::GetNotes() const -> QString
 {
     return ui->plainTextEditToolNotes->toPlainText();
 }
@@ -245,17 +238,96 @@ QString DialogArc::GetNotes() const
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArc::SetAliasSuffix(const QString &alias)
 {
-    originAliasSuffix = alias;
-    ui->lineEditAlias->setText(originAliasSuffix);
+    m_originAliasSuffix = alias;
+    ui->lineEditAlias->setText(m_originAliasSuffix);
     ValidateAlias();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogArc::GetAliasSuffix() const
+auto DialogArc::GetAliasSuffix() const -> QString
 {
     return ui->lineEditAlias->text();
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogArc::ShowDialog(bool click)
+{
+    if (prepare)
+    {
+        auto *arcVis = qobject_cast<VisToolArc *>(vis);
+        SCASSERT(arcVis != nullptr)
+
+        auto FinishCreating = [this, arcVis]()
+        {
+            arcVis->SetMode(Mode::Show);
+            arcVis->RefreshGeometry();
+
+            emit ToolTip(QString());
+
+            setModal(true);
+            show();
+        };
+
+        if (click)
+        {
+            // The check need to ignore first release of mouse button.
+            // User can select point by clicking on a label.
+            if (not m_firstRelease)
+            {
+                m_firstRelease = true;
+                return;
+            }
+
+            /*We will ignore click if pointer is in point circle*/
+            auto *scene = qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
+            SCASSERT(scene != nullptr)
+            const QSharedPointer<VPointF> point = data->GeometricObject<VPointF>(GetCenter());
+            QLineF line = QLineF(static_cast<QPointF>(*point), scene->getScenePos());
+
+            auto Angle = [line]()
+            {
+                if (QGuiApplication::keyboardModifiers() == Qt::ShiftModifier)
+                {
+                    QLineF correction = line;
+                    correction.setAngle(Visualization::CorrectAngle(correction.angle()));
+                    return correction.angle();
+                }
+
+                return line.angle();
+            };
+
+            if (m_stageRadius)
+            {
+                //Radius of point circle, but little bigger. Need handle with hover sizes.
+                if (line.length() <= ScaledRadius(SceneScale(VAbstractValApplication::VApp()->getCurrentScene()))*1.5)
+                {
+                    return;
+                }
+
+                SetRadius(QString::number(VAbstractValApplication::VApp()->fromPixel(line.length())));
+                arcVis->RefreshGeometry();
+                m_stageRadius = false;
+                m_stageF1 = true;
+            }
+            else if (m_stageF1)
+            {
+                SetF1(QString::number(Angle()));
+                arcVis->RefreshGeometry();
+                m_stageF1 = false;
+            }
+            else
+            {
+                SetF2(QString::number(arcVis->StickyEnd(Angle())));
+
+                FinishCreating();
+            }
+            return;
+        }
+
+        FinishCreating();
+    }
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief SetF1 set formula first angle of arc
@@ -263,18 +335,18 @@ QString DialogArc::GetAliasSuffix() const
  */
 void DialogArc::SetF1(const QString &value)
 {
-    f1 = VAbstractApplication::VApp()->TrVars()
+    m_f1 = VAbstractApplication::VApp()->TrVars()
             ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
-    if (f1.length() > 80)
+    if (m_f1.length() > 80)
     {
         this->DeployF1TextEdit();
     }
-    ui->plainTextEditF1->setPlainText(f1);
+    ui->plainTextEditF1->setPlainText(m_f1);
 
-    VisToolArc *path = qobject_cast<VisToolArc *>(vis);
+    auto *path = qobject_cast<VisToolArc *>(vis);
     SCASSERT(path != nullptr)
-    path->setF1(f1);
+    path->SetF1(m_f1);
 
     MoveCursorToEnd(ui->plainTextEditF1);
 }
@@ -286,18 +358,18 @@ void DialogArc::SetF1(const QString &value)
  */
 void DialogArc::SetRadius(const QString &value)
 {
-    radius = VAbstractApplication::VApp()->TrVars()
+    m_radius = VAbstractApplication::VApp()->TrVars()
             ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
-    if (radius.length() > 80)
+    if (m_radius.length() > 80)
     {
         this->DeployFormulaTextEdit();
     }
-    ui->plainTextEditFormula->setPlainText(radius);
+    ui->plainTextEditFormula->setPlainText(m_radius);
 
-    VisToolArc *path = qobject_cast<VisToolArc *>(vis);
+    auto *path = qobject_cast<VisToolArc *>(vis);
     SCASSERT(path != nullptr)
-    path->setRadius(radius);
+    path->SetRadius(m_radius);
 
     MoveCursorToEnd(ui->plainTextEditFormula);
 }
@@ -318,11 +390,16 @@ void DialogArc::ChosenObject(quint32 id, const SceneObject &type)
             {
                 if (vis != nullptr)
                 {
+                    auto *window = qobject_cast<VAbstractMainWindow *>(
+                                VAbstractValApplication::VApp()->getMainWindow());
+                    SCASSERT(window != nullptr)
+                    connect(vis.data(), &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
+
                     vis->VisualMode(id);
+                    vis->RefreshToolTip();
                 }
+
                 prepare = true;
-                this->setModal(true);
-                this->show();
             }
         }
     }
@@ -337,18 +414,18 @@ void DialogArc::ShowVisualization()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArc::SaveData()
 {
-    radius = ui->plainTextEditFormula->toPlainText();
-    f1 = ui->plainTextEditF1->toPlainText();
-    f2 = ui->plainTextEditF2->toPlainText();
+    m_radius = ui->plainTextEditFormula->toPlainText();
+    m_f1 = ui->plainTextEditF1->toPlainText();
+    m_f2 = ui->plainTextEditF2->toPlainText();
 
-    VisToolArc *path = qobject_cast<VisToolArc *>(vis);
+    auto *path = qobject_cast<VisToolArc *>(vis);
     SCASSERT(path != nullptr)
 
-    path->setObject1Id(GetCenter());
-    path->setRadius(radius);
-    path->setF1(f1);
-    path->setF2(f2);
-    path->setApproximationScale(ui->doubleSpinBoxApproximationScale->value());
+    path->SetCenterId(GetCenter());
+    path->SetRadius(m_radius);
+    path->SetF1(m_f1);
+    path->SetF2(m_f2);
+    path->SetApproximationScale(ui->doubleSpinBoxApproximationScale->value());
     path->RefreshGeometry();
 }
 
@@ -369,14 +446,14 @@ void DialogArc::ValidateAlias()
     arc.SetAliasSuffix(GetAliasSuffix());
     if (not GetAliasSuffix().isEmpty() &&
         (not rx.match(arc.GetAlias()).hasMatch() ||
-         (originAliasSuffix != GetAliasSuffix() && not data->IsUnique(arc.GetAlias()))))
+         (m_originAliasSuffix != GetAliasSuffix() && not data->IsUnique(arc.GetAlias()))))
     {
-        flagAlias = false;
+        m_flagAlias = false;
         ChangeColor(ui->labelAlias, errorColor);
     }
     else
     {
-        flagAlias = true;
+        m_flagAlias = true;
         ChangeColor(ui->labelAlias, OkColor(this));
     }
 
@@ -386,7 +463,7 @@ void DialogArc::ValidateAlias()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArc::FXRadius()
 {
-    DialogEditWrongFormula *dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit radius"));
     dialog->SetFormula(GetRadius());
     dialog->setPostfix(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true));
@@ -400,7 +477,7 @@ void DialogArc::FXRadius()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArc::FXF1()
 {
-    DialogEditWrongFormula *dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit first angle"));
     dialog->SetFormula(GetF1());
     dialog->setPostfix(degreeSymbol);
@@ -414,7 +491,7 @@ void DialogArc::FXF1()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArc::FXF2()
 {
-    DialogEditWrongFormula *dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit second angle"));
     dialog->SetFormula(GetF2());
     dialog->setPostfix(degreeSymbol);
@@ -438,11 +515,11 @@ void DialogArc::EvalRadius()
     formulaData.labelResult = ui->labelResultRadius;
     formulaData.postfix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true);
 
-    const qreal radius = Eval(formulaData, flagRadius);
+    const qreal radius = Eval(formulaData, m_flagRadius);
 
     if (radius < 0)
     {
-        flagRadius = false;
+        m_flagRadius = false;
         ChangeColor(ui->labelEditRadius, errorColor);
         ui->labelResultRadius->setText(tr("Error"));
         ui->labelResultRadius->setToolTip(tr("Radius can't be negative"));
@@ -465,13 +542,13 @@ void DialogArc::EvalF()
     formulaData.postfix = degreeSymbol;
     formulaData.checkZero = false;
 
-    angleF1 = Eval(formulaData, flagF1);
+    m_angleF1 = Eval(formulaData, m_flagF1);
 
     formulaData.formula = ui->plainTextEditF2->toPlainText();
     formulaData.labelEditFormula = ui->labelEditF2;
     formulaData.labelResult = ui->labelResultF2;
 
-    angleF2 = Eval(formulaData, flagF2);
+    m_angleF2 = Eval(formulaData, m_flagF2);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -479,7 +556,7 @@ void DialogArc::EvalF()
  * @brief GetCenter return id of center point
  * @return id id
  */
-quint32 DialogArc::GetCenter() const
+auto DialogArc::GetCenter() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxBasePoint);
 }
@@ -489,10 +566,9 @@ quint32 DialogArc::GetCenter() const
  * @brief GetRadius return formula of radius
  * @return formula
  */
-QString DialogArc::GetRadius() const
+auto DialogArc::GetRadius() const -> QString
 {
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(radius, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(m_radius, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -500,10 +576,9 @@ QString DialogArc::GetRadius() const
  * @brief GetF1 return formula first angle of arc
  * @return formula
  */
-QString DialogArc::GetF1() const
+auto DialogArc::GetF1() const -> QString
 {
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(f1, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(m_f1, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -511,8 +586,7 @@ QString DialogArc::GetF1() const
  * @brief GetF2 return formula second angle of arc
  * @return formula
  */
-QString DialogArc::GetF2() const
+auto DialogArc::GetF2() const -> QString
 {
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(f2, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(m_f2, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
