@@ -38,7 +38,6 @@
 #include <QToolButton>
 #include <Qt>
 
-#include "../ifc/xml/vdomdocument.h"
 #include "../vpatterndb/vtranslatevars.h"
 #include "../vpatterndb/vcontainer.h"
 #include "../../visualization/path/vistoolarcwithlength.h"
@@ -49,42 +48,35 @@
 #include "ui_dialogarcwithlength.h"
 #include "../vgeometry/varc.h"
 #include "../qmuparser/qmudef.h"
+#include "../vwidgets/vabstractmainwindow.h"
+#include "../vwidgets/global.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 DialogArcWithLength::DialogArcWithLength(const VContainer *data, quint32 toolId, QWidget *parent)
     : DialogTool(data, toolId, parent),
       ui(new Ui::DialogArcWithLength),
-      flagRadius(false),
-      flagF1(false),
-      flagLength(false),
-      timerRadius(new QTimer(this)),
-      timerF1(new QTimer(this)),
-      timerLength(new QTimer(this)),
-      radius(),
-      f1(),
-      length(),
-      formulaBaseHeightRadius(0),
-      formulaBaseHeightF1(0),
-      formulaBaseHeightLength(0)
+      m_timerRadius(new QTimer(this)),
+      m_timerF1(new QTimer(this)),
+      m_timerLength(new QTimer(this))
 {
     ui->setupUi(this);
 
-    this->formulaBaseHeightRadius = ui->plainTextEditRadius->height();
-    this->formulaBaseHeightF1 = ui->plainTextEditF1->height();
-    this->formulaBaseHeightLength = ui->plainTextEditLength->height();
+    this->m_formulaBaseHeightRadius = ui->plainTextEditRadius->height();
+    this->m_formulaBaseHeightF1 = ui->plainTextEditF1->height();
+    this->m_formulaBaseHeightLength = ui->plainTextEditLength->height();
 
     ui->plainTextEditRadius->installEventFilter(this);
     ui->plainTextEditF1->installEventFilter(this);
     ui->plainTextEditLength->installEventFilter(this);
 
-    timerRadius->setSingleShot(true);
-    connect(timerRadius, &QTimer::timeout, this, &DialogArcWithLength::Radius);
+    m_timerRadius->setSingleShot(true);
+    connect(m_timerRadius, &QTimer::timeout, this, &DialogArcWithLength::Radius);
 
-    timerF1->setSingleShot(true);
-    connect(timerF1, &QTimer::timeout, this, &DialogArcWithLength::EvalF);
+    m_timerF1->setSingleShot(true);
+    connect(m_timerF1, &QTimer::timeout, this, &DialogArcWithLength::EvalF);
 
-    timerLength->setSingleShot(true);
-    connect(timerLength, &QTimer::timeout, this, &DialogArcWithLength::Length);
+    m_timerLength->setSingleShot(true);
+    connect(m_timerLength, &QTimer::timeout, this, &DialogArcWithLength::Length);
 
     InitOkCancelApply(ui);
 
@@ -100,17 +92,17 @@ DialogArcWithLength::DialogArcWithLength(const VContainer *data, quint32 toolId,
 
     connect(ui->plainTextEditRadius, &QPlainTextEdit::textChanged, this, [this]()
     {
-        timerRadius->start(formulaTimerTimeout);
+        m_timerRadius->start(formulaTimerTimeout);
     });
 
     connect(ui->plainTextEditF1, &QPlainTextEdit::textChanged, this, [this]()
     {
-        timerF1->start(formulaTimerTimeout);
+        m_timerF1->start(formulaTimerTimeout);
     });
 
     connect(ui->plainTextEditLength, &QPlainTextEdit::textChanged, this, [this]()
     {
-        timerLength->start(formulaTimerTimeout);
+        m_timerLength->start(formulaTimerTimeout);
     });
 
     connect(ui->pushButtonGrowLengthRadius, &QPushButton::clicked, this, &DialogArcWithLength::DeployRadiusTextEdit);
@@ -132,7 +124,7 @@ DialogArcWithLength::~DialogArcWithLength()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogArcWithLength::GetCenter() const
+auto DialogArcWithLength::GetCenter() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxCenter);
 }
@@ -141,88 +133,88 @@ quint32 DialogArcWithLength::GetCenter() const
 void DialogArcWithLength::SetCenter(const quint32 &value)
 {
     ChangeCurrentData(ui->comboBoxCenter, value);
-    vis->setObject1Id(value);
+    auto *path = qobject_cast<VisToolArcWithLength *>(vis);
+    SCASSERT(path != nullptr)
+    path->SetCenterId(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogArcWithLength::GetRadius() const
+auto DialogArcWithLength::GetRadius() const -> QString
 {
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(radius, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(m_radius, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArcWithLength::SetRadius(const QString &value)
 {
-    radius = VAbstractApplication::VApp()->TrVars()
+    m_radius = VAbstractApplication::VApp()->TrVars()
             ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
-    if (radius.length() > 80)
+    if (m_radius.length() > 80)
     {
         this->DeployRadiusTextEdit();
     }
-    ui->plainTextEditRadius->setPlainText(radius);
+    ui->plainTextEditRadius->setPlainText(m_radius);
 
-    VisToolArcWithLength *path = qobject_cast<VisToolArcWithLength *>(vis);
+    auto *path = qobject_cast<VisToolArcWithLength *>(vis);
     SCASSERT(path != nullptr)
-    path->setRadius(radius);
+    path->SetRadius(m_radius);
 
     MoveCursorToEnd(ui->plainTextEditRadius);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogArcWithLength::GetF1() const
+auto DialogArcWithLength::GetF1() const -> QString
 {
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(f1, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(m_f1, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
+//---------------------------------------------------------------------------------------------------------------------
 void DialogArcWithLength::SetF1(const QString &value)
 {
-    f1 = VAbstractApplication::VApp()->TrVars()
+    m_f1 = VAbstractApplication::VApp()->TrVars()
             ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
-    if (f1.length() > 80)
+    if (m_f1.length() > 80)
     {
         this->DeployF1TextEdit();
     }
-    ui->plainTextEditF1->setPlainText(f1);
+    ui->plainTextEditF1->setPlainText(m_f1);
 
-    VisToolArcWithLength *path = qobject_cast<VisToolArcWithLength *>(vis);
+    auto *path = qobject_cast<VisToolArcWithLength *>(vis);
     SCASSERT(path != nullptr)
-    path->setF1(f1);
+    path->SetF1(m_f1);
 
     MoveCursorToEnd(ui->plainTextEditF1);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogArcWithLength::GetLength() const
+auto DialogArcWithLength::GetLength() const -> QString
 {
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(length, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(m_length, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArcWithLength::SetLength(const QString &value)
 {
-    length = VAbstractApplication::VApp()->TrVars()
+    m_length = VAbstractApplication::VApp()->TrVars()
             ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
-    if (length.length() > 80)
+    if (m_length.length() > 80)
     {
         this->DeployLengthTextEdit();
     }
-    ui->plainTextEditLength->setPlainText(length);
+    ui->plainTextEditLength->setPlainText(m_length);
 
-    VisToolArcWithLength *path = qobject_cast<VisToolArcWithLength *>(vis);
+    auto *path = qobject_cast<VisToolArcWithLength *>(vis);
     SCASSERT(path != nullptr)
-    path->setLength(radius);
+    path->SetLength(m_length);
 
     MoveCursorToEnd(ui->plainTextEditLength);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogArcWithLength::GetPenStyle() const
+auto DialogArcWithLength::GetPenStyle() const -> QString
 {
     return GetComboBoxCurrentData(ui->comboBoxPenStyle, TypeLineLine);
 }
@@ -234,7 +226,7 @@ void DialogArcWithLength::SetPenStyle(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogArcWithLength::GetColor() const
+auto DialogArcWithLength::GetColor() const -> QString
 {
     return GetComboBoxCurrentData(ui->comboBoxColor, ColorBlack);
 }
@@ -246,7 +238,7 @@ void DialogArcWithLength::SetColor(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal DialogArcWithLength::GetApproximationScale() const
+auto DialogArcWithLength::GetApproximationScale() const -> qreal
 {
     return ui->doubleSpinBoxApproximationScale->value();
 }
@@ -256,9 +248,9 @@ void DialogArcWithLength::SetApproximationScale(qreal value)
 {
     ui->doubleSpinBoxApproximationScale->setValue(value);
 
-    VisToolArcWithLength *path = qobject_cast<VisToolArcWithLength *>(vis);
+    auto *path = qobject_cast<VisToolArcWithLength *>(vis);
     SCASSERT(path != nullptr)
-            path->setApproximationScale(value);
+    path->SetApproximationScale(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -268,7 +260,7 @@ void DialogArcWithLength::SetNotes(const QString &notes)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogArcWithLength::GetNotes() const
+auto DialogArcWithLength::GetNotes() const -> QString
 {
     return ui->plainTextEditToolNotes->toPlainText();
 }
@@ -276,21 +268,105 @@ QString DialogArcWithLength::GetNotes() const
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArcWithLength::SetAliasSuffix(const QString &alias)
 {
-    originAliasSuffix = alias;
-    ui->lineEditAlias->setText(originAliasSuffix);
+    m_originAliasSuffix = alias;
+    ui->lineEditAlias->setText(m_originAliasSuffix);
     ValidateAlias();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogArcWithLength::GetAliasSuffix() const
+auto DialogArcWithLength::GetAliasSuffix() const -> QString
 {
     return ui->lineEditAlias->text();
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogArcWithLength::ShowDialog(bool click)
+{
+    if (prepare)
+    {
+        auto FinishCreating = [this]()
+        {
+            vis->SetMode(Mode::Show);
+            vis->RefreshGeometry();
+
+            emit ToolTip(QString());
+
+            setModal(true);
+            show();
+        };
+
+        if (click)
+        {
+            // The check need to ignore first release of mouse button.
+            // User can select point by clicking on a label.
+            if (not m_firstRelease)
+            {
+                m_firstRelease = true;
+                return;
+            }
+
+            /*We will ignore click if pointer is in point circle*/
+            auto *scene = qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
+            SCASSERT(scene != nullptr)
+            const QSharedPointer<VPointF> point = data->GeometricObject<VPointF>(GetCenter());
+            QLineF line = QLineF(static_cast<QPointF>(*point), scene->getScenePos());
+
+            auto Angle = [line]()
+            {
+                if (QGuiApplication::keyboardModifiers() == Qt::ShiftModifier)
+                {
+                    QLineF correction = line;
+                    correction.setAngle(VisToolArcWithLength::CorrectAngle(correction.angle()));
+                    return correction.angle();
+                }
+
+                return line.angle();
+            };
+
+            if (m_stageRadius)
+            {
+                //Radius of point circle, but little bigger. Need handle with hover sizes.
+                if (line.length() <= ScaledRadius(SceneScale(VAbstractValApplication::VApp()->getCurrentScene()))*1.5)
+                {
+                    return;
+                }
+
+                SetRadius(QString::number(VAbstractValApplication::VApp()->fromPixel(line.length())));
+                vis->RefreshGeometry();
+
+                m_stageRadius = false;
+                m_stageF1 = true;
+            }
+            else if (m_stageF1)
+            {
+
+                SetF1(QString::number(Angle()));
+                vis->RefreshGeometry();
+
+                m_stageF1 = false;
+            }
+            else
+            {
+                const qreal r = Visualization::FindLengthFromUser(m_radius, data->DataVariables());
+                const qreal angle1 = Visualization::FindValFromUser(m_f1, data->DataVariables());
+                VArc arc(*point, r, angle1, line.angle());
+
+                SetLength(QString::number(VAbstractValApplication::VApp()->fromPixel(arc.GetLength())));
+
+                FinishCreating();
+            }
+
+            return;
+        }
+
+        FinishCreating();
+    }
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArcWithLength::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (prepare == false)// After first choose we ignore all objects
+    if (not prepare)// After first choose we ignore all objects
     {
         if (type == SceneObject::Point)
         {
@@ -298,11 +374,16 @@ void DialogArcWithLength::ChosenObject(quint32 id, const SceneObject &type)
             {
                 if (vis != nullptr)
                 {
+                    auto *window = qobject_cast<VAbstractMainWindow *>(
+                                VAbstractValApplication::VApp()->getMainWindow());
+                    SCASSERT(window != nullptr)
+                    connect(vis.data(), &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
+
                     vis->VisualMode(id);
+                    vis->RefreshToolTip();
                 }
+
                 prepare = true;
-                this->setModal(true);
-                this->show();
             }
         }
     }
@@ -311,25 +392,25 @@ void DialogArcWithLength::ChosenObject(quint32 id, const SceneObject &type)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArcWithLength::DeployRadiusTextEdit()
 {
-    DeployFormula(this, ui->plainTextEditRadius, ui->pushButtonGrowLengthArcLength, formulaBaseHeightRadius);
+    DeployFormula(this, ui->plainTextEditRadius, ui->pushButtonGrowLengthArcLength, m_formulaBaseHeightRadius);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArcWithLength::DeployF1TextEdit()
 {
-    DeployFormula(this, ui->plainTextEditF1, ui->pushButtonGrowLengthF1, formulaBaseHeightF1);
+    DeployFormula(this, ui->plainTextEditF1, ui->pushButtonGrowLengthF1, m_formulaBaseHeightF1);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArcWithLength::DeployLengthTextEdit()
 {
-    DeployFormula(this, ui->plainTextEditLength, ui->pushButtonGrowLengthArcLength, formulaBaseHeightLength);
+    DeployFormula(this, ui->plainTextEditLength, ui->pushButtonGrowLengthArcLength, m_formulaBaseHeightLength);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArcWithLength::FXRadius()
 {
-    DialogEditWrongFormula *dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit radius"));
     dialog->SetFormula(GetRadius());
     dialog->setPostfix(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true));
@@ -343,7 +424,7 @@ void DialogArcWithLength::FXRadius()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArcWithLength::FXF1()
 {
-    DialogEditWrongFormula *dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit the first angle"));
     dialog->SetFormula(GetF1());
     dialog->setPostfix(degreeSymbol);
@@ -357,7 +438,7 @@ void DialogArcWithLength::FXF1()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArcWithLength::FXLength()
 {
-    DialogEditWrongFormula *dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit the arc length"));
     dialog->SetFormula(GetLength());
     dialog->setPostfix(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true));
@@ -377,18 +458,18 @@ void DialogArcWithLength::ShowVisualization()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArcWithLength::SaveData()
 {
-    radius = ui->plainTextEditRadius->toPlainText();
-    f1 = ui->plainTextEditF1->toPlainText();
-    length = ui->plainTextEditLength->toPlainText();
+    m_radius = ui->plainTextEditRadius->toPlainText();
+    m_f1 = ui->plainTextEditF1->toPlainText();
+    m_length = ui->plainTextEditLength->toPlainText();
 
-    VisToolArcWithLength *path = qobject_cast<VisToolArcWithLength *>(vis);
+    auto *path = qobject_cast<VisToolArcWithLength *>(vis);
     SCASSERT(path != nullptr)
 
-    path->setObject1Id(GetCenter());
-    path->setRadius(radius);
-    path->setF1(f1);
-    path->setLength(length);
-    path->setApproximationScale(ui->doubleSpinBoxApproximationScale->value());
+    path->SetCenterId(GetCenter());
+    path->SetRadius(m_radius);
+    path->SetF1(m_f1);
+    path->SetLength(m_length);
+    path->SetApproximationScale(ui->doubleSpinBoxApproximationScale->value());
     path->RefreshGeometry();
 }
 
@@ -409,14 +490,14 @@ void DialogArcWithLength::ValidateAlias()
     arc.SetAliasSuffix(GetAliasSuffix());
     if (not GetAliasSuffix().isEmpty() &&
         (not rx.match(arc.GetAlias()).hasMatch() ||
-         (originAliasSuffix != GetAliasSuffix() && not data->IsUnique(arc.GetAlias()))))
+         (m_originAliasSuffix != GetAliasSuffix() && not data->IsUnique(arc.GetAlias()))))
     {
-        flagAlias = false;
+        m_flagAlias = false;
         ChangeColor(ui->labelAlias, errorColor);
     }
     else
     {
-        flagAlias = true;
+        m_flagAlias = true;
         ChangeColor(ui->labelAlias, OkColor(this));
     }
 
@@ -434,7 +515,7 @@ void DialogArcWithLength::Radius()
     formulaData.postfix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true);
     formulaData.checkLessThanZero = true;
 
-    Eval(formulaData, flagRadius);
+    Eval(formulaData, m_flagRadius);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -447,7 +528,7 @@ void DialogArcWithLength::Length()
     formulaData.labelResult = ui->labelResultLength;
     formulaData.postfix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true);
 
-    Eval(formulaData, flagLength);
+    Eval(formulaData, m_flagLength);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -461,5 +542,5 @@ void DialogArcWithLength::EvalF()
     formulaData.postfix = degreeSymbol;
     formulaData.checkZero = false;
 
-    Eval(formulaData, flagF1);
+    Eval(formulaData, m_flagF1);
 }
