@@ -45,15 +45,14 @@
 #include "../vpatterndb/vtranslatevars.h"
 #include "../vwidgets/vmaingraphicsscene.h"
 #include "../vwidgets/vabstractmainwindow.h"
-#include "../../tools/vabstracttool.h"
 #include "../../visualization/line/vistoolendline.h"
 #include "../../visualization/visualization.h"
 #include "../ifc/xml/vabstractpattern.h"
-#include "../ifc/xml/vdomdocument.h"
 #include "../support/dialogeditwrongformula.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
 #include "ui_dialogendline.h"
+#include "../vwidgets/global.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -208,7 +207,7 @@ void DialogEndLine::FXLength()
  */
 void DialogEndLine::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (prepare == false)// After first choose we ignore all objects
+    if (not prepare)// After first choose we ignore all objects
     {
         if (type == SceneObject::Point)
         {
@@ -218,8 +217,7 @@ void DialogEndLine::ChosenObject(quint32 id, const SceneObject &type)
                 {
                     vis->VisualMode(id);
                 }
-                VAbstractMainWindow *window =
-                        qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
+                auto *window = qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
                 SCASSERT(window != nullptr)
                 connect(vis.data(), &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
                 prepare = true;
@@ -247,7 +245,7 @@ void DialogEndLine::SetPointName(const QString &value)
 void DialogEndLine::SetTypeLine(const QString &value)
 {
     ChangeCurrentData(ui->comboBoxLineType, value);
-    vis->setLineStyle(LineStyleToPenStyle(value));
+    vis->SetLineStyle(LineStyleToPenStyle(value));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -267,9 +265,9 @@ void DialogEndLine::SetFormula(const QString &value)
     }
     ui->plainTextEditFormula->setPlainText(formulaLength);
 
-    VisToolEndLine *line = qobject_cast<VisToolEndLine *>(vis);
+    auto *line = qobject_cast<VisToolEndLine *>(vis);
     SCASSERT(line != nullptr)
-    line->setLength(formulaLength);
+    line->SetLength(formulaLength);
 
     MoveCursorToEnd(ui->plainTextEditFormula);
 }
@@ -291,7 +289,7 @@ void DialogEndLine::SetAngle(const QString &value)
     }
     ui->plainTextEditAngle->setPlainText(formulaAngle);
 
-    VisToolEndLine *line = qobject_cast<VisToolEndLine *>(vis);
+    auto *line = qobject_cast<VisToolEndLine *>(vis);
     SCASSERT(line != nullptr)
     line->SetAngle(formulaAngle);
 
@@ -307,13 +305,13 @@ void DialogEndLine::SetBasePointId(const quint32 &value)
 {
     setCurrentPointId(ui->comboBoxBasePoint, value);
 
-    VisToolEndLine *line = qobject_cast<VisToolEndLine *>(vis);
+    auto *line = qobject_cast<VisToolEndLine *>(vis);
     SCASSERT(line != nullptr)
-    line->setObject1Id(value);
+    line->SetBasePointId(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogEndLine::GetLineColor() const
+auto DialogEndLine::GetLineColor() const -> QString
 {
     return GetComboBoxCurrentData(ui->comboBoxLineColor, ColorBlack);
 }
@@ -344,8 +342,7 @@ void DialogEndLine::ShowDialog(bool click)
             }
 
             /*We will ignore click if pointer is in point circle*/
-            VMainGraphicsScene *scene =
-                    qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
+            auto *scene = qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
             SCASSERT(scene != nullptr)
             const QSharedPointer<VPointF> point = data->GeometricObject<VPointF>(GetBasePointId());
             QLineF line = QLineF(static_cast<QPointF>(*point), scene->getScenePos());
@@ -358,7 +355,7 @@ void DialogEndLine::ShowDialog(bool click)
         }
         this->setModal(true);
 
-        VisToolEndLine *line = qobject_cast<VisToolEndLine *>(vis);
+        auto *line = qobject_cast<VisToolEndLine *>(vis);
         SCASSERT(line != nullptr)
 
         this->SetAngle(line->Angle());//Show in dialog angle what user choose
@@ -385,10 +382,10 @@ void DialogEndLine::SaveData()
     VisToolEndLine *line = qobject_cast<VisToolEndLine *>(vis);
     SCASSERT(line != nullptr)
 
-    line->setObject1Id(GetBasePointId());
-    line->setLength(formulaLength);
+    line->SetBasePointId(GetBasePointId());
+    line->SetLength(formulaLength);
     line->SetAngle(formulaAngle);
-    line->setLineStyle(LineStyleToPenStyle(GetTypeLine()));
+    line->SetLineStyle(LineStyleToPenStyle(GetTypeLine()));
     line->RefreshGeometry();
 }
 
@@ -429,8 +426,7 @@ QString DialogEndLine::GetTypeLine() const
  */
 QString DialogEndLine::GetFormula() const
 {
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(formulaLength, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(formulaLength, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -440,8 +436,7 @@ QString DialogEndLine::GetFormula() const
  */
 QString DialogEndLine::GetAngle() const
 {
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(formulaAngle, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(formulaAngle, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
