@@ -45,7 +45,7 @@ namespace Ui
 
 class DialogGroup : public DialogTool
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 
 public:
     explicit DialogGroup(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
@@ -73,7 +73,7 @@ private slots:
     void NameChanged();
 
 private:
-    Q_DISABLE_COPY(DialogGroup)
+    Q_DISABLE_COPY_MOVE(DialogGroup) // NOLINT
     Ui::DialogGroup *ui;
     QMap<quint32, quint32> group;
     bool flagName;
