@@ -48,57 +48,60 @@ namespace Ui
  */
 class DialogHeight final : public DialogTool
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 public:
     DialogHeight(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
-    virtual ~DialogHeight() override;
+    ~DialogHeight() override;
 
-    QString          GetPointName() const;
-    void             SetPointName(const QString &value);
+    auto GetPointName() const -> QString;
+    void SetPointName(const QString &value);
 
-    QString          GetTypeLine() const;
-    void             SetTypeLine(const QString &value);
+    auto GetTypeLine() const -> QString;
+    void SetTypeLine(const QString &value);
 
-    quint32          GetBasePointId() const;
-    void             SetBasePointId(const quint32 &value);
+    auto GetBasePointId() const -> quint32;
+    void SetBasePointId(const quint32 &value);
 
-    quint32          GetP1LineId() const;
-    void             SetP1LineId(const quint32 &value);
+    auto GetP1LineId() const -> quint32;
+    void SetP1LineId(const quint32 &value);
 
-    quint32          GetP2LineId() const;
-    void             SetP2LineId(const quint32 &value);
+    auto GetP2LineId() const -> quint32;
+    void SetP2LineId(const quint32 &value);
 
-    QString          GetLineColor() const;
-    void             SetLineColor(const QString &value);
+    auto GetLineColor() const -> QString;
+    void SetLineColor(const QString &value);
 
-    void    SetNotes(const QString &notes);
-    QString GetNotes() const;
+    void SetNotes(const QString &notes);
+    auto GetNotes() const -> QString;
 public slots:
-    virtual void     ChosenObject(quint32 id, const SceneObject &type) override;
-    virtual void     PointNameChanged() override;
+    void ChosenObject(quint32 id, const SceneObject &type) override;
+    void PointNameChanged() override;
 protected:
-    virtual void     ShowVisualization() override;
+    void ShowVisualization() override;
     /**
      * @brief SaveData Put dialog data in local variables
      */
-    virtual void     SaveData() override;
-    virtual bool     IsValid() const final;
+    void SaveData() override;
+    auto IsValid() const -> bool final;
 private:
-    Q_DISABLE_COPY(DialogHeight)
+    Q_DISABLE_COPY_MOVE(DialogHeight) // NOLINT
 
     /** @brief ui keeps information about user interface */
     Ui::DialogHeight *ui;
 
-    QString pointName;
+    QString m_pointName{};
 
-    bool flagError;
-    bool flagName;
+    bool m_flagError{true};
+    bool m_flagName{true};
+
+    /** @brief number number of handled objects */
+    qint32 m_number{0};
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-inline bool DialogHeight::IsValid() const
+inline auto DialogHeight::IsValid() const -> bool
 {
-    return flagError && flagName;
+    return m_flagError && m_flagName;
 }
 
 #endif // DIALOGHEIGHT_H
