@@ -48,7 +48,7 @@ namespace Ui
 
 class DialogMove : public DialogTool
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 
 public:
     explicit DialogMove(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
@@ -119,7 +119,7 @@ protected:
     virtual bool IsValid() const final;
 
 private:
-    Q_DISABLE_COPY(DialogMove)
+    Q_DISABLE_COPY_MOVE(DialogMove) // NOLINT
     Ui::DialogMove *ui;
 
     /** @brief timerAngle timer of check formula of angle */
