@@ -45,24 +45,18 @@
 #include "../vpatterndb/vcontainer.h"
 #include "../../visualization/visualization.h"
 #include "../../visualization/line/vistoolpointfromcircleandtangent.h"
-#include "../ifc/xml/vdomdocument.h"
 #include "../support/dialogeditwrongformula.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
 #include "ui_dialogpointfromcircleandtangent.h"
+#include "../vwidgets/vabstractmainwindow.h"
+#include "../vgeometry/vpointf.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 DialogPointFromCircleAndTangent::DialogPointFromCircleAndTangent(const VContainer *data, quint32 toolId,
                                                                  QWidget *parent)
     : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogPointFromCircleAndTangent),
-      timerCircleRadius(nullptr),
-      circleRadius(),
-      formulaBaseHeightCircleRadius(0),
-      pointName(),
-      flagCircleRadius(false),
-      flagName(true),
-      flagError(true)
+      ui(new Ui::DialogPointFromCircleAndTangent)
 {
     ui->setupUi(this);
 
@@ -71,12 +65,12 @@ DialogPointFromCircleAndTangent::DialogPointFromCircleAndTangent(const VContaine
     ui->lineEditNamePoint->setText(
                 VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
 
-    this->formulaBaseHeightCircleRadius = ui->plainTextEditRadius->height();
+    this->m_formulaBaseHeightCircleRadius = ui->plainTextEditRadius->height();
 
     ui->plainTextEditRadius->installEventFilter(this);
 
-    timerCircleRadius = new QTimer(this);
-    connect(timerCircleRadius, &QTimer::timeout, this, &DialogPointFromCircleAndTangent::EvalCircleRadius);
+    m_timerCircleRadius = new QTimer(this);
+    connect(m_timerCircleRadius, &QTimer::timeout, this, &DialogPointFromCircleAndTangent::EvalCircleRadius);
 
     InitOkCancelApply(ui);
 
@@ -86,7 +80,7 @@ DialogPointFromCircleAndTangent::DialogPointFromCircleAndTangent(const VContaine
 
     connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this, [this]()
     {
-        CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, pointName, this->data, flagName);
+        CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, m_pointName, this->data, m_flagName);
         CheckState();
     });
     connect(ui->comboBoxCircleCenter, &QComboBox::currentTextChanged,
@@ -97,7 +91,7 @@ DialogPointFromCircleAndTangent::DialogPointFromCircleAndTangent(const VContaine
 
     connect(ui->plainTextEditRadius, &QPlainTextEdit::textChanged, this, [this]()
     {
-        timerCircleRadius->start(formulaTimerTimeout);
+        m_timerCircleRadius->start(formulaTimerTimeout);
     });
 
     connect(ui->pushButtonGrowRadius, &QPushButton::clicked, this,
@@ -116,20 +110,20 @@ DialogPointFromCircleAndTangent::~DialogPointFromCircleAndTangent()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogPointFromCircleAndTangent::GetPointName() const
+auto DialogPointFromCircleAndTangent::GetPointName() const -> QString
 {
-    return pointName;
+    return m_pointName;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPointFromCircleAndTangent::SetPointName(const QString &value)
 {
-    pointName = value;
-    ui->lineEditNamePoint->setText(pointName);
+    m_pointName = value;
+    ui->lineEditNamePoint->setText(m_pointName);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogPointFromCircleAndTangent::GetCircleCenterId() const
+auto DialogPointFromCircleAndTangent::GetCircleCenterId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxCircleCenter);
 }
@@ -139,17 +133,16 @@ void DialogPointFromCircleAndTangent::SetCircleCenterId(const quint32 &value)
 {
     setCurrentPointId(ui->comboBoxCircleCenter, value);
 
-    VisToolPointFromCircleAndTangent *point = qobject_cast<VisToolPointFromCircleAndTangent *>(vis);
+    auto *point = qobject_cast<VisToolPointFromCircleAndTangent *>(vis);
     SCASSERT(point != nullptr)
-    point->setObject2Id(value);
+    point->SetCenterId(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogPointFromCircleAndTangent::GetCircleRadius() const
+auto DialogPointFromCircleAndTangent::GetCircleRadius() const -> QString
 {
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(ui->plainTextEditRadius->toPlainText(),
-                                 VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(ui->plainTextEditRadius->toPlainText(),
+                                              VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -164,85 +157,126 @@ void DialogPointFromCircleAndTangent::SetCircleRadius(const QString &value)
     }
     ui->plainTextEditRadius->setPlainText(formula);
 
-    VisToolPointFromCircleAndTangent *point = qobject_cast<VisToolPointFromCircleAndTangent *>(vis);
+    auto *point = qobject_cast<VisToolPointFromCircleAndTangent *>(vis);
     SCASSERT(point != nullptr)
-    point->setCRadius(formula);
+    point->SetCRadius(formula);
 
     MoveCursorToEnd(ui->plainTextEditRadius);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogPointFromCircleAndTangent::GetTangentPointId() const
+auto DialogPointFromCircleAndTangent::GetTangentPointId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxTangentPoint);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void DialogPointFromCircleAndTangent::SetTangentPointId(const quint32 &value)
+void DialogPointFromCircleAndTangent::SetTangentPointId(quint32 value)
 {
     setCurrentPointId(ui->comboBoxTangentPoint, value);
 
-    VisToolPointFromCircleAndTangent *point = qobject_cast<VisToolPointFromCircleAndTangent *>(vis);
+    auto *point = qobject_cast<VisToolPointFromCircleAndTangent *>(vis);
     SCASSERT(point != nullptr)
-    point->setObject1Id(value);
+    point->SetPointId(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-CrossCirclesPoint DialogPointFromCircleAndTangent::GetCrossCirclesPoint() const
+auto DialogPointFromCircleAndTangent::GetCrossCirclesPoint() const -> CrossCirclesPoint
 {
     return getCurrentCrossPoint<CrossCirclesPoint>(ui->comboBoxResult);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void DialogPointFromCircleAndTangent::SetCrossCirclesPoint(const CrossCirclesPoint &p)
+void DialogPointFromCircleAndTangent::SetCrossCirclesPoint(CrossCirclesPoint p)
 {
     const qint32 index = ui->comboBoxResult->findData(static_cast<int>(p));
     if (index != -1)
     {
         ui->comboBoxResult->setCurrentIndex(index);
 
-        VisToolPointFromCircleAndTangent *point = qobject_cast<VisToolPointFromCircleAndTangent *>(vis);
+        auto *point = qobject_cast<VisToolPointFromCircleAndTangent *>(vis);
         SCASSERT(point != nullptr)
-        point->setCrossPoint(p);
+        point->SetCrossPoint(p);
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogPointFromCircleAndTangent::ShowDialog(bool click)
+{
+    if (not prepare)
+    {
+        return;
+    }
+
+    if (click)
+    {
+        // The check need to ignore first release of mouse button.
+        // User can select point by clicking on a label.
+        if (not m_firstRelease)
+        {
+            m_firstRelease = true;
+            return;
+        }
+
+        /*We will ignore click if pointer is in point circle*/
+        auto *scene = qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
+        SCASSERT(scene != nullptr)
+        const QSharedPointer<VPointF> center = data->GeometricObject<VPointF>(GetCircleCenterId());
+        QLineF line = QLineF(static_cast<QPointF>(*center), scene->getScenePos());
+
+        SetCircleRadius(QString::number(FromPixel(line.length(), *data->GetPatternUnit())));
+    }
+
+    vis->SetMode(Mode::Show);
+    vis->RefreshGeometry();
+
+    emit ToolTip(QString());
+
+    setModal(true);
+    show();
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPointFromCircleAndTangent::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (prepare == false)// After first choose we ignore all objects
+    if (prepare)// After first choose we ignore all objects
     {
-        if (type == SceneObject::Point)
-        {
-            VisToolPointFromCircleAndTangent *point = qobject_cast<VisToolPointFromCircleAndTangent *>(vis);
-            SCASSERT(point != nullptr)
+        return;
+    }
 
-            switch (number)
-            {
-                case 0:
-                    if (SetObject(id, ui->comboBoxTangentPoint, tr("Select a circle center")))
+    if (type == SceneObject::Point)
+    {
+        auto *point = qobject_cast<VisToolPointFromCircleAndTangent *>(vis);
+        SCASSERT(point != nullptr)
+
+        switch (m_number)
+        {
+            case 0:
+                if (SetObject(id, ui->comboBoxTangentPoint, tr("Select a circle center")))
+                {
+                    m_number++;
+                    point->VisualMode(id);
+                }
+                break;
+            case 1:
+                if (getCurrentObjectId(ui->comboBoxTangentPoint) != id)
+                {
+                    if (SetObject(id, ui->comboBoxCircleCenter, QString()))
                     {
-                        number++;
-                        point->VisualMode(id);
+                        auto *window = qobject_cast<VAbstractMainWindow *>(
+                            VAbstractValApplication::VApp()->getMainWindow());
+                        SCASSERT(window != nullptr)
+                        connect(vis.data(), &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
+
+                        m_number = 0;
+                        point->SetCenterId(id);
+                        point->RefreshGeometry();
+                        prepare = true;
                     }
-                    break;
-                case 1:
-                    if (getCurrentObjectId(ui->comboBoxTangentPoint) != id)
-                    {
-                        if (SetObject(id, ui->comboBoxCircleCenter, QString()))
-                        {
-                            number = 0;
-                            point->setObject2Id(id);
-                            point->RefreshGeometry();
-                            prepare = true;
-                            this->setModal(true);
-                            this->show();
-                        }
-                    }
-                    break;
-                default:
-                    break;
-            }
+                }
+                break;
+            default:
+                break;
         }
     }
 }
@@ -253,12 +287,12 @@ void DialogPointFromCircleAndTangent::PointChanged()
     QColor color;
     if (getCurrentObjectId(ui->comboBoxCircleCenter) == getCurrentObjectId(ui->comboBoxTangentPoint))
     {
-        flagError = false;
+        m_flagError = false;
         color = errorColor;
     }
     else
     {
-        flagError = true;
+        m_flagError = true;
         color = OkColor(this);
     }
     ChangeColor(ui->labelCircleCenter, color);
@@ -269,13 +303,13 @@ void DialogPointFromCircleAndTangent::PointChanged()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPointFromCircleAndTangent::DeployCircleRadiusTextEdit()
 {
-    DeployFormula(this, ui->plainTextEditRadius, ui->pushButtonGrowRadius, formulaBaseHeightCircleRadius);
+    DeployFormula(this, ui->plainTextEditRadius, ui->pushButtonGrowRadius, m_formulaBaseHeightCircleRadius);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPointFromCircleAndTangent::FXCircleRadius()
 {
-    DialogEditWrongFormula *dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit radius"));
     dialog->SetFormula(GetCircleRadius());
     dialog->setPostfix(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true));
@@ -296,11 +330,11 @@ void DialogPointFromCircleAndTangent::EvalCircleRadius()
     formulaData.labelResult = ui->labelResultCircleRadius;
     formulaData.postfix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true);
 
-    const qreal radius = Eval(formulaData, flagCircleRadius);
+    const qreal radius = Eval(formulaData, m_flagCircleRadius);
 
     if (radius < 0)
     {
-        flagCircleRadius = false;
+        m_flagCircleRadius = false;
         ChangeColor(ui->labelEditRadius, errorColor);
         ui->labelResultCircleRadius->setText(tr("Error"));
         ui->labelResultCircleRadius->setToolTip(tr("Radius can't be negative"));
@@ -318,15 +352,15 @@ void DialogPointFromCircleAndTangent::ShowVisualization()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPointFromCircleAndTangent::SaveData()
 {
-    pointName = ui->lineEditNamePoint->text();
+    m_pointName = ui->lineEditNamePoint->text();
 
-    VisToolPointFromCircleAndTangent *point = qobject_cast<VisToolPointFromCircleAndTangent *>(vis);
+    auto *point = qobject_cast<VisToolPointFromCircleAndTangent *>(vis);
     SCASSERT(point != nullptr)
 
-    point->setObject1Id(GetTangentPointId());
-    point->setObject2Id(GetCircleCenterId());
-    point->setCRadius(ui->plainTextEditRadius->toPlainText());
-    point->setCrossPoint(GetCrossCirclesPoint());
+    point->SetPointId(GetTangentPointId());
+    point->SetCenterId(GetCircleCenterId());
+    point->SetCRadius(ui->plainTextEditRadius->toPlainText());
+    point->SetCrossPoint(GetCrossCirclesPoint());
     point->RefreshGeometry();
 }
 
@@ -344,7 +378,7 @@ void DialogPointFromCircleAndTangent::SetNotes(const QString &notes)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogPointFromCircleAndTangent::GetNotes() const
+auto DialogPointFromCircleAndTangent::GetNotes() const -> QString
 {
     return ui->plainTextEditToolNotes->toPlainText();
 }
