@@ -45,28 +45,20 @@
 #include "../vpatterndb/vcontainer.h"
 #include "../../visualization/visualization.h"
 #include "../../visualization/line/vistoolpointofintersectioncircles.h"
-#include "../ifc/xml/vdomdocument.h"
 #include "../support/dialogeditwrongformula.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
 #include "ui_dialogpointofintersectioncircles.h"
+#include "../vwidgets/vabstractmainwindow.h"
+#include "../vgeometry/vpointf.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 DialogPointOfIntersectionCircles::DialogPointOfIntersectionCircles(const VContainer *data, quint32 toolId,
                                                                    QWidget *parent)
     : DialogTool(data, toolId, parent),
       ui(new Ui::DialogPointOfIntersectionCircles),
-      timerCircle1Radius(new QTimer(this)),
-      timerCircle2Radius(new QTimer(this)),
-      circle1Radius(),
-      circle2Radius(),
-      formulaBaseHeightCircle1Radius(0),
-      formulaBaseHeightCircle2Radius(0),
-      pointName(),
-      flagCircle1Radius(false),
-      flagCircle2Radius(false),
-      flagName(true),
-      flagError(true)
+      m_timerCircle1Radius(new QTimer(this)),
+      m_timerCircle2Radius(new QTimer(this))
 {
     ui->setupUi(this);
 
@@ -75,17 +67,17 @@ DialogPointOfIntersectionCircles::DialogPointOfIntersectionCircles(const VContai
     ui->lineEditNamePoint->setText(
                 VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
 
-    this->formulaBaseHeightCircle1Radius = ui->plainTextEditCircle1Radius->height();
-    this->formulaBaseHeightCircle2Radius = ui->plainTextEditCircle2Radius->height();
+    this->m_formulaBaseHeightCircle1Radius = ui->plainTextEditCircle1Radius->height();
+    this->m_formulaBaseHeightCircle2Radius = ui->plainTextEditCircle2Radius->height();
 
     ui->plainTextEditCircle1Radius->installEventFilter(this);
     ui->plainTextEditCircle2Radius->installEventFilter(this);
 
-    timerCircle1Radius->setSingleShot(true);
-    connect(timerCircle1Radius, &QTimer::timeout, this, &DialogPointOfIntersectionCircles::EvalCircle1Radius);
+    m_timerCircle1Radius->setSingleShot(true);
+    connect(m_timerCircle1Radius, &QTimer::timeout, this, &DialogPointOfIntersectionCircles::EvalCircle1Radius);
 
-    timerCircle2Radius->setSingleShot(true);
-    connect(timerCircle2Radius, &QTimer::timeout, this, &DialogPointOfIntersectionCircles::EvalCircle2Radius);
+    m_timerCircle2Radius->setSingleShot(true);
+    connect(m_timerCircle2Radius, &QTimer::timeout, this, &DialogPointOfIntersectionCircles::EvalCircle2Radius);
 
     InitOkCancelApply(ui);
 
@@ -95,7 +87,7 @@ DialogPointOfIntersectionCircles::DialogPointOfIntersectionCircles(const VContai
 
     connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this, [this]()
     {
-        CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, pointName, this->data, flagName);
+        CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, m_pointName, this->data, m_flagName);
         CheckState();
     });
     connect(ui->comboBoxCircle1Center, &QComboBox::currentTextChanged,
@@ -110,12 +102,12 @@ DialogPointOfIntersectionCircles::DialogPointOfIntersectionCircles(const VContai
 
     connect(ui->plainTextEditCircle1Radius, &QPlainTextEdit::textChanged, this, [this]()
     {
-        timerCircle1Radius->start(formulaTimerTimeout);
+        m_timerCircle1Radius->start(formulaTimerTimeout);
     });
 
     connect(ui->plainTextEditCircle2Radius, &QPlainTextEdit::textChanged, this, [this]()
     {
-        timerCircle2Radius->start(formulaTimerTimeout);
+        m_timerCircle2Radius->start(formulaTimerTimeout);
     });
 
     connect(ui->pushButtonGrowCircle1Radius, &QPushButton::clicked, this,
@@ -136,20 +128,20 @@ DialogPointOfIntersectionCircles::~DialogPointOfIntersectionCircles()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogPointOfIntersectionCircles::GetPointName() const
+auto DialogPointOfIntersectionCircles::GetPointName() const -> QString
 {
-    return pointName;
+    return m_pointName;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPointOfIntersectionCircles::SetPointName(const QString &value)
 {
-    pointName = value;
-    ui->lineEditNamePoint->setText(pointName);
+    m_pointName = value;
+    ui->lineEditNamePoint->setText(m_pointName);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogPointOfIntersectionCircles::GetFirstCircleCenterId() const
+auto DialogPointOfIntersectionCircles::GetFirstCircleCenterId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxCircle1Center);
 }
@@ -159,13 +151,13 @@ void DialogPointOfIntersectionCircles::SetFirstCircleCenterId(const quint32 &val
 {
     setCurrentPointId(ui->comboBoxCircle1Center, value);
 
-    VisToolPointOfIntersectionCircles *point = qobject_cast<VisToolPointOfIntersectionCircles *>(vis);
+    auto *point = qobject_cast<VisToolPointOfIntersectionCircles *>(vis);
     SCASSERT(point != nullptr)
-    point->setObject1Id(value);
+    point->SetCircle1Id(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogPointOfIntersectionCircles::GetSecondCircleCenterId() const
+auto DialogPointOfIntersectionCircles::GetSecondCircleCenterId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxCircle2Center);
 }
@@ -175,17 +167,16 @@ void DialogPointOfIntersectionCircles::SetSecondCircleCenterId(const quint32 &va
 {
     setCurrentPointId(ui->comboBoxCircle2Center, value);
 
-    VisToolPointOfIntersectionCircles *point = qobject_cast<VisToolPointOfIntersectionCircles *>(vis);
+    auto *point = qobject_cast<VisToolPointOfIntersectionCircles *>(vis);
     SCASSERT(point != nullptr)
-    point->setObject2Id(value);
+    point->SetCircle2Id(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogPointOfIntersectionCircles::GetFirstCircleRadius() const
+auto DialogPointOfIntersectionCircles::GetFirstCircleRadius() const -> QString
 {
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(ui->plainTextEditCircle1Radius->toPlainText(),
-                                 VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(ui->plainTextEditCircle1Radius->toPlainText(),
+                                              VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -200,19 +191,18 @@ void DialogPointOfIntersectionCircles::SetFirstCircleRadius(const QString &value
     }
     ui->plainTextEditCircle1Radius->setPlainText(formula);
 
-    VisToolPointOfIntersectionCircles *point = qobject_cast<VisToolPointOfIntersectionCircles *>(vis);
+    auto *point = qobject_cast<VisToolPointOfIntersectionCircles *>(vis);
     SCASSERT(point != nullptr)
-    point->setC1Radius(formula);
+    point->SetC1Radius(formula);
 
     MoveCursorToEnd(ui->plainTextEditCircle1Radius);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogPointOfIntersectionCircles::GetSecondCircleRadius() const
+auto DialogPointOfIntersectionCircles::GetSecondCircleRadius() const -> QString
 {
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(ui->plainTextEditCircle2Radius->toPlainText(),
-                                 VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(ui->plainTextEditCircle2Radius->toPlainText(),
+                                              VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -227,15 +217,15 @@ void DialogPointOfIntersectionCircles::SetSecondCircleRadius(const QString &valu
     }
     ui->plainTextEditCircle2Radius->setPlainText(formula);
 
-    VisToolPointOfIntersectionCircles *point = qobject_cast<VisToolPointOfIntersectionCircles *>(vis);
+    auto *point = qobject_cast<VisToolPointOfIntersectionCircles *>(vis);
     SCASSERT(point != nullptr)
-    point->setC2Radius(formula);
+    point->SetC2Radius(formula);
 
     MoveCursorToEnd(ui->plainTextEditCircle2Radius);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-CrossCirclesPoint DialogPointOfIntersectionCircles::GetCrossCirclesPoint() const
+auto DialogPointOfIntersectionCircles::GetCrossCirclesPoint() const -> CrossCirclesPoint
 {
     return getCurrentCrossPoint<CrossCirclesPoint>(ui->comboBoxResult);
 }
@@ -248,48 +238,114 @@ void DialogPointOfIntersectionCircles::SetCrossCirclesPoint(const CrossCirclesPo
     {
         ui->comboBoxResult->setCurrentIndex(index);
 
-        VisToolPointOfIntersectionCircles *point = qobject_cast<VisToolPointOfIntersectionCircles *>(vis);
+        auto *point = qobject_cast<VisToolPointOfIntersectionCircles *>(vis);
         SCASSERT(point != nullptr)
-        point->setCrossPoint(p);
+        point->SetCrossPoint(p);
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogPointOfIntersectionCircles::ShowDialog(bool click)
+{
+    if (m_stage == 0 || m_stage == 2)
+    {
+        return;
+    }
+
+    auto FinishCreating = [this]()
+    {
+        vis->SetMode(Mode::Show);
+        vis->RefreshGeometry();
+
+        emit ToolTip(QString());
+
+        setModal(true);
+        show();
+    };
+
+    if (click)
+    {
+        // The check need to ignore first release of mouse button.
+        // User can select point by clicking on a label.
+        if (not m_firstRelease)
+        {
+            m_firstRelease = true;
+            return;
+        }
+
+        auto *scene = qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
+        SCASSERT(scene != nullptr)
+
+        QSharedPointer<VPointF> center = data->GeometricObject<VPointF>(m_stage == 1 ? GetFirstCircleCenterId()
+                                                                                     : GetSecondCircleCenterId());
+
+        QLineF line(static_cast<QPointF>(*center), scene->getScenePos());
+
+        if (m_stage == 1)
+        {
+            SetFirstCircleRadius(QString::number(FromPixel(line.length(), *data->GetPatternUnit())));
+            emit ToolTip(tr("Select second circle center"));
+            ++m_stage;
+            m_firstRelease = false;
+        }
+        else
+        {
+            SetSecondCircleRadius(QString::number(FromPixel(line.length(), *data->GetPatternUnit())));
+            ++m_stage;
+        }
+
+        if (m_stage > 2)
+        {
+            FinishCreating();
+        }
+
+        return;
+    }
+
+    FinishCreating();
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPointOfIntersectionCircles::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (prepare == false)// After first choose we ignore all objects
+    if (prepare)// After first choose we ignore all objects
     {
-        if (type == SceneObject::Point)
-        {
-            VisToolPointOfIntersectionCircles *point = qobject_cast<VisToolPointOfIntersectionCircles *>(vis);
-            SCASSERT(point != nullptr)
+        return;
+    }
 
-            switch (number)
-            {
-                case 0:
-                    if (SetObject(id, ui->comboBoxCircle1Center, tr("Select second circle center")))
+    if (type == SceneObject::Point)
+    {
+        auto *point = qobject_cast<VisToolPointOfIntersectionCircles *>(vis);
+        SCASSERT(point != nullptr)
+
+        switch (m_stage)
+        {
+            case 0:
+                if (SetObject(id, ui->comboBoxCircle1Center, QString()))
+                {
+                    ++m_stage;
+                    point->VisualMode(id);
+
+                    auto *window = qobject_cast<VAbstractMainWindow *>(
+                        VAbstractValApplication::VApp()->getMainWindow());
+                    SCASSERT(window != nullptr)
+                    connect(vis.data(), &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
+                }
+                break;
+            case 2:
+                if (getCurrentObjectId(ui->comboBoxCircle1Center) != id)
+                {
+                    if (SetObject(id, ui->comboBoxCircle2Center, QString()))
                     {
-                        number++;
-                        point->VisualMode(id);
+                        point->SetCircle2Id(id);
+                        point->RefreshGeometry();
+                        ++m_stage;
+                        prepare = true;
                     }
-                    break;
-                case 1:
-                    if (getCurrentObjectId(ui->comboBoxCircle1Center) != id)
-                    {
-                        if (SetObject(id, ui->comboBoxCircle2Center, QString()))
-                        {
-                            number = 0;
-                            point->setObject2Id(id);
-                            point->RefreshGeometry();
-                            prepare = true;
-                            this->setModal(true);
-                            this->show();
-                        }
-                    }
-                    break;
-                default:
-                    break;
-            }
+                }
+                break;
+            default:
+                break;
         }
     }
 }
@@ -300,12 +356,12 @@ void DialogPointOfIntersectionCircles::PointChanged()
     QColor color;
     if (getCurrentObjectId(ui->comboBoxCircle1Center) == getCurrentObjectId(ui->comboBoxCircle2Center))
     {
-        flagError = false;
+        m_flagError = false;
         color = errorColor;
     }
     else
     {
-        flagError = true;
+        m_flagError = true;
         color = OkColor(this);
     }
     ChangeColor(ui->labelCircle1Center, color);
@@ -316,19 +372,19 @@ void DialogPointOfIntersectionCircles::PointChanged()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPointOfIntersectionCircles::DeployCircle1RadiusTextEdit()
 {
-    DeployFormula(this, ui->plainTextEditCircle1Radius, ui->pushButtonGrowCircle1Radius, formulaBaseHeightCircle1Radius);
+    DeployFormula(this, ui->plainTextEditCircle1Radius, ui->pushButtonGrowCircle1Radius, m_formulaBaseHeightCircle1Radius);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPointOfIntersectionCircles::DeployCircle2RadiusTextEdit()
 {
-    DeployFormula(this, ui->plainTextEditCircle2Radius, ui->pushButtonGrowCircle2Radius, formulaBaseHeightCircle2Radius);
+    DeployFormula(this, ui->plainTextEditCircle2Radius, ui->pushButtonGrowCircle2Radius, m_formulaBaseHeightCircle2Radius);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPointOfIntersectionCircles::FXCircle1Radius()
 {
-    DialogEditWrongFormula *dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit first circle radius"));
     dialog->SetFormula(GetFirstCircleRadius());
     dialog->setPostfix(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true));
@@ -342,7 +398,7 @@ void DialogPointOfIntersectionCircles::FXCircle1Radius()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPointOfIntersectionCircles::FXCircle2Radius()
 {
-    DialogEditWrongFormula *dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit second circle radius"));
     dialog->SetFormula(GetSecondCircleRadius());
     dialog->setPostfix(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true));
@@ -363,11 +419,11 @@ void DialogPointOfIntersectionCircles::EvalCircle1Radius()
     formulaData.labelResult = ui->labelResultCircle1Radius;
     formulaData.postfix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true);
 
-    const qreal radius = Eval(formulaData, flagCircle1Radius);
+    const qreal radius = Eval(formulaData, m_flagCircle1Radius);
 
     if (radius < 0)
     {
-        flagCircle2Radius = false;
+        m_flagCircle2Radius = false;
         ChangeColor(ui->labelEditCircle1Radius, errorColor);
         ui->labelResultCircle1Radius->setText(tr("Error"));
         ui->labelResultCircle1Radius->setToolTip(tr("Radius can't be negative"));
@@ -386,11 +442,11 @@ void DialogPointOfIntersectionCircles::EvalCircle2Radius()
     formulaData.labelResult = ui->labelResultCircle2Radius;
     formulaData.postfix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true);
 
-    const qreal radius = Eval(formulaData, flagCircle2Radius);
+    const qreal radius = Eval(formulaData, m_flagCircle2Radius);
 
     if (radius < 0)
     {
-        flagCircle2Radius = false;
+        m_flagCircle2Radius = false;
         ChangeColor(ui->labelEditCircle2Radius, errorColor);
         ui->labelResultCircle2Radius->setText(tr("Error"));
         ui->labelResultCircle2Radius->setToolTip(tr("Radius can't be negative"));
@@ -408,16 +464,16 @@ void DialogPointOfIntersectionCircles::ShowVisualization()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPointOfIntersectionCircles::SaveData()
 {
-    pointName = ui->lineEditNamePoint->text();
+    m_pointName = ui->lineEditNamePoint->text();
 
-    VisToolPointOfIntersectionCircles *point = qobject_cast<VisToolPointOfIntersectionCircles *>(vis);
+    auto *point = qobject_cast<VisToolPointOfIntersectionCircles *>(vis);
     SCASSERT(point != nullptr)
 
-    point->setObject1Id(GetFirstCircleCenterId());
-    point->setObject2Id(GetSecondCircleCenterId());
-    point->setC1Radius(ui->plainTextEditCircle1Radius->toPlainText());
-    point->setC2Radius(ui->plainTextEditCircle2Radius->toPlainText());
-    point->setCrossPoint(GetCrossCirclesPoint());
+    point->SetCircle1Id(GetFirstCircleCenterId());
+    point->SetCircle2Id(GetSecondCircleCenterId());
+    point->SetC1Radius(ui->plainTextEditCircle1Radius->toPlainText());
+    point->SetC2Radius(ui->plainTextEditCircle2Radius->toPlainText());
+    point->SetCrossPoint(GetCrossCirclesPoint());
     point->RefreshGeometry();
 }
 
@@ -436,7 +492,7 @@ void DialogPointOfIntersectionCircles::SetNotes(const QString &notes)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogPointOfIntersectionCircles::GetNotes() const
+auto DialogPointOfIntersectionCircles::GetNotes() const -> QString
 {
     return ui->plainTextEditToolNotes->toPlainText();
 }
