@@ -45,7 +45,7 @@ class DialogPointOfIntersectionCurves;
 
 class DialogPointOfIntersectionCurves : public DialogTool
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 
 public:
     explicit DialogPointOfIntersectionCurves(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
@@ -98,7 +98,7 @@ private slots:
     void ValidateAlias();
 
 private:
-    Q_DISABLE_COPY(DialogPointOfIntersectionCurves)
+    Q_DISABLE_COPY_MOVE(DialogPointOfIntersectionCurves) // NOLINT
 
     Ui::DialogPointOfIntersectionCurves *ui;
 
@@ -115,6 +115,9 @@ private:
     QString originCurve1AliasSuffix2{};
     QString originCurve2AliasSuffix1{};
     QString originCurve2AliasSuffix2{};
+
+    /** @brief number number of handled objects */
+    qint32 number{0};
 };
 
 //---------------------------------------------------------------------------------------------------------------------
