@@ -202,7 +202,7 @@ void DialogSpline::ChosenObject(quint32 id, const SceneObject &type)
                         {
                             ++number;
 
-                            path->SetObject4Id(id);
+                            path->SetPoint4Id(id);
                             path->RefreshGeometry();
                             prepare = true;
                         }
@@ -227,14 +227,14 @@ void DialogSpline::SaveData()
     auto path = qobject_cast<VisToolSpline *>(vis);
     SCASSERT(path != nullptr)
 
-    path->setObject1Id(GetP1()->id());
-    path->SetObject4Id(GetP4()->id());
+    path->SetPoint1Id(GetP1()->id());
+    path->SetPoint4Id(GetP4()->id());
     path->SetAngle1(spl.GetStartAngle());
     path->SetAngle2(spl.GetEndAngle());
     path->SetKAsm1(spl.GetKasm1());
     path->SetKAsm2(spl.GetKasm2());
     path->SetKCurve(spl.GetKcurve());
-    path->setApproximationScale(spl.GetApproximationScale());
+    path->SetApproximationScale(spl.GetApproximationScale());
     path->SetMode(Mode::Show);
     path->RefreshGeometry();
 }
@@ -278,9 +278,8 @@ void DialogSpline::FXAngle1()
 {
     auto* dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit first control point angle"));
-    QString angle1F = VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(ui->plainTextEditAngle1F->toPlainText(),
-                                 VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    QString angle1F = VTranslateVars::TryFormulaFromUser(ui->plainTextEditAngle1F->toPlainText(),
+                                                         VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     dialog->SetFormula(angle1F);
     dialog->setPostfix(degreeSymbol);
     if (dialog->exec() == QDialog::Accepted)
@@ -303,9 +302,8 @@ void DialogSpline::FXAngle2()
 {
     auto* dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit second control point angle"));
-    QString angle2F = VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(ui->plainTextEditAngle2F->toPlainText(),
-                                 VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    QString angle2F = VTranslateVars::TryFormulaFromUser(ui->plainTextEditAngle2F->toPlainText(),
+                                                         VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     dialog->SetFormula(angle2F);
     dialog->setPostfix(degreeSymbol);
     if (dialog->exec() == QDialog::Accepted)
@@ -328,9 +326,8 @@ void DialogSpline::FXLength1()
 {
     auto* dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit first control point length"));
-    QString length1F = VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(ui->plainTextEditLength1F->toPlainText(),
-                                 VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    QString length1F = VTranslateVars::TryFormulaFromUser(ui->plainTextEditLength1F->toPlainText(),
+                                                          VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     dialog->SetFormula(length1F);
     dialog->setPostfix(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true));
     if (dialog->exec() == QDialog::Accepted)
@@ -353,9 +350,8 @@ void DialogSpline::FXLength2()
 {
     auto* dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit second control point length"));
-    QString length2F = VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(ui->plainTextEditLength2F->toPlainText(),
-                                 VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    QString length2F = VTranslateVars::TryFormulaFromUser(ui->plainTextEditLength2F->toPlainText(),
+                                                          VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     dialog->SetFormula(length2F);
     dialog->setPostfix(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true));
     if (dialog->exec() == QDialog::Accepted)
@@ -484,10 +480,10 @@ VSpline DialogSpline::CurrentSpline() const
 
     const bool separator = VAbstractApplication::VApp()->Settings()->GetOsSeparator();
 
-    angle1F = VAbstractApplication::VApp()->TrVars()->TryFormulaFromUser(angle1F, separator);
-    angle2F = VAbstractApplication::VApp()->TrVars()->TryFormulaFromUser(angle2F, separator);
-    length1F = VAbstractApplication::VApp()->TrVars()->TryFormulaFromUser(length1F, separator);
-    length2F = VAbstractApplication::VApp()->TrVars()->TryFormulaFromUser(length2F, separator);
+    angle1F = VTranslateVars::TryFormulaFromUser(angle1F, separator);
+    angle2F = VTranslateVars::TryFormulaFromUser(angle2F, separator);
+    length1F = VTranslateVars::TryFormulaFromUser(length1F, separator);
+    length2F = VTranslateVars::TryFormulaFromUser(length2F, separator);
 
     VSpline spline(*GetP1(), *GetP4(), angle1, angle1F, angle2, angle2F, length1, length1F,  length2, length2F);
     spline.SetApproximationScale(ui->doubleSpinBoxApproximationScale->value());
@@ -635,14 +631,14 @@ void DialogSpline::SetSpline(const VSpline &spline)
     auto path = qobject_cast<VisToolSpline *>(vis);
     SCASSERT(path != nullptr)
 
-    path->setObject1Id(spl.GetP1().id());
-    path->SetObject4Id(spl.GetP4().id());
+    path->SetPoint1Id(spl.GetP1().id());
+    path->SetPoint4Id(spl.GetP4().id());
     path->SetAngle1(spl.GetStartAngle());
     path->SetAngle2(spl.GetEndAngle());
     path->SetKAsm1(spl.GetKasm1());
     path->SetKAsm2(spl.GetKasm2());
     path->SetKCurve(spl.GetKcurve());
-    path->setApproximationScale(spl.GetApproximationScale());
+    path->SetApproximationScale(spl.GetApproximationScale());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
