@@ -47,17 +47,18 @@
 #include <Qt>
 #include <new>
 
-#include "../../tools/vabstracttool.h"
 #include "../../visualization/visualization.h"
 #include "../../visualization/path/vistoolsplinepath.h"
 #include "../ifc/xml/vdomdocument.h"
-#include "../qmuparser/qmuparsererror.h"
 #include "../support/dialogeditwrongformula.h"
 #include "../vgeometry/../ifc/ifcdef.h"
 #include "../vgeometry/vpointf.h"
 #include "../vgeometry/vsplinepoint.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
+#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
+#include "../vmisc/backport/qoverload.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
 #include "../vpatterndb/vcontainer.h"
 #include "../vwidgets/vabstractmainwindow.h"
 #include "../vwidgets/vmaingraphicsscene.h"
@@ -1003,6 +1004,45 @@ bool DialogSplinePath::IsValid() const
     return fAngle1 && fAngle2 && fLength1 && fLength2 && flagError && flagAlias;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSplinePath::showEvent(QShowEvent *event)
+{
+    QDialog::showEvent( event ); // NOLINT(bugprone-parent-virtual-call)
+    if ( event->spontaneous() )
+    {
+        return;
+    }
+    if (isInitialized)
+    {
+        return;
+    }
+    // do your init stuff here
+
+    const QSize sz = VAbstractApplication::VApp()->Settings()->GetDialogSplinePathSize();
+    if (not sz.isEmpty())
+    {
+        resize(sz);
+    }
+
+    isInitialized = true;//first show windows are held
+    ShowVisualization();
+
+    CheckState();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSplinePath::resizeEvent(QResizeEvent *event)
+{
+    // remember the size for the next time this dialog is opened, but only
+    // if widget was already initialized, which rules out the resize at
+    // dialog creating, which would
+    if (isInitialized)
+    {
+        VAbstractApplication::VApp()->Settings()->SetDialogSplinePathSize(size());
+    }
+    QDialog::resizeEvent(event);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSplinePath::SetNotes(const QString &notes)
 {
