@@ -61,12 +61,8 @@
 #include <QBuffer>
 
 #include "../ifc/xml/vdomdocument.h"
-#include "../qmuparser/qmudef.h"
-#include "../qmuparser/qmuparsererror.h"
 #include "../vgeometry/vpointf.h"
-#include "../vpatterndb/calculator.h"
 #include "../vpatterndb/vcontainer.h"
-#include "../vpatterndb/vtranslatevars.h"
 #include "../vpatterndb/vpiecenode.h"
 #include "../../tools/vabstracttool.h"
 #include "../ifc/xml/vabstractpattern.h"
@@ -75,7 +71,13 @@
 
 template <class T> class QSharedPointer;
 
-Q_LOGGING_CATEGORY(vDialog, "v.dialog")
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_CLANG("-Wmissing-prototypes")
+QT_WARNING_DISABLE_INTEL(1418)
+
+Q_LOGGING_CATEGORY(vDialog, "v.dialog") // NOLINT
+
+QT_WARNING_POP
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -92,7 +94,6 @@ DialogTool::DialogTool(const VContainer *data, quint32 toolId, QWidget *parent)
       associatedTool(nullptr),
       toolId(toolId),
       prepare(false),
-      number(0),
       vis(nullptr)
 {
     SCASSERT(data != nullptr)      
