@@ -79,7 +79,7 @@ QT_WARNING_DISABLE_GCC("-Wsuggest-final-methods")
  */
 class DialogTool : public QDialog
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 public:
     DialogTool(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
     virtual          ~DialogTool() override;
@@ -128,7 +128,6 @@ public slots:
     virtual void     PointNameChanged() {}
 protected:
     /** @brief data container with data */
-    // cppcheck-suppress duplInheritedMember
     const VContainer *data;
 
     /** @brief isInitialized true if window is initialized */
@@ -149,9 +148,6 @@ protected:
     /** @brief prepare show if we prepare. Show dialog after finish working with visual part of tool*/
     bool             prepare;
 
-    /** @brief number number of handled objects */
-    qint32           number;
-
     QPointer<Visualization> vis;
 
     virtual void     closeEvent ( QCloseEvent * event ) override;
@@ -223,7 +219,7 @@ protected:
 
     void             InitNodeAngles(QComboBox *box);
 private:
-    Q_DISABLE_COPY(DialogTool)
+    Q_DISABLE_COPY_MOVE(DialogTool) // NOLINT
     void FillList(QComboBox *box, const QMap<QString, quint32> &list)const;
 
     template <typename T>
@@ -237,6 +233,7 @@ private:
                    const quint32 &ch1 = NULL_ID, const quint32 &ch2 = NULL_ID) const;
 };
 
+// cppcheck-suppress unknownMacro
 QT_WARNING_POP
 
 //---------------------------------------------------------------------------------------------------------------------
