@@ -39,7 +39,7 @@ namespace Ui
 
 class DialogInsertNode : public DialogTool
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 
 public:
     explicit DialogInsertNode(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
@@ -66,7 +66,7 @@ private slots:
     void NodeNumberChanged(int val);
 
 private:
-    Q_DISABLE_COPY(DialogInsertNode)
+    Q_DISABLE_COPY_MOVE(DialogInsertNode) // NOLINT
     Ui::DialogInsertNode *ui;
 
     QVector<VPieceNode> m_nodes{};
