@@ -30,10 +30,12 @@
 #include "ui_dialogpiecepath.h"
 #include "../vpatterndb/vpiecenode.h"
 #include "visualization/path/vistoolpiecepath.h"
-#include "../../../tools/vabstracttool.h"
 #include "../../../tools/vtoolseamallowance.h"
 #include "../../support/dialogeditwrongformula.h"
 #include "../vmisc/vmodifierkey.h"
+#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
+#include "../vmisc/backport/qoverload.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
 
 #include <QMenu>
 #include <QTimer>
@@ -921,9 +923,8 @@ void DialogPiecePath::EvalPassmarkLength()
 
     Eval(formulaData, m_flagFormulaPassmarkLength);
 
-    UpdateNodePassmarkLength(VAbstractApplication::VApp()->TrVars()
-                             ->TryFormulaFromUser(ui->plainTextEditPassmarkLength->toPlainText(),
-                                                  VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+    UpdateNodePassmarkLength(VTranslateVars::TryFormulaFromUser(
+        ui->plainTextEditPassmarkLength->toPlainText(), VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -1392,7 +1393,7 @@ Qt::PenStyle DialogPiecePath::GetPenType() const
 void DialogPiecePath::SetPenType(const Qt::PenStyle &type)
 {
     ChangeCurrentData(ui->comboBoxPenType, PenStyleToLineStyle(type));
-    vis->setLineStyle(type);
+    vis->SetLineStyle(type);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -1584,8 +1585,7 @@ void DialogPiecePath::SetPieceId(quint32 id)
 QString DialogPiecePath::GetFormulaSAWidth() const
 {
     QString width = ui->plainTextEditFormulaWidth->toPlainText();
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(width, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(width, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -1702,24 +1702,21 @@ void DialogPiecePath::NewItem(const VPieceNode &node)
 QString DialogPiecePath::GetFormulaSAWidthBefore() const
 {
     QString width = ui->plainTextEditFormulaWidthBefore->toPlainText();
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(width, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(width, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 QString DialogPiecePath::GetFormulaSAWidthAfter() const
 {
     QString width = ui->plainTextEditFormulaWidthAfter->toPlainText();
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(width, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(width, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 QString DialogPiecePath::GetFormulaVisible() const
 {
     QString formula = ui->plainTextEditFormulaVisible->toPlainText();
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(formula, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(formula, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -1740,8 +1737,7 @@ void DialogPiecePath::SetFormulaVisible(const QString &formula)
 QString DialogPiecePath::GetFormulaPassmarkLength() const
 {
     QString formula = ui->plainTextEditPassmarkLength->toPlainText();
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(formula, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(formula, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
