@@ -29,10 +29,11 @@
 #include "ui_dialogplacelabel.h"
 
 #include "visualization/line/vistoolspecialpoint.h"
-#include "../../../tools/vabstracttool.h"
-#include "../../../tools/vtoolseamallowance.h"
 #include "../../support/dialogeditwrongformula.h"
-#include "../vgeometry/vplacelabelitem.h"
+#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
+#include "../vmisc/backport/qoverload.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
+#include "../vpatterndb/vcontainer.h"
 
 #include <QTimer>
 
@@ -101,7 +102,7 @@ void DialogPlaceLabel::SetCenterPoint(quint32 id)
     {
         VisToolSpecialPoint *point = qobject_cast<VisToolSpecialPoint *>(vis);
         SCASSERT(point != nullptr)
-        point->setObject1Id(id);
+        point->SetPointId(id);
     }
 
     CheckPoint();
@@ -126,9 +127,8 @@ void DialogPlaceLabel::SetLabelType(PlaceLabelType type)
 //---------------------------------------------------------------------------------------------------------------------
 QString DialogPlaceLabel::GetWidth() const
 {
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(ui->plainTextEditFormulaWidth->toPlainText(),
-                                 VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(ui->plainTextEditFormulaWidth->toPlainText(),
+                                              VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -146,7 +146,7 @@ void DialogPlaceLabel::SetWidth(const QString &value)
 
 //    VisToolPlaceLabel *point = qobject_cast<VisToolPlaceLabel *>(vis);
 //    SCASSERT(point != nullptr)
-//    point->setObject1Id(id);
+//    point->SetPointId(id);
 
     MoveCursorToEnd(ui->plainTextEditFormulaWidth);
 }
@@ -154,9 +154,8 @@ void DialogPlaceLabel::SetWidth(const QString &value)
 //---------------------------------------------------------------------------------------------------------------------
 QString DialogPlaceLabel::GetHeight() const
 {
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(ui->plainTextEditFormulaHeight->toPlainText(),
-                                 VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(ui->plainTextEditFormulaHeight->toPlainText(),
+                                              VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -174,7 +173,7 @@ void DialogPlaceLabel::SetHeight(const QString &value)
 
 //    VisToolPlaceLabel *point = qobject_cast<VisToolPlaceLabel *>(vis);
 //    SCASSERT(point != nullptr)
-//    point->setObject1Id(id);
+//    point->SetPointId(id);
 
     MoveCursorToEnd(ui->plainTextEditFormulaHeight);
 }
@@ -182,9 +181,8 @@ void DialogPlaceLabel::SetHeight(const QString &value)
 //---------------------------------------------------------------------------------------------------------------------
 QString DialogPlaceLabel::GetAngle() const
 {
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(ui->plainTextEditFormulaAngle->toPlainText(),
-                                 VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(ui->plainTextEditFormulaAngle->toPlainText(),
+                                              VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -202,7 +200,7 @@ void DialogPlaceLabel::SetAngle(const QString &value)
 
 //    VisToolPlaceLabel *point = qobject_cast<VisToolPlaceLabel *>(vis);
 //    SCASSERT(point != nullptr)
-//    point->setObject1Id(id);
+//    point->SetPointId(id);
 
     MoveCursorToEnd(ui->plainTextEditFormulaAngle);
 }
@@ -553,8 +551,7 @@ void DialogPlaceLabel::CheckPoint()
 QString DialogPlaceLabel::GetFormulaVisible() const
 {
     QString formula = ui->plainTextEditFormulaVisible->toPlainText();
-    return VAbstractApplication::VApp()->TrVars()
-            ->TryFormulaFromUser(formula, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(formula, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
