@@ -50,7 +50,9 @@
 #include "../vpatterndb/vtranslatevars.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
+#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #include "../vmisc/diagnostic.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #include "../vpatterndb/vcontainer.h"
 #include "../vpatterndb/vformula.h"
 #include "../ifc/ifcdef.h"
@@ -204,12 +206,13 @@ void VToolFlippingByAxis::SetVisualization()
 {
     if (not vis.isNull())
     {
-        VisToolFlippingByAxis *visual = qobject_cast<VisToolFlippingByAxis *>(vis);
+        auto *visual = qobject_cast<VisToolFlippingByAxis *>(vis);
         SCASSERT(visual != nullptr)
 
         visual->SetObjects(SourceToObjects(source));
         visual->SetOriginPointId(m_originPointId);
         visual->SetAxisType(m_axisType);
+        visual->SetMode(Mode::Show);
         visual->RefreshGeometry();
     }
 }
