@@ -50,7 +50,9 @@
 #include "../vpatterndb/vtranslatevars.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
+#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #include "../vmisc/diagnostic.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #include "../vpatterndb/vcontainer.h"
 #include "../vpatterndb/vformula.h"
 #include "../ifc/ifcdef.h"
@@ -189,12 +191,13 @@ void VToolFlippingByLine::SetVisualization()
 {
     if (not vis.isNull())
     {
-        VisToolFlippingByLine *visual = qobject_cast<VisToolFlippingByLine *>(vis);
+        auto *visual = qobject_cast<VisToolFlippingByLine *>(vis);
         SCASSERT(visual != nullptr)
 
         visual->SetObjects(SourceToObjects(source));
         visual->SetFirstLinePointId(m_firstLinePointId);
         visual->SetSecondLinePointId(m_secondLinePointId);
+        visual->SetMode(Mode::Show);
         visual->RefreshGeometry();
     }
 }
