@@ -58,7 +58,9 @@
 #include "../vpatterndb/vtranslatevars.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
+#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #include "../vmisc/diagnostic.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #include "../vpatterndb/vcontainer.h"
 #include "../vpatterndb/vformula.h"
 #include "../ifc/ifcdef.h"
@@ -339,13 +341,14 @@ void VToolRotation::SetVisualization()
 {
     if (not vis.isNull())
     {
-        VisToolRotation *visual = qobject_cast<VisToolRotation *>(vis);
+        auto *visual = qobject_cast<VisToolRotation *>(vis);
         SCASSERT(visual != nullptr)
 
         visual->SetObjects(SourceToObjects(source));
         visual->SetOriginPointId(origPointId);
         visual->SetAngle(VAbstractApplication::VApp()->TrVars()
                          ->FormulaToUser(formulaAngle, VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+        visual->SetMode(Mode::Show);
         visual->RefreshGeometry();
     }
 }
