@@ -41,15 +41,16 @@
 #include <new>
 
 #include "../ifc/exception/vexception.h"
-#include "../ifc/exception/vexceptionbadid.h"
 #include "../ifc/xml/vabstractpattern.h"
 #include "../qmuparser/qmutokenparser.h"
+#include "../qmuparser/qmudef.h"
 #include "../vgeometry/vgobject.h"
 #include "../vgeometry/vpointf.h"
 #include "../vgeometry/vspline.h"
 #include "../vgeometry/vabstractarc.h"
 #include "../vpatterndb/vcontainer.h"
 #include "../vwidgets/vcontrolpointspline.h"
+#include "../vwidgets/global.h"
 #include "../../../visualization/line/visline.h"
 #include "../../vabstracttool.h"
 #include "../vdrawtool.h"
