@@ -347,19 +347,19 @@ void VToolArcWithLength::SetVisualization()
     if (not vis.isNull())
     {
         const QSharedPointer<VArc> arc = VAbstractTool::data.GeometricObject<VArc>(m_id);
-        VisToolArcWithLength *visual = qobject_cast<VisToolArcWithLength *>(vis);
+        auto *visual = qobject_cast<VisToolArcWithLength *>(vis);
         SCASSERT(visual != nullptr)
 
+        const bool osSeparator = VAbstractApplication::VApp()->Settings()->GetOsSeparator();
         const VTranslateVars *trVars = VAbstractApplication::VApp()->TrVars();
-        visual->setObject1Id(arc->GetCenter().id());
-        visual->setRadius(trVars->FormulaToUser(arc->GetFormulaRadius(),
-                                                VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
-        visual->setF1(trVars->FormulaToUser(arc->GetFormulaF1(),
-                                            VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
-        visual->setLength(trVars->FormulaToUser(arc->GetFormulaLength(),
-                                                VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
-        visual->setLineStyle(LineStyleToPenStyle(arc->GetPenStyle()));
-        visual->setApproximationScale(arc->GetApproximationScale());
+
+        visual->SetCenterId(arc->GetCenter().id());
+        visual->SetRadius(trVars->FormulaToUser(arc->GetFormulaRadius(), osSeparator));
+        visual->SetF1(trVars->FormulaToUser(arc->GetFormulaF1(), osSeparator));
+        visual->SetLength(trVars->FormulaToUser(arc->GetFormulaLength(), osSeparator));
+        visual->SetLineStyle(LineStyleToPenStyle(arc->GetPenStyle()));
+        visual->SetApproximationScale(arc->GetApproximationScale());
+        visual->SetMode(Mode::Show);
         visual->RefreshGeometry();
     }
 }
