@@ -125,6 +125,7 @@ VToolEllipticalArc* VToolEllipticalArc::Create(const QPointer<DialogTool> &dialo
     initData.data = data;
     initData.parse = Document::FullParse;
     initData.typeCreation = Source::FromGui;
+    initData.approximationScale = dialogTool->GetApproximationScale();
     initData.notes = dialogTool->GetNotes();
     initData.aliasSuffix = dialogTool->GetAliasSuffix();
     //initData.approximationScale = dialogTool->GetApproximationScale(); // For future use
@@ -333,6 +334,24 @@ void VToolEllipticalArc::SetFormulaRotationAngle(const VFormula &value)
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+qreal VToolEllipticalArc::GetApproximationScale() const
+{
+    QSharedPointer<VEllipticalArc> arc = VAbstractTool::data.GeometricObject<VEllipticalArc>(m_id);
+    SCASSERT(arc.isNull() == false)
+
+    return arc->GetApproximationScale();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VToolEllipticalArc::SetApproximationScale(qreal value)
+{
+    QSharedPointer<VGObject> obj = VAbstractTool::data.GetGObject(m_id);
+    QSharedPointer<VEllipticalArc> arc = qSharedPointerDynamicCast<VEllipticalArc>(obj);
+    arc->SetApproximationScale(value);
+    SaveOption(obj);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void VToolEllipticalArc::ShowVisualization(bool show)
 {
@@ -388,6 +407,7 @@ void VToolEllipticalArc::SaveDialog(QDomElement &domElement, QList<quint32> &old
     doc->SetAttribute(domElement, AttrRotationAngle, dialogTool->GetRotationAngle());
     doc->SetAttribute(domElement, AttrColor, dialogTool->GetColor());
     doc->SetAttribute(domElement, AttrPenStyle, dialogTool->GetPenStyle());
+    doc->SetAttribute(domElement, AttrAScale, dialogTool->GetApproximationScale());
     doc->SetAttributeOrRemoveIf<QString>(domElement, AttrAlias, dialogTool->GetAliasSuffix(),
                                          [](const QString &suffix) noexcept {return suffix.isEmpty();});
     doc->SetAttributeOrRemoveIf<QString>(domElement, AttrNotes, dialogTool->GetNotes(),
@@ -417,22 +437,21 @@ void VToolEllipticalArc::SetVisualization()
     if (not vis.isNull())
     {
         const QSharedPointer<VEllipticalArc> elArc = VAbstractTool::data.GeometricObject<VEllipticalArc>(m_id);
-        VisToolEllipticalArc *visual = qobject_cast<VisToolEllipticalArc *>(vis);
+        auto *visual = qobject_cast<VisToolEllipticalArc *>(vis);
         SCASSERT(visual != nullptr)
 
+        const bool osSeparator = VAbstractApplication::VApp()->Settings()->GetOsSeparator();
         const VTranslateVars *trVars = VAbstractApplication::VApp()->TrVars();
-        visual->setObject1Id(elArc->GetCenter().id());
-        visual->setRadius1(trVars->FormulaToUser(elArc->GetFormulaRadius1(),
-                                                 VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
-        visual->setRadius2(trVars->FormulaToUser(elArc->GetFormulaRadius2(),
-                                                 VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
-        visual->setF1(trVars->FormulaToUser(elArc->GetFormulaF1(),
-                                            VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
-        visual->setF2(trVars->FormulaToUser(elArc->GetFormulaF2(),
-                                            VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
-        visual->setRotationAngle(trVars->FormulaToUser(elArc->GetFormulaRotationAngle(),
-                                                       VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
-        visual->setLineStyle(LineStyleToPenStyle(elArc->GetPenStyle()));
+
+        visual->SetCenterId(elArc->GetCenter().id());
+        visual->SetRadius1(trVars->FormulaToUser(elArc->GetFormulaRadius1(), osSeparator));
+        visual->SetRadius2(trVars->FormulaToUser(elArc->GetFormulaRadius2(), osSeparator));
+        visual->SetF1(trVars->FormulaToUser(elArc->GetFormulaF1(), osSeparator));
+        visual->SetF2(trVars->FormulaToUser(elArc->GetFormulaF2(), osSeparator));
+        visual->SetRotationAngle(trVars->FormulaToUser(elArc->GetFormulaRotationAngle(), osSeparator));
+        visual->SetLineStyle(LineStyleToPenStyle(elArc->GetPenStyle()));
+        visual->SetApproximationScale(elArc->GetApproximationScale());
+        visual->SetMode(Mode::Show);
         visual->RefreshGeometry();
     }
 }
