@@ -46,6 +46,7 @@
 #include <QVector>
 #include <Qt>
 #include <new>
+#include <QtMath>
 
 #include "../../../dialogs/tools/dialogspline.h"
 #include "../../../dialogs/tools/dialogtool.h"
@@ -59,10 +60,10 @@
 #include "../vgeometry/vgobject.h"
 #include "../vgeometry/vpointf.h"
 #include "../vmisc/vabstractapplication.h"
-#include "../vmisc/vmath.h"
 #include "../vpatterndb/vcontainer.h"
 #include "../vwidgets/vcontrolpointspline.h"
 #include "../vwidgets/vmaingraphicsscene.h"
+#include "../vwidgets/global.h"
 #include "../../vabstracttool.h"
 #include "../vdrawtool.h"
 #include "vabstractspline.h"
@@ -539,19 +540,19 @@ void VToolSpline::SetVisualization()
 {
     if (not vis.isNull())
     {
-        VisToolSpline *visual = qobject_cast<VisToolSpline *>(vis);
+        auto *visual = qobject_cast<VisToolSpline *>(vis);
         SCASSERT(visual != nullptr)
 
         const QSharedPointer<VSpline> spl = VAbstractTool::data.GeometricObject<VSpline>(m_id);
-        visual->setObject1Id(spl->GetP1().id());
-        visual->SetObject4Id(spl->GetP4().id());
+        visual->SetPoint1Id(spl->GetP1().id());
+        visual->SetPoint4Id(spl->GetP4().id());
         visual->SetAngle1(spl->GetStartAngle());
         visual->SetAngle2(spl->GetEndAngle());
         visual->SetKAsm1(spl->GetKasm1());
         visual->SetKAsm2(spl->GetKasm2());
         visual->SetKCurve(spl->GetKcurve());
-        visual->setLineStyle(LineStyleToPenStyle(spl->GetPenStyle()));
-        visual->setApproximationScale(spl->GetApproximationScale());
+        visual->SetLineStyle(LineStyleToPenStyle(spl->GetPenStyle()));
+        visual->SetApproximationScale(spl->GetApproximationScale());
         visual->SetMode(Mode::Show);
         visual->RefreshGeometry();
     }
