@@ -108,6 +108,15 @@ void VToolDoublePoint::setNameP2(const QString &name)
     SetPointName(p2id, name);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VToolDoublePoint::SetNotes(const QString &notes)
+{
+    m_notes = notes;
+
+    QSharedPointer<VGObject> obj = VContainer::GetFakeGObject(m_id);
+    SaveOption(obj);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void VToolDoublePoint::GroupVisibility(quint32 object, bool visible)
 {
