@@ -46,11 +46,11 @@ class VSimplePoint;
 
 class VToolDoublePoint: public VAbstractPoint, public QGraphicsPathItem
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 public:
     VToolDoublePoint(VAbstractPattern *doc, VContainer *data, quint32 id, quint32 p1id, quint32 p2id,
                      const QString &notes, QGraphicsItem * parent = nullptr);
-    virtual ~VToolDoublePoint() Q_DECL_EQ_DEFAULT;
+    virtual ~VToolDoublePoint() = default;
 
     virtual int   type() const override {return Type;}
     enum { Type = UserType + static_cast<int>(Tool::DoublePoint)};
@@ -102,7 +102,7 @@ protected:
     QString ComplexToolTip(quint32 itemId) const;
 
 private:
-    Q_DISABLE_COPY(VToolDoublePoint)
+    Q_DISABLE_COPY_MOVE(VToolDoublePoint) // NOLINT
 };
 
 #endif // VTOOLDOUBLEPOINT_H
