@@ -222,7 +222,7 @@ VPointF *VToolCutSplinePath::CutSplinePath(qreal length, const QSharedPointer<VA
     QPointF spl1p2, spl1p3, spl2p2, spl2p3;
     qint32 p1 = 0, p2 = 0;
 
-    const QPointF point = splPath->CutSplinePath(length, p1, p2, spl1p2, spl1p3, spl2p2, spl2p3);
+    const QPointF point = splPath->CutSplinePath(length, p1, p2, spl1p2, spl1p3, spl2p2, spl2p3, pName);
     VPointF *p = new VPointF(point);
     p->setName(pName);
 
@@ -360,16 +360,16 @@ void VToolCutSplinePath::SetVisualization()
 {
     if (not vis.isNull())
     {
-        VisToolCutSplinePath *visual = qobject_cast<VisToolCutSplinePath *>(vis);
+        auto *visual = qobject_cast<VisToolCutSplinePath *>(vis);
         SCASSERT(visual != nullptr)
 
-        visual->setObject1Id(baseCurveId);
-        visual->setLength(VAbstractApplication::VApp()->TrVars()
+        visual->SetSplinePathId(baseCurveId);
+        visual->SetLength(VAbstractApplication::VApp()->TrVars()
                           ->FormulaToUser(formula, VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
 
         const QSharedPointer<VAbstractCurve> curve = VAbstractTool::data.GeometricObject<VAbstractCurve>(baseCurveId);
-        visual->setLineStyle(LineStyleToPenStyle(curve->GetPenStyle()));
-
+        visual->SetLineStyle(LineStyleToPenStyle(curve->GetPenStyle()));
+        visual->SetMode(Mode::Show);
         visual->RefreshGeometry();
     }
 }
