@@ -225,15 +225,16 @@ void VToolEndLine::SetVisualization()
 {
     if (not vis.isNull())
     {
-        VisToolEndLine *visual = qobject_cast<VisToolEndLine *>(vis);
+        auto *visual = qobject_cast<VisToolEndLine *>(vis);
         SCASSERT(visual != nullptr)
 
-        visual->setObject1Id(basePointId);
-        visual->setLength(VAbstractApplication::VApp()->TrVars()
-                          ->FormulaToUser(formulaLength, VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
-        visual->SetAngle(VAbstractApplication::VApp()->TrVars()
-                         ->FormulaToUser(formulaAngle, VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
-        visual->setLineStyle(LineStyleToPenStyle(m_lineType));
+        const bool osSeparator = VAbstractApplication::VApp()->Settings()->GetOsSeparator();
+        const VTranslateVars *trVars = VAbstractApplication::VApp()->TrVars();
+
+        visual->SetBasePointId(basePointId);
+        visual->SetLength(trVars->FormulaToUser(formulaLength, osSeparator));
+        visual->SetAngle(trVars->FormulaToUser(formulaAngle, osSeparator));
+        visual->SetLineStyle(LineStyleToPenStyle(m_lineType));
         visual->SetMode(Mode::Show);
         visual->RefreshGeometry();
     }
