@@ -257,13 +257,14 @@ void VToolHeight::SetVisualization()
 {
     if (not vis.isNull())
     {
-        VisToolHeight *visual = qobject_cast<VisToolHeight *>(vis);
+        auto *visual = qobject_cast<VisToolHeight *>(vis);
         SCASSERT(visual != nullptr)
 
-        visual->setObject1Id(basePointId);
-        visual->setLineP1Id(p1LineId);
-        visual->setLineP2Id(p2LineId);
-        visual->setLineStyle(LineStyleToPenStyle(m_lineType));
+        visual->SetBasePointId(basePointId);
+        visual->SetLineP1Id(p1LineId);
+        visual->SetLineP2Id(p2LineId);
+        visual->SetLineStyle(LineStyleToPenStyle(m_lineType));
+        visual->SetMode(Mode::Show);
         visual->RefreshGeometry();
     }
 }
