@@ -331,12 +331,13 @@ void VToolPointFromArcAndTangent::SetVisualization()
 {
     if (not vis.isNull())
     {
-        VisToolPointFromArcAndTangent *visual = qobject_cast<VisToolPointFromArcAndTangent *>(vis);
+        auto *visual = qobject_cast<VisToolPointFromArcAndTangent *>(vis);
         SCASSERT(visual != nullptr)
 
-        visual->setObject1Id(tangentPointId);
-        visual->setArcId(arcId);
-        visual->setCrossPoint(crossPoint);
+        visual->SetPointId(tangentPointId);
+        visual->SetArcId(arcId);
+        visual->SetCrossPoint(crossPoint);
+        visual->SetMode(Mode::Show);
         visual->RefreshGeometry();
     }
 }
