@@ -237,11 +237,12 @@ void VToolPointOfIntersection::SetVisualization()
 {
     if (not vis.isNull())
     {
-        VisToolPointOfIntersection *visual = qobject_cast<VisToolPointOfIntersection *>(vis);
+        auto *visual = qobject_cast<VisToolPointOfIntersection *>(vis);
         SCASSERT(visual != nullptr)
 
-        visual->setObject1Id(firstPointId);
-        visual->setPoint2Id(secondPointId);
+        visual->SetPoint1Id(firstPointId);
+        visual->SetPoint2Id(secondPointId);
+        visual->SetMode(Mode::Show);
         visual->RefreshGeometry();
     }
 }
