@@ -351,12 +351,13 @@ void VToolPointOfIntersectionArcs::SetVisualization()
 {
     if (not vis.isNull())
     {
-        VisToolPointOfIntersectionArcs *visual = qobject_cast<VisToolPointOfIntersectionArcs *>(vis);
+        auto *visual = qobject_cast<VisToolPointOfIntersectionArcs *>(vis);
         SCASSERT(visual != nullptr)
 
-        visual->setArc1Id(firstArcId);
-        visual->setArc2Id(secondArcId);
-        visual->setCrossPoint(crossPoint);
+        visual->SetArc1Id(firstArcId);
+        visual->SetArc2Id(secondArcId);
+        visual->SetCrossPoint(crossPoint);
+        visual->SetMode(Mode::Show);
         visual->RefreshGeometry();
     }
 }
