@@ -367,14 +367,19 @@ void VToolPointOfIntersectionCircles::SetVisualization()
 {
     if (not vis.isNull())
     {
-        VisToolPointOfIntersectionCircles *visual = qobject_cast<VisToolPointOfIntersectionCircles *>(vis);
+        auto *visual = qobject_cast<VisToolPointOfIntersectionCircles *>(vis);
         SCASSERT(visual != nullptr)
 
-        visual->setObject1Id(firstCircleCenterId);
-        visual->setObject2Id(secondCircleCenterId);
-        visual->setC1Radius(firstCircleRadius);
-        visual->setC2Radius(secondCircleRadius);
-        visual->setCrossPoint(crossPoint);
+        visual->SetCircle1Id(firstCircleCenterId);
+        visual->SetCircle2Id(secondCircleCenterId);
+
+        const bool osSeparator = VAbstractApplication::VApp()->Settings()->GetOsSeparator();
+        const VTranslateVars *trVars = VAbstractApplication::VApp()->TrVars();
+
+        visual->SetC1Radius(trVars->FormulaToUser(firstCircleRadius, osSeparator));
+        visual->SetC2Radius(trVars->FormulaToUser(secondCircleRadius, osSeparator));
+        visual->SetCrossPoint(crossPoint);
+        visual->SetMode(Mode::Show);
         visual->RefreshGeometry();
     }
 }
