@@ -46,10 +46,8 @@
 #include "../../../../undocommands/label/movelabel.h"
 #include "../../../../undocommands/label/showlabel.h"
 #include "../ifc/exception/vexception.h"
-#include "../ifc/exception/vexceptionbadid.h"
 #include "../ifc/ifcdef.h"
 #include "../ifc/xml/vabstractpattern.h"
-#include "../vmisc/diagnostic.h"
 #include "../vgeometry/vgobject.h"
 #include "../vgeometry/vpointf.h"
 #include "../vgeometry/vabstractcubicbezierpath.h"
@@ -62,6 +60,7 @@
 #include "../vpatterndb/vcontainer.h"
 #include "../vwidgets/vgraphicssimpletextitem.h"
 #include "../vwidgets/scalesceneitems.h"
+#include "../vwidgets/global.h"
 #include "../../../vabstracttool.h"
 #include "../../vdrawtool.h"
 #include "../vabstractpoint.h"
@@ -71,7 +70,7 @@ QT_WARNING_PUSH
 QT_WARNING_DISABLE_CLANG("-Wmissing-prototypes")
 QT_WARNING_DISABLE_INTEL(1418)
 
-Q_LOGGING_CATEGORY(vToolSinglePoint, "v.toolSinglePoint")
+Q_LOGGING_CATEGORY(vToolSinglePoint, "v.toolSinglePoint") // NOLINT
 
 QT_WARNING_POP
 
@@ -415,11 +414,11 @@ auto VToolSinglePoint::InitSegments(GOType curveType, qreal segLength, const VPo
             QPointF spl1p2, spl1p3, spl2p2, spl2p3;
             if (not VFuzzyComparePossibleNulls(segLength, -1))
             {
-                spl->CutSpline(segLength, spl1p2, spl1p3, spl2p2, spl2p3);
+                spl->CutSpline(segLength, spl1p2, spl1p3, spl2p2, spl2p3, p->name());
             }
             else
             {
-                spl->CutSpline(0, spl1p2, spl1p3, spl2p2, spl2p3);
+                spl->CutSpline(0, spl1p2, spl1p3, spl2p2, spl2p3, p->name());
             }
 
             VSpline *spl1 = new VSpline(spl->GetP1(), spl1p2, spl1p3, *p);
