@@ -65,11 +65,11 @@ struct VToolSinglePointInitData : VDrawToolInitData
  */
 class VToolSinglePoint: public VAbstractPoint, public VScenePoint
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 public:
     VToolSinglePoint(VAbstractPattern *doc, VContainer *data, quint32 id, const QString &notes,
                      QGraphicsItem * parent = nullptr);
-    virtual ~VToolSinglePoint() Q_DECL_EQ_DEFAULT;
+    virtual ~VToolSinglePoint() = default;
 
     virtual int type() const override {return Type;}
     enum { Type = UserType + static_cast<int>(Tool::SinglePoint)};
@@ -113,7 +113,7 @@ protected:
     static QPair<QString, QString> InitSegments(GOType curveType, qreal segLength, const VPointF *p, quint32 curveId,
                                                 VContainer *data, const QString &alias1, const QString &alias2);
 private:
-    Q_DISABLE_COPY(VToolSinglePoint)
+    Q_DISABLE_COPY_MOVE(VToolSinglePoint) // NOLINT
 };
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -131,11 +131,11 @@ inline auto VToolSinglePoint::InitArc(VContainer *data, qreal segLength, const V
 
     if (not VFuzzyComparePossibleNulls(segLength, -1))
     {
-        arc->CutArc(segLength, arc1, arc2);
+        arc->CutArc(segLength, arc1, arc2, p->name());
     }
     else
     {
-        arc->CutArc(0, arc1, arc2);
+        arc->CutArc(0, arc1, arc2, p->name());
     }
 
     // Arc highly depend on id. Need for creating the name.
