@@ -45,7 +45,7 @@
  */
 class VNodeSplinePath : public VAbstractNode
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 public:
     static void Create(const VAbstractNodeInitData &initData);
 
@@ -60,9 +60,10 @@ protected:
     virtual void ShowNode() override {}
     virtual void HideNode() override {}
 private:
-    Q_DISABLE_COPY(VNodeSplinePath)
+    // cppcheck-suppress unknownMacro
+    Q_DISABLE_COPY_MOVE(VNodeSplinePath) // NOLINT
 
-    VNodeSplinePath(const VAbstractNodeInitData &initData, QObject *qoParent = nullptr);
+    explicit VNodeSplinePath(const VAbstractNodeInitData &initData, QObject *qoParent = nullptr);
 };
 
 #endif // VNODESPLINEPATH_H
