@@ -44,7 +44,9 @@
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/def.h"
 #include "../vwidgets/vmaingraphicsscene.h"
+#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #include "../vmisc/diagnostic.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #include "vdatatool.h"
 
 class VGraphicsSimpleTextItem;
@@ -83,7 +85,7 @@ QT_WARNING_POP
  */
 class VAbstractTool: public VDataTool
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 public:
     VAbstractTool(VAbstractPattern *doc, VContainer *data, quint32 id, QObject *parent = nullptr);
     virtual ~VAbstractTool() override;
@@ -181,7 +183,7 @@ protected:
     static quint32 PrepareNode(const VPieceNode &node, VMainGraphicsScene *scene, VAbstractPattern *doc,
                                VContainer *data);
 private:
-    Q_DISABLE_COPY(VAbstractTool)
+    Q_DISABLE_COPY_MOVE(VAbstractTool) // NOLINT
 };
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -209,7 +211,8 @@ template <typename T>
 inline void VAbstractTool::AddVisualization()
 {
     T *visual = new T(getData());
-    VMainGraphicsScene *scene = qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
+    auto *scene = qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
+    // cppcheck-suppress unknownMacro
     SCASSERT(scene != nullptr)
     scene->addItem(visual);
 
