@@ -39,7 +39,9 @@
 #include <QtAlgorithms>
 #include <new>
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #include "../vmisc/diagnostic.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #include "../vmisc/vmodifierkey.h"
 #include "../vgeometry/vabstractcurve.h"
 #include "../vgeometry/varc.h"
@@ -51,27 +53,17 @@
 #include "../vgeometry/vpointf.h"
 #include "../vgeometry/vspline.h"
 #include "../vgeometry/vsplinepath.h"
-#include "../vmisc/vabstractapplication.h"
 #include "../vpatterndb/vcontainer.h"
-#include "../vwidgets/vmaingraphicsscene.h"
+#include "../vwidgets/global.h"
 #include "visoperation.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 VisToolRotation::VisToolRotation(const VContainer *data, QGraphicsItem *parent)
-    : VisOperation(data, parent),
-      angle(INT_MIN),
-      point(nullptr),
-      angleArc(nullptr),
-      xAxis(nullptr)
-{
-    point = InitPoint(supportColor2, this);
-    angleArc = InitItem<VCurvePathItem>(supportColor2, this);
-    xAxis = InitItem<VScaledLine>(supportColor2, this);
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-VisToolRotation::~VisToolRotation()
+    : VisOperation(data, parent)
 {
+    m_point = InitPoint(Color(VColor::SupportColor2), this);
+    m_angleArc = InitItem<VCurvePathItem>(Color(VColor::SupportColor2), this);
+    m_xAxis = InitItem<VScaledLine>(Color(VColor::SupportColor2), this);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -80,7 +72,7 @@ QT_WARNING_DISABLE_GCC("-Wswitch-default")
 
 void VisToolRotation::RefreshGeometry()
 {
-    if (objects.isEmpty())
+    if (Objects().isEmpty())
     {
         return;
     }
@@ -89,15 +81,15 @@ void VisToolRotation::RefreshGeometry()
 
     qreal tempAngle = 0;
 
-    if (object1Id != NULL_ID)
+    if (m_originPointId != NULL_ID)
     {
-        origin = Visualization::data->GeometricObject<VPointF>(object1Id);
-        DrawPoint(point, static_cast<QPointF>(*origin), supportColor2);
+        origin = GetData()->GeometricObject<VPointF>(m_originPointId);
+        DrawPoint(m_point, static_cast<QPointF>(*origin), Color(VColor::SupportColor2));
 
         QLineF rLine;
-        if (VFuzzyComparePossibleNulls(angle, INT_MIN))
+        if (VFuzzyComparePossibleNulls(m_angle, INT_MIN))
         {
-            rLine = QLineF(static_cast<QPointF>(*origin), Visualization::scenePos);
+            rLine = QLineF(static_cast<QPointF>(*origin), ScenePos());
 
             if (QGuiApplication::keyboardModifiers() == Qt::ShiftModifier)
             {
@@ -109,28 +101,27 @@ void VisToolRotation::RefreshGeometry()
         }
         else
         {
-            rLine = QLineF(static_cast<QPointF>(*origin), Ray(static_cast<QPointF>(*origin), angle));
-            tempAngle = angle;
+            rLine = QLineF(static_cast<QPointF>(*origin), Ray(static_cast<QPointF>(*origin), m_angle));
+            tempAngle = m_angle;
         }
 
-        DrawLine(this, rLine, supportColor2, Qt::DashLine);
-        DrawLine(xAxis, QLineF(static_cast<QPointF>(*origin), Ray(static_cast<QPointF>(*origin), 0)), supportColor2,
-                 Qt::DashLine);
+        DrawLine(this, rLine, Color(VColor::SupportColor2), Qt::DashLine);
+        DrawLine(m_xAxis, QLineF(static_cast<QPointF>(*origin), Ray(static_cast<QPointF>(*origin), 0)),
+                 Color(VColor::SupportColor2), Qt::DashLine);
 
         VArc arc(*origin, ScaledRadius(SceneScale(VAbstractValApplication::VApp()->getCurrentScene()))*2, 0, tempAngle);
-        DrawPath(angleArc, arc.GetPath(), supportColor2, Qt::SolidLine, Qt::RoundCap);
+        DrawPath(m_angleArc, arc.GetPath(), Color(VColor::SupportColor2), Qt::SolidLine, Qt::RoundCap);
 
-        Visualization::toolTip = tr("Rotating angle = %1°, <b>%2</b> - sticking angle, "
-                                    "<b>Mouse click</b> - finish creation")
-                .arg(tempAngle)
-                .arg(VModifierKey::Shift());
+        SetToolTip(tr("Rotating angle = %1°, <b>%2</b> - sticking angle, "
+                      "<b>Mouse click</b> - finish creation")
+                       .arg(AngleToUser(tempAngle), VModifierKey::Shift()));
     }
 
     int iPoint = -1;
     int iCurve = -1;
-    for (auto id : qAsConst(objects))
+    for (auto id : Objects())
     {
-        const QSharedPointer<VGObject> obj = Visualization::data->GetGObject(id);
+        const QSharedPointer<VGObject> obj = GetData()->GetGObject(id);
 
         // This check helps to find missed objects in the switch
         Q_STATIC_ASSERT_X(static_cast<int>(GOType::Unknown) == 8, "Not all objects was handled.");
@@ -139,19 +130,19 @@ void VisToolRotation::RefreshGeometry()
         {
             case GOType::Point:
             {
-                const QSharedPointer<VPointF> p = Visualization::data->GeometricObject<VPointF>(id);
+                const QSharedPointer<VPointF> p = GetData()->GeometricObject<VPointF>(id);
 
                 ++iPoint;
-                VScaledEllipse *point = GetPoint(static_cast<quint32>(iPoint), supportColor2);
-                DrawPoint(point, static_cast<QPointF>(*p), supportColor2);
+                VScaledEllipse *point = GetPoint(static_cast<quint32>(iPoint), Color(VColor::SupportColor2));
+                DrawPoint(point, static_cast<QPointF>(*p), Color(VColor::SupportColor2));
 
                 ++iPoint;
-                point = GetPoint(static_cast<quint32>(iPoint), supportColor);
+                point = GetPoint(static_cast<quint32>(iPoint), Color(VColor::SupportColor));
 
-                if (object1Id != NULL_ID)
+                if (m_originPointId != NULL_ID)
                 {
                     DrawPoint(point, static_cast<QPointF>(p->Rotate(static_cast<QPointF>(*origin), tempAngle)),
-                              supportColor);
+                              Color(VColor::SupportColor));
                 }
                 break;
             }
@@ -192,16 +183,11 @@ void VisToolRotation::RefreshGeometry()
         }
     }
 }
+
 QT_WARNING_POP
 
 //---------------------------------------------------------------------------------------------------------------------
-void VisToolRotation::SetOriginPointId(quint32 value)
-{
-    object1Id = value;
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-QString VisToolRotation::Angle() const
+auto VisToolRotation::Angle() const -> QString
 {
     return QString::number(line().angle());
 }
@@ -209,25 +195,27 @@ QString VisToolRotation::Angle() const
 //---------------------------------------------------------------------------------------------------------------------
 void VisToolRotation::SetAngle(const QString &expression)
 {
-    angle = FindValFromUser(expression, Visualization::data->DataVariables());
+    m_angle = FindValFromUser(expression, GetData()->DataVariables());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 template <class Item>
-int VisToolRotation::AddCurve(qreal angle, const QPointF &origin, quint32 id, int i)
+auto VisToolRotation::AddCurve(qreal angle, const QPointF &origin, quint32 id, int i) -> int
 {
-    const QSharedPointer<Item> curve = Visualization::data->template GeometricObject<Item>(id);
+    const QSharedPointer<Item> curve = GetData()->template GeometricObject<Item>(id);
 
     ++i;
-    VCurvePathItem *path = GetCurve(static_cast<quint32>(i), supportColor2);
-    DrawPath(path, curve->GetPath(), curve->DirectionArrows(), supportColor2, Qt::SolidLine, Qt::RoundCap);
+    VCurvePathItem *path = GetCurve(static_cast<quint32>(i), Color(VColor::SupportColor2));
+    DrawPath(path, curve->GetPath(), curve->DirectionArrows(), Color(VColor::SupportColor2), Qt::SolidLine,
+             Qt::RoundCap);
 
     ++i;
-    path = GetCurve(static_cast<quint32>(i), supportColor);
-    if (object1Id != NULL_ID)
+    path = GetCurve(static_cast<quint32>(i), Color(VColor::SupportColor));
+    if (m_originPointId != NULL_ID)
     {
         const Item rotated = curve->Rotate(origin, angle);
-        DrawPath(path, rotated.GetPath(), rotated.DirectionArrows(), supportColor, Qt::SolidLine, Qt::RoundCap);
+        DrawPath(path, rotated.GetPath(), rotated.DirectionArrows(), Color(VColor::SupportColor), Qt::SolidLine,
+                 Qt::RoundCap);
     }
 
     return i;
