@@ -30,8 +30,6 @@
 
 #include <QPen>
 
-#include "../ifc/ifcdef.h"
-#include "../vmisc/vabstractapplication.h"
 #include "../vpatterndb/vcontainer.h"
 #include "../visualization.h"
 #include "../vwidgets/vsimplepoint.h"
@@ -39,19 +37,18 @@
 //---------------------------------------------------------------------------------------------------------------------
 VisPath::VisPath(const VContainer *data, QGraphicsItem *parent)
     : Visualization(data),
-      VCurvePathItem(parent),
-      m_approximationScale(0)
+      VCurvePathItem(parent)
 {
-    this->setZValue(1);// Show on top real tool
-    InitPen();
+    setZValue(1);// Show on top real tool
+    VisPath::InitPen();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VisPath::InitPen()
 {
     QPen visPen = pen();
-    visPen.setColor(mainColor);
-    visPen.setStyle(lineStyle);
+    visPen.setColor(Color(VColor::MainColor));
+    visPen.setStyle(LineStyle());
 
     setPen(visPen);
 }
@@ -63,27 +60,24 @@ void VisPath::AddOnScene()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VSimplePoint *VisPath::GetPoint(QVector<VSimplePoint *> &points, quint32 i, const QColor &color)
+auto VisPath::GetPoint(QVector<VSimplePoint *> &points, quint32 i, const QColor &color) -> VSimplePoint *
 {
     if (not points.isEmpty() && static_cast<quint32>(points.size() - 1) >= i)
     {
         return points.at(static_cast<int>(i));
     }
-    else
-    {
-        VSimplePoint *point = new VSimplePoint(NULL_ID, color);
-        point->SetPointHighlight(true);
-        point->setParentItem(this);
-        point->SetVisualizationMode(true);
-        points.append(point);
 
-        return point;
-    }
-    return nullptr;
+    auto *point = new VSimplePoint(NULL_ID, color);
+    point->SetPointHighlight(true);
+    point->setParentItem(this);
+    point->SetVisualizationMode(true);
+    points.append(point);
+
+    return point;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VisPath::setApproximationScale(qreal approximationScale)
+void VisPath::SetApproximationScale(qreal approximationScale)
 {
     m_approximationScale = approximationScale;
 }
