@@ -37,27 +37,43 @@
 #include <QtGlobal>
 
 #include "../vmisc/def.h"
+#include "defglobal.h"
 #include "vispath.h"
 
 class VisToolArc final : public VisPath
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 public:
     explicit VisToolArc(const VContainer *data, QGraphicsItem *parent = nullptr);
-    virtual ~VisToolArc() Q_DECL_EQ_DEFAULT;
+    ~VisToolArc() override =default;
+
+    void RefreshGeometry() override;
+    void VisualMode(quint32 id) override;
+
+    void SetCenterId(quint32 newCenterId);
+    void SetRadius(const QString &expression);
+    void SetF1(const QString &expression);
+    void SetF2(const QString &expression);
+
+    auto type() const -> int override {return Type;}
+    enum {Type = UserType + static_cast<int>(Vis::ToolArc)};
+
+    auto StickyEnd(qreal angle) const -> qreal;
 
-    virtual void RefreshGeometry() override;
-    void         setRadius(const QString &expression);
-    void         setF1(const QString &expression);
-    void         setF2(const QString &expression);
-    virtual int  type() const override {return Type;}
-    enum { Type = UserType + static_cast<int>(Vis::ToolArc)};
 private:
-    Q_DISABLE_COPY(VisToolArc)
-    VScaledEllipse *arcCenter;
-    qreal           radius;
-    qreal           f1;
-    qreal           f2;
+    Q_DISABLE_COPY_MOVE(VisToolArc) // NOLINT
+    VScaledEllipse *m_arcCenter{nullptr};
+    VScaledEllipse *m_f1Point{nullptr};
+    qreal           m_radius{0};
+    qreal           m_f1{-1};
+    qreal           m_f2{-1};
+    quint32         m_centerId{NULL_ID};
 };
 
+//---------------------------------------------------------------------------------------------------------------------
+inline void VisToolArc::SetCenterId(quint32 newCenterId)
+{
+    m_centerId = newCenterId;
+}
+
 #endif // VISTOOLARC_H
