@@ -41,21 +41,33 @@
 
 class VisToolCutArc final : public VisPath
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 public:
     explicit VisToolCutArc(const VContainer *data, QGraphicsItem *parent = nullptr);
-    virtual ~VisToolCutArc() Q_DECL_EQ_DEFAULT;
+    ~VisToolCutArc() override = default;
 
-    virtual void RefreshGeometry() override;
-    void         setLength(const QString &expression);
-    virtual int  type() const override {return Type;}
-    enum { Type = UserType + static_cast<int>(Vis::ToolCutArc)};
-protected:
-    Q_DISABLE_COPY(VisToolCutArc)
-    VScaledEllipse *point;
-    VCurvePathItem *arc1;
-    VCurvePathItem *arc2;
-    qreal           length;
+    void RefreshGeometry() override;
+    void VisualMode(quint32 id) override;
+
+    void SetArcId(quint32 newArcId);
+    void SetLength(const QString &expression);
+
+    auto type() const -> int override {return Type;}
+    enum {Type = UserType + static_cast<int>(Vis::ToolCutArc)};
+
+private:
+    Q_DISABLE_COPY_MOVE(VisToolCutArc) // NOLINT
+    VScaledEllipse *m_point{nullptr};
+    VCurvePathItem *m_arc1{nullptr};
+    VCurvePathItem *m_arc2{nullptr};
+    qreal           m_length{0};
+    quint32         m_arcId{NULL_ID};
 };
 
+//---------------------------------------------------------------------------------------------------------------------
+inline void VisToolCutArc::SetArcId(quint32 newArcId)
+{
+    m_arcId = newArcId;
+}
+
 #endif // VISTOOLCUTARC_H
