@@ -43,28 +43,34 @@
 #include <QString>
 #include <Qt>
 #include <QtDebug>
+#include <QtMath>
 
 #include "../vpatterndb/calculator.h"
 #include "../vpatterndb/vtranslatevars.h"
 #include "../qmuparser/qmuparsererror.h"
-#include "../tools/drawTools/vdrawtool.h"
-#include "../ifc/ifcdef.h"
 #include "../vmisc/vcommonsettings.h"
 #include "../vpatterndb/vcontainer.h"
 #include "../vwidgets/vmaingraphicsscene.h"
 #include "../vwidgets/vcurvepathitem.h"
 #include "../vwidgets/scalesceneitems.h"
+#include "../vwidgets/global.h"
 
 template <class K, class V> class QHash;
 
-Q_LOGGING_CATEGORY(vVis, "v.visualization")
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_CLANG("-Wmissing-prototypes")
+QT_WARNING_DISABLE_INTEL(1418)
+
+Q_LOGGING_CATEGORY(vVis, "v.visualization") // NOLINT
+
+QT_WARNING_POP
 
 namespace
 {
 //---------------------------------------------------------------------------------------------------------------------
-VScaledEllipse *InitPointItem(const QColor &color, QGraphicsItem *parent, qreal z = 0)
+auto InitPointItem(const QColor &color, QGraphicsItem *parent, qreal z = 0) -> VScaledEllipse *
 {
-    VScaledEllipse *point = new VScaledEllipse(parent);
+    auto *point = new VScaledEllipse(parent);
     point->setZValue(1);
     point->setBrush(QBrush(Qt::NoBrush));
 
@@ -81,9 +87,9 @@ VScaledEllipse *InitPointItem(const QColor &color, QGraphicsItem *parent, qreal
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VCurvePathItem *InitCurveItem(const QColor &color, QGraphicsItem *parent, qreal z = 0)
+auto InitCurveItem(const QColor &color, QGraphicsItem *parent, qreal z = 0) -> VCurvePathItem *
 {
-    VCurvePathItem *curve = new VCurvePathItem(parent);
+    auto *curve = new VCurvePathItem(parent);
     curve->setBrush(QBrush(Qt::NoBrush));
 
     QPen visPen = curve->pen();
@@ -95,101 +101,66 @@ VCurvePathItem *InitCurveItem(const QColor &color, QGraphicsItem *parent, qreal
     curve->setVisible(false);
     return curve;
 }
-}
+}  // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 Visualization::Visualization(const VContainer *data)
-    :QObject(),
-      data(data),
-      scenePos(QPointF()),
-      mainColor(Qt::red),
-      supportColor(Qt::magenta),
-      lineStyle(Qt::SolidLine),
-      object1Id(NULL_ID),
-      toolTip(QString()),
-      mode(Mode::Creation)
+    :m_data(data)
 {}
 
 //---------------------------------------------------------------------------------------------------------------------
-void Visualization::setObject1Id(const quint32 &value)
+void Visualization::SetLineStyle(const Qt::PenStyle &value)
 {
-    object1Id = value;
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-void Visualization::setLineStyle(const Qt::PenStyle &value)
-{
-    lineStyle = value;
+    m_lineStyle = value;
     InitPen();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 // cppcheck-suppress unusedFunction
-void Visualization::setScenePos(const QPointF &value)
+void Visualization::SetMainColor(const QColor &value)
 {
-    scenePos = value;
+    SetColor(VColor::MainColor, value);
+    InitPen();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void Visualization::VisualMode(const quint32 &pointId)
+void Visualization::StartVisualMode()
 {
-    VMainGraphicsScene *scene = qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
+    auto *scene = qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
     SCASSERT(scene != nullptr)
 
-    this->object1Id = pointId;
-    this->scenePos = scene->getScenePos();
+    this->m_scenePos = scene->getScenePos();
     RefreshGeometry();
 
     AddOnScene();
 }
 
-//---------------------------------------------------------------------------------------------------------------------
-// cppcheck-suppress unusedFunction
-void Visualization::setMainColor(const QColor &value)
-{
-    mainColor = value;
-    InitPen();
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-const VContainer *Visualization::GetData() const
-{
-    return data;
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-void Visualization::SetData(const VContainer *data)
-{
-    this->data = data;
-}
-
 //---------------------------------------------------------------------------------------------------------------------
 void Visualization::MousePos(const QPointF &scenePos)
 {
-    this->scenePos = scenePos;
+    this->m_scenePos = scenePos;
     RefreshGeometry();
-    if (toolTip.isEmpty() == false)
-    {
-        emit ToolTip(toolTip);
-    }
+    RefreshToolTip();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VScaledEllipse *Visualization::InitPoint(const QColor &color, QGraphicsItem *parent, qreal z) const
+auto Visualization::InitPoint(const QColor &color, QGraphicsItem *parent, qreal z) -> VScaledEllipse *
 {
     return InitPointItem(color, parent, z);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal Visualization::FindLengthFromUser(const QString &expression,
-                                        const QHash<QString, QSharedPointer<VInternalVariable> > *vars, bool fromUser)
+auto Visualization::FindLengthFromUser(const QString &expression,
+                                       const QHash<QString, QSharedPointer<VInternalVariable> > *vars,
+                                       bool fromUser) -> qreal
 {
     return VAbstractValApplication::VApp()->toPixel(FindValFromUser(expression, vars, fromUser));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal Visualization::FindValFromUser(const QString &expression,
-                                     const QHash<QString, QSharedPointer<VInternalVariable> > *vars, bool fromUser)
+auto Visualization::FindValFromUser(const QString &expression,
+                                    const QHash<QString, QSharedPointer<VInternalVariable> > *vars,
+                                    bool fromUser) -> qreal
 {
     qreal val = 0;
     if (expression.isEmpty())
@@ -229,6 +200,27 @@ qreal Visualization::FindValFromUser(const QString &expression,
     return val;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+qreal Visualization::CorrectAngle(qreal angle)
+{
+    qreal ang = angle;
+    if (angle > 360)
+    {
+        ang = angle - 360.0 * qFloor(angle/360);
+    }
+
+    return (qFloor(qAbs(ang)/5.)) * 5;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void Visualization::RefreshToolTip() const
+{
+    if (!m_toolTip.isEmpty())
+    {
+        emit ToolTip(m_toolTip);
+    }
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void Visualization::DrawPoint(QGraphicsEllipseItem *point, const QPointF &pos, const QColor &color, Qt::PenStyle style)
 {
@@ -258,6 +250,8 @@ void Visualization::DrawLine(VScaledLine *lineItem, const QLineF &line, const QC
     {
         lineItem->setLine(line);
     }
+
+    lineItem->setVisible(not line.isNull());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -286,45 +280,56 @@ void Visualization::DrawPath(VCurvePathItem *pathItem, const QPainterPath &path,
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VScaledEllipse *Visualization::GetPointItem(QVector<VScaledEllipse *> &points, quint32 i,
-                                            const QColor &color, QGraphicsItem *parent)
+auto Visualization::GetPointItem(QVector<VScaledEllipse *> &points, quint32 i, const QColor &color,
+                                 QGraphicsItem *parent) -> VScaledEllipse *
 {
     if (not points.isEmpty() && static_cast<quint32>(points.size() - 1) >= i)
     {
         return points.at(static_cast<int>(i));
     }
-    else
-    {
-        auto point = InitPointItem(color, parent);
-        points.append(point);
-        return point;
-    }
+
+    auto *point = InitPointItem(color, parent);
+    points.append(point);
+    return point;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VCurvePathItem *Visualization::GetCurveItem(QVector<VCurvePathItem *> &curves, quint32 i, const QColor &color,
-                                            QGraphicsItem *parent)
+auto Visualization::GetCurveItem(QVector<VCurvePathItem *> &curves, quint32 i, const QColor &color,
+                                 QGraphicsItem *parent) -> VCurvePathItem *
 {
     if (not curves.isEmpty() && static_cast<quint32>(curves.size() - 1) >= i)
     {
         return curves.at(static_cast<int>(i));
     }
-    else
-    {
-        auto point = InitCurveItem(color, parent);
-        curves.append(point);
-        return point;
-    }
+
+    auto *point = InitCurveItem(color, parent);
+    curves.append(point);
+    return point;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-Mode Visualization::GetMode() const
+auto Visualization::LengthToUser(qreal value) -> QString
 {
-    return mode;
+    return VAbstractApplication::VApp()->TrVars()
+        ->FormulaToUser(QString::number(VAbstractValApplication::VApp()->fromPixel(value)),
+                        VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void Visualization::SetMode(const Mode &value)
+auto Visualization::AngleToUser(qreal value) -> QString
 {
-    mode = value;
+    return VAbstractApplication::VApp()->TrVars()
+        ->FormulaToUser(QString::number(value), VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void Visualization::SetColor(VColor type, const QColor& color)
+{
+    m_colorShema.insert(type, color);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto Visualization::Color(VColor type) const -> QColor
+{
+    return m_colorShema.value(type, Qt::black);
 }
