@@ -140,7 +140,7 @@
 */
 class ColorPickerButton : public QFrame
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 
 public:
     explicit ColorPickerButton(QWidget *parent);
@@ -164,7 +164,7 @@ protected:
 */
 class ColorPickerItem : public QFrame
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 
 public:
     ColorPickerItem(const QColor &color = Qt::white, const QString &text = QString(),
@@ -200,7 +200,7 @@ private:
 */
 class ColorPickerPopup : public QFrame
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 
 public:
     ColorPickerPopup(int width, bool withColorDialog,
@@ -238,7 +238,7 @@ protected:
     void regenerateGrid();
 
 private:
-    Q_DISABLE_COPY(ColorPickerPopup)
+    Q_DISABLE_COPY_MOVE(ColorPickerPopup) // NOLINT
     QMap<int, QMap<int, QWidget *> > widgetAt{};
     QList<ColorPickerItem *> items{};
     QGridLayout *grid{nullptr};
@@ -600,14 +600,14 @@ ColorPickerPopup::~ColorPickerPopup()
     If there is an item whole color is equal to \a col, returns a
     pointer to this item; otherwise returns 0.
 */
-ColorPickerItem *ColorPickerPopup::find(const QColor &col) const
+auto ColorPickerPopup::find(const QColor &col) const -> ColorPickerItem *
 {
-    for (auto *item : items)
+    auto item = std::find_if(items.begin(), items.end(),
+                             [col](ColorPickerItem *item){return item && item->color() == col;});
+
+    if (item != items.end())
     {
-        if (item && item->color() == col)
-        {
-            return item;
-        }
+        return *item;
     }
 
     return nullptr;
@@ -832,11 +832,10 @@ void ColorPickerPopup::keyPressEvent(QKeyEvent *e)
                 int i = 0;
                 while ((layoutItem = grid->itemAt(i)) != 0)
                 {
-                    QWidget *w = layoutItem->widget();
-                    if (w && w->inherits("ColorPickerItem"))
+                    QWidget *wl = layoutItem->widget();
+                    if (wl && wl->inherits("ColorPickerItem"))
                     {
-                        ColorPickerItem *litem
-                            = reinterpret_cast<ColorPickerItem *>(layoutItem->widget());
+                        auto *litem = reinterpret_cast<ColorPickerItem *>(layoutItem->widget());
                         if (litem != wi)
                         {
                             litem->setSelected(false);
@@ -858,11 +857,10 @@ void ColorPickerPopup::keyPressEvent(QKeyEvent *e)
                 int i = 0;
                 while ((layoutItem = grid->itemAt(i)) != 0)
                 {
-                    QWidget *w = layoutItem->widget();
-                    if (w && w->inherits("ColorPickerItem"))
+                    QWidget *wl = layoutItem->widget();
+                    if (wl && wl->inherits("ColorPickerItem"))
                     {
-                        ColorPickerItem *litem
-                            = reinterpret_cast<ColorPickerItem *>(layoutItem->widget());
+                        auto *litem = reinterpret_cast<ColorPickerItem *>(layoutItem->widget());
                         if (litem != wi)
                         {
                             litem->setSelected(false);
