@@ -35,6 +35,11 @@
 #include <QObject>
 #include <QString>
 
+#include "../vmisc/defglobal.h"
+#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
+#include "../vmisc/diagnostic.h"
+#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
+
 struct VFinalMeasurement;
 
 QT_WARNING_PUSH
@@ -43,10 +48,10 @@ QT_WARNING_DISABLE_GCC("-Wsuggest-final-methods")
 
 class VAbstractMainWindow : public QMainWindow
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 public:
     explicit VAbstractMainWindow(QWidget *parent = nullptr);
-    virtual ~VAbstractMainWindow() Q_DECL_EQ_DEFAULT;
+    virtual ~VAbstractMainWindow() = default;
 
 public slots:
     virtual void ShowToolTip(const QString &toolTip);
@@ -80,7 +85,7 @@ protected:
     bool IgnoreLocking(int error, const QString &path, bool guiMode);
 
 private:
-    Q_DISABLE_COPY(VAbstractMainWindow)
+    Q_DISABLE_COPY_MOVE(VAbstractMainWindow) // NOLINT
 };
 
 QT_WARNING_POP
