@@ -49,6 +49,7 @@
 #include "vscenepoint.h"
 #include "../vmisc/vmath.h"
 #include "../vmisc/vabstractvalapplication.h"
+#include "../vmisc/literals.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -152,7 +153,7 @@ void VGraphicsSimpleTextItem::SetShowParentTooltip(bool show)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VGraphicsSimpleTextItem::SetRealPos(QPointF pos)
+void VGraphicsSimpleTextItem::SetRealPos(const QPointF &pos)
 {
     m_realPos = pos;
 
