@@ -131,13 +131,13 @@ void TST_MeasurementRegExp::TestCheckIsNamesUnique_data()
     }
 
     QTest::addColumn<QString>("translatedName");
-    QTest::addColumn<QList<QString>>("originalNames");
+    QTest::addColumn<QStringList>("originalNames");
 
     QList<QString> keys = names.uniqueKeys();
     for (const auto &key : keys)
     {
         const QString tag = QString("System: '%1', locale: '%2'. Name '%3'").arg(m_system, m_locale, key);
-        QTest::newRow(qUtf8Printable(tag)) << key << names.values(key);
+        QTest::newRow(qUtf8Printable(tag)) << key << QStringList(names.values(key));
     }
 }
 
@@ -145,7 +145,7 @@ void TST_MeasurementRegExp::TestCheckIsNamesUnique_data()
 void TST_MeasurementRegExp::TestCheckIsNamesUnique()
 {
     QFETCH(QString, translatedName);
-    QFETCH(QList<QString>, originalNames);
+    QFETCH(QStringList, originalNames);
 
     if (QLocale() == QLocale(QStringLiteral("zh_CN")) || QLocale() == QLocale(QStringLiteral("he_IL")))
     {
@@ -201,6 +201,7 @@ void TST_MeasurementRegExp::TestCombinations(int systemCounts, const QStringList
     QDir dir(TranslationsPath());
     const QStringList fileNames = dir.entryList(QStringList("measurements_p*_*.qm"));
 
+    // cppcheck-suppress unreadVariable
     const QString error = QString("Unexpected count of files. Excpected %1, got %2.")
             .arg(combinations).arg(fileNames.size());
     QVERIFY2(combinations == fileNames.size(), qUtf8Printable(error));
