@@ -785,7 +785,7 @@ void TST_VSpline::TestLengthByPoint_data()
     const qreal length = spl.GetLength();
     const qreal testLength = length*(2.0/3.0);
     VSpline spl1, spl2;
-    const QPointF p = spl.CutSpline(testLength, spl1, spl2);
+    const QPointF p = spl.CutSpline(testLength, spl1, spl2, QString());
 
     QTest::newRow("Point on spline") << spl << p << testLength;
     QTest::newRow("Wrong point") << spl << QPointF(-10000, -10000) << -1.0;
@@ -840,7 +840,8 @@ void TST_VSpline::TestFlip()
 
     const VSpline res = spl.Flip(axis, prefix);
 
-    const QString errorMsg = QString("The name doesn't contain the prefix '%1'.").arg(prefix);
+    // cppcheck-suppress unreadVariable
+    const QString errorMsg = QStringLiteral("The name doesn't contain the prefix '%1'.").arg(prefix);
     QVERIFY2(res.name().endsWith(prefix), qUtf8Printable(errorMsg));
 
     QCOMPARE(spl.GetLength(), res.GetLength());
@@ -848,6 +849,63 @@ void TST_VSpline::TestFlip()
     QCOMPARE(spl.GetC2Length(), res.GetC2Length());
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void TST_VSpline::TestCutSpline_data()
+{
+    QTest::addColumn<VSpline>("spl");
+    QTest::addColumn<qreal>("result");
+    QTest::addColumn<QString>("name");
+
+    {
+    VPointF p1(187.31716535433043, 51.31464566929152, QStringLiteral("p1"), 140.42872440944885, -22.62372283464567);
+    VPointF p4(-991.8954330708666, 9.739842519685212, QStringLiteral("p4"), 9.999987401574804, 15.0);
+
+    VSpline spl(p1, p4, 181.0, QStringLiteral("181"), 356.0, QStringLiteral("356"), 548.7874015748031,
+                QStringLiteral("Line_Г3_Г6*1.1"), 226.7716535433071, QStringLiteral("6"));
+    spl.SetApproximationScale(0.5);
+
+    QString name(QStringLiteral("з"));
+    qreal result = 1.35; // Correct distance in cm.
+
+    // See file valentina_private_collection/bugs/men_jacket/issue_cut_spline.val (private collection)
+    // Size 54 produces incorrect spline segment distance
+    QTest::newRow("Size 54") << spl << result << name;
+    }
+
+    {
+    VPointF p1(1898.0384322000489, -143.17624447113994, QStringLiteral("p1"), 9.999987401574804, -105.35848818897638);
+    VPointF p4(1557.8809518850883, -143.17624447113994, QStringLiteral("p4"), 9.999987401574804, 15.0);
+
+    VSpline spl(p1, p4, 175.0, QStringLiteral("175"), 5.0, QStringLiteral("5"), 151.18110236220474,
+                QStringLiteral("4"), 151.18110236220474, QStringLiteral("4"));
+
+
+    QString name(QStringLiteral("А193"));
+    const qreal result = 4.5090698038574057; // Correct distance in cm.
+    // See file valentina_private_collection/bugs/coat/coat.val (private collection)
+    QTest::newRow("Half of a curve") << spl << result << name;
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void TST_VSpline::TestCutSpline()
+{
+    QFETCH(VSpline, spl);
+    QFETCH(qreal, result);
+    QFETCH(QString, name);
+
+    QPointF spl1p2, spl1p3, spl2p2, spl2p3;
+    QPointF point = spl.CutSpline(UnitConvertor(result, Unit::Cm, Unit::Px), spl1p2, spl1p3, spl2p2, spl2p3, name);
+
+    VPointF p(point, name, -16.590651968503941, 37.574173228346453);
+
+    VSpline spline1(spl.GetP1(), spl1p2, spl1p3, p);
+    spline1.SetApproximationScale(0.5);
+
+    Q_DECL_RELAXED_CONSTEXPR qreal eps = ToPixel(0.0001, Unit::Mm);
+    QVERIFY(UnitConvertor(spline1.GetLength(), Unit::Px, Unit::Cm) - result < eps);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void TST_VSpline::CompareSplines(const VSpline &spl1, const VSpline &spl2) const
 {
