@@ -30,12 +30,13 @@
 #define TST_VSPLINE_H
 
 #include "../vtest/abstracttest.h"
+#include "../vmisc/defglobal.h"
 
 class VSpline;
 
 class TST_VSpline : public AbstractTest
 {
-    Q_OBJECT
+    Q_OBJECT // NOLINT
 public:
     explicit TST_VSpline(QObject *parent = nullptr);
 
@@ -55,9 +56,12 @@ private slots:
     void TestLengthByPoint();
     void TestFlip_data();
     void TestFlip();
+    void TestCutSpline_data();
+    void TestCutSpline();
 
 private:
-    Q_DISABLE_COPY(TST_VSpline)
+    // cppcheck-suppress unknownMacro
+    Q_DISABLE_COPY_MOVE(TST_VSpline) // NOLINT
     void CompareSplines(const VSpline &spl1, const VSpline &spl2) const;
 };
 
